#!/bin/sh

# As a shell script (running on Unix...) it expects to find the local
# copy of your standard Unix shell, the 'tail' utility and a working 'awk'
# interpreter.

# I use the default location for ASSP's maillog file, and the 'maillog.txt'
# name (in assp.cfg) to keep ASSP from changing it on me.

# This script attempts to go back at least 300 lines in your maillog.txt
# file to give you a nice screenful of goodies to review when it
# first starts.  If your maillog.txt is nearly empty, then just
# be patient. As things happen - the logger will reveal it in COLOR!
# ------------------------------------ KRL -------------------------

# Version: 0.04  Nov. 21, 2003
# Fixed "-adds-" substring boo-boo
# Version: 0.03
# Fixed/improved the display of Whitelist additions..(aka: hamlist & normal)

# Simple (sort of...) AWK script to display ASSP 'maillog.txt"
#  data in a useful format.
#
# Uses 'tail' to follow the output, format each line in
#  a nice way - and use COLOR + a 2 Char. Flag to identify
#  each entry as they scroll by. It goes back 100 lines in
#  order to give you a full screen on startup. Also, it assumes
#  ANSI Color mode for your screen to display the lines in color.
#
# BS (in Red) lines are those caught by the Bayesian filter !!
# LW (in White .. mostly) are those Local or Whitelisted eMails
# Ok (in Green) are eMail that fully pass alltests without exceptions.
# RB (in Magenta) .. Blocked Relay attempt
# HL (in Magenta) .. Blocked due to spam HELO
# SP (in Magenta) .. Blocked by failed SPF lookup
# WA+  Whitelist ADDITION by an authorized local user
# WL+  Whitelist ADDITION of address CC'd in whitelisted email
# BA (in Cyan) .. Bad ATTACHEMENT rejected
# SR (in Cyan) .. spam@ report submission
# NS (in Cyan) .. notspam@ report submission
#
# I got the idea for this script from Mark Constable. He submitted
#  a similar script to follow the Courier-MTA /var/log/maillog
#  Thanks,
#  Randy Lewis, RTMX.NET
#  Nov., 2003
#
# NOTES:
# Some fields are truncated (with a hard-coded length value, usually 40)
#   to keep each line more or less intact on your screen as things scroll by
# Colors are coded with ANSI Color coding, your mileage may vary ...
# I assume the naming convention of 'maillog.txt' so ASSP won't munge
#  each current log into some difficult-to-grok name.  You should try
#  to use this feature - and perhaps roll the log periodically with
#  your system's 'newsyslog' functionality. You can send a SIGHUP to
#  ASSP when you roll the log so it starts afresh..KRL

tail -300 -f /var/db/assp/maillog.txt | \
 awk  ' \
  /local or whitelisted/ { \
  printf("%s %s \033[1;32m%-15s\033[0m \033[1;37mLW  %s\033[0m \033[1;32m->\033[0m \033[1;37m%s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6 )\
        } \
  /Email whitelist addition/ { \
  printf("%s %s \033[1;36m%-15s WA+ %s\033[0m \033[1;37m%s\033[0m\n", \
        $1, \
        $2, \
        "+email address+", \
        "-adds-", \
        $6 )\
        } \
  /whitelist addition:/ && !/[Ee]mail/ { \
  printf("%s %s \033[1;32m%-15s\033[0m \033[1;37mWL+ %s\033[0m \033[1;32m%s\033[0m \033[1;37m%s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        "-adds-", \
        $9 )\
        } \
  /Bayesian [Ss]pam/ { \
  printf("%s %s \033[1;31m%-15s BS  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6 )\
        } \
  /message ok/ { \
  printf("%s %s \033[1;32m%-15s Ok  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6 )\
        } \
  /bad attachment/ && !/no bad/ { \
        printf("%s %s \033[1;35m%-15s BA  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6 )\
        } \
  /relay attempt blocked/ { \
        printf("%s %s \033[1;35m%-15s RB  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        ($9 ~ /^(.*):$/) ? $10 : $9 )\
        } \
  /[Ii]nvalid address rejected/ { \
  printf("%s %s \033[1;34m%-15s IR  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $NF )\
        } \
  /malformed address/ { \
  printf("%s %s \033[1;35m%-15s MA  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $7 )\
        } \
  /failed RBL checks|Received-RBL: fail/ { \
  printf("%s %s \033[1;35m%-15s BL  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6 )\
        } \
  /failed SPF checks|Received-SPF: fail/ { \
  printf("%s %s \033[1;35m%-15s SP  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6 )\
        } \
  /has spam helo/ { \
  printf("%s %s \033[1;35m%-15s HL  %s -> %s %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $6, \
        $10 )\
        } \
  /Sender Validation:blocked:/ { \
  printf("%s %s \033[1;35m%-15s HL  %s %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $9 )\
        } \
  /recipient delayed/ { \
  printf("%s %s \033[1;35m%-15s DL  %s -> %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        substr($4,1,40), \
        $7 ) \
        } \
  /Admin (update:|connection from )/ { \
  printf("\033[1;33m%s\033[0m\n", $0) \
        } \
  /[Ee]mail spamreport/ { \
  printf("%s %s\033[1;36m %-15s SR  %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        $4 ) \
        } \
  /[Ee]mail hamreport/ { \
  printf("%s %s\033[1;36m %-15s NS  %s\033[0m\n", \
        $1, \
        $2, \
        $3, \
        $4 ) \
 }'
# end of script

