#!/usr/local/bin/perl

#use strict;
#use warnings;

# perl antispam smtp proxy
# (c) John Hanna, John Calvi, Robert Orso, AJ 2004 under the terms of the GPL
# ASSP founded and developed to Version 1.0.12 by John Hanna.
# ASSP web interface by AJ.
# ASSP development since 1.0.12 by John Calvi.
# LDAP implementation by Robert Orso.
# Nigel Barling - SPF & RBL.
# Mark Pizzolato - SMTP Session Limits.
# Przemek Czerkas - 1.1.2 SRS, Delaying, Maillog Search, HTTP Compression.
# Fritz Borgstedt - 1.2.x
#  Contributions - Wim Borghs, Micheal Espinola, Doug Traylor, Lars Troen, 
#				   Andrew Macpherson, Javier Albinarrate 

use bytes; # get rid of annoying 'Malformed UTF-8' messages

$version='1.2.3';
$modversion='(0)'; #appended in version display.
$starttime=localtime(time);


$CanUseHostname = $localhostname = hostname();
$CanUseHostaddr = $localhostaddr = inet_ntoa(scalar(gethostbyname($localhostname)) || 'localhost') if $CanUseHostname;


$CanUseLDAP = eval("use Net::LDAP; 1"); # Net LDAP module installed
$CanUseAddress = eval("use Email::Valid; 1"); # Email Valid module installed
$CanUseDNS = eval("use Net::DNS; 1"); # Net DNS module installed - required for SPF & RBL
$AvailSPF = eval("use Mail::SPF::Query; 1"); # Mail SPF module installed
$CanUseSPF = $AvailSPF && $CanUseDNS; # SPF and dependancies installed
$CanUseRBL = $CanUseDNS; # RBL is rolled into the code
$AvailSRS = eval("use Mail::SRS; 1"); # Mail SRS module installed
$CanUseSRS = $AvailSRS;
$AvailZlib = eval("use Compress::Zlib; 1"); # Zlib module installed
$CanUseHTTPCompression = $AvailZlib;
$AvailMD5 = eval("use Digest::MD5; 1"); # Digest MD5 module installed
$CanUseMD5Keys = $AvailMD5;
$AvailReadBackwards = eval("use File::ReadBackwards; 1"); # ReadBackwards module installed;
$CanSearchLogs = $AvailReadBackwards;
$AvailHiRes = eval("use Time::HiRes; 1"); # Time::HiRes module installed;
$CanStatCPU = $AvailHiRes;
$AvailIO = eval("use PerlIO::scalar; 1") ; # make it chroot savy;
$CanChroot = $AvailIO;
$AvailSyslog = eval("use Sys::Syslog qw( :DEFAULT setlogsock); 1");
$CanUseSyslog = $AvailSyslog;
$AvailWin32Daemon = eval("use Win32::Daemon; 1") ; # Win32 Daemon module installed
$CanUseWin32Daemon = $AvailWin32Daemon;



# load from command line if specified
if($ARGV[0]) {
 $base=$ARGV[0];
} else {
 # the last one is the one used if all else fails
 foreach ('.','assp','/usr/local/assp','/home/assp','/usr/assp','/assp','.') {
  $base=$_;
  last if -e "$base/assp.cfg";
 }
}
if ( !-e "$base/images/noIcon.png")
{ die "Abort: folder 'images' not correctly installed";}

loadConfig();

sub loadConfig {
 # print "loading config -- base='$base'\n";
 @Config=(
[0,0,0,'heading','Network Setup'],
 # except for the heading lines, all config lines have the following:
 #  $name,$nicename,$size,$func,$default,$valid,$onchange,$description
 # name is the variable name that holds the data
 # nicename is a human readable pretty display name (oh how nice!)
 # size is the appropriate input box size
 # func is a function called to render the config item
 # default is the default value
 # valid is a regular expression used to clean and validate the input -- no match is an error and $1 is the desired result
 # onchange is a function to be called when this value is changed -- usually undef; just updating the value is enough
 # group is the heading group belonged to.
 # description is text displayed to help the user figure what to put in the entry

 [smtpDestination,'SMTP Destination',20,textinput,'127.0.0.1:225','(\S*)',undef,
  'The address:port of your message handling system\'s smtp server.<br />If only the port is entered, or the keyword <b>__INBOUND__</b>:<i>port</i> is used, then the connection will be established to the same IP where the connection was received. This is usefull when you have several IPs with different domains/profiles in your MTA.<br /> Examples: "127.0.0.1:125", "10.0.1.3", "10.0.1.3:1025", "__INBOUND__:125", "125", etc.'],
 [AsAService,'As a Service',0,checkbox,0,'(.*)',undef,
  'In Windows 2000 / NT you can run it as a service; requires <a href="http://www.roth.net/perl/Daemon/" rel="external">win32::daemon</a>. Requires start from the service control panel.'],
 [AsADaemon,'As a Daemon',0,checkbox,1,'(.*)',undef,
 'In Linux/BSD/Unix/OSX fork and close file handles, kinda like "perl assp.pl &amp;" but better. Requires restart.'],
 [myName,'My Name',40,textinput,'ASSP.nospam','(\S+)',undef,
  'What the program calls itself in the email "received by" header. Usually ASSP.nospam.'],
 [listenPort,'Listen Port',20,textinput,'125','(\S+)',ConfigChangeMailPort,
  'On what port should ASSP accept smtp connections? Normally 25. You can supply an interface:port to limit connections.'],
 [listenPort2,'Another Listen Port',20,textinput,'','(\S*)',ConfigChangeMailPort2,
  'Listen for incoming SMTP requests on a second port.<br />
  For those who cannot use SMTP Port 25 outside of their ISP Network,
  or as a dedicated port for VPN purposes.<br />
  You can supply an interface:port to limit connections. For example: 2525 or 127.0.0.2:325'],
[smtpAuthServer,'SMTP Auth Destination',20,textinput,'','(\S*)',undef, 
'Port to connect to when connections arrive on the second Listen Port. If blank all incoming 
mail will go to the main SMTP Destination, the main use is to allow remote / travelling users to make authenticated connections, and therefore inject their mail at the SPF-correct point in the network. eg 127.0.0.1:587'],
 
 [ConnectionLog,'Connections Logging',0,checkbox,0,'(.*)',undef,
  'Log an event each time a new connection is received.'],
 [maxSMTPSessions,'Maximum SMTP Sessions',5,textinput,'50','(\d?\d?\d?)',undef,
  'The maximum number of SMTP sessions (connections) to handle concurrently.<br />
  This can help if the server is overloading. 20 simultaneous connections is typically enough.
 no entry or zero = no limit.'],
 [maxSMTPipSessions,'Maximum Sessions/IP',5,textinput,'5','(\d?\d?\d?)',undef,
  'The maximum number of SMTP sessions (connections) to handle per IP address concurrently.<br />
  Limit this to prevent DOS attacks, 5 simultaneous connections is typically enough.
  no entry or zero = no limit.<br />
  Also note that the ISP &amp; accept all mail addresses are excluded from limiting.'],
 [smtpIdleTimeout,'SMTP Idle Timeout',5,textinput,'0','(\d?\d?\d?)',undef,
  'The maximum time the connection will be allowed to be idle.<br />
  This can be helpful with bad-behaved MTAs. 60 seconds is default. No entry or zero = no limit.'],
 [SessionLog,'Session Limit Logging',0,checkbox,0,'(.*)',undef,
  'Log an event each time the above session limits are triggered.'],
 [proxyserver,'Proxy Server',20,textinput,'','(\S*)',undef,
  'Use a Proxy Server for up/downloading greylist etc. Format - interface:port.
  For example: 192.168.0.1:8080'],
 [webAdminPort,'Web Admin Port',20,textinput,55555,'(\S+)',ConfigChangeAdminPort,
  'On what port should ASSP listen for http connections for the web administration interface?<br />
  Changing this will require changing the URL on your browser to reconnect.
  You can supply an interface:port to limit connections.  <br />
  <hr />
  <div class=\"menuLevel1\">Notes On Network Setup</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/network.txt\',3);">
  '],

[0,0,0,'heading','SPAM Control'],
[DoBayesian,'Bayesian Check',1,textinput,1,'(\d*)',undef,
'If activated, the message is checked  based on Bayesian factors in Spamdb.<br /><span class="negative"> 0 = no check, 1 = check.</span>.'],
[baysConfidence,'Bayesian Confidence Level',3,textinput,'0','(.*)',undef,
'Spam-Mails having a confidence below this value are passed in testmode and those
above are blocked. Set this only above 0 if you are familiar with the bayesian statistics used in ASSP.<br /><span class="negative"> 0 = disabled.</span>.'],
 [SpamError,'Spam Error',80,textinput,'500 Mail appears to be unsolicited -- send error reports to postmaster@yourdomain.com','(5\d\d .*)',undef,
  'SMTP error message to reject spam.'],
 [spamaddresses,'Spam Collect Addresses*',60,textinput,'put|your@spambucket.com|addresses|@here.org','(.*)',ConfigMakeRe,
  'Mail to any of these users at are always spam and will contribute to the spam-collection unless from someone on the whitelist;<br />
  @domain.com makes the whole domain a spam domain. A username without domain will register across all local domains.'],
[spamtrapaddresses,'Spam Trap Addresses*',60,textinput,'put|your@spamtrap.com|addresses|@here.org','(.*)',ConfigMakeRe,
  'Mail to any of these users will be blocked by Penalty Box. Whitelist will be ignored. No logging will occur;<br />
  @domain.com makes the whole domain a spam domain. A username without domain will register across all local domains.'],
[noProcessing,'Unprocessed Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'Mail solely to or from any of these addresses are ignored by ASSP.<br />
  Like a more efficient version of spamLovers &amp; redlist combined. Valid entry types are as per spamlovers.'],
 [blackListedDomains,'Blacklisted Domains*',60,textinput,'','(.*)',ConfigMakeRe,
  'Domains from which you always want to reject mail, they only send you spam. For example: spam.net|xxxpics.com'],
 [whiteRe,'Expression to Identify Non-Spam*',60,textinput,'','(.*)',ConfigCompileRe,
  'If an incoming email matches this Perl regular expression it will be considered non-spam.<br />
  For example: Secret Ham Password|307\D{0,3}730\D{0,3}4[12]\d\d<br />
  For help writing regular expressions click <a href="http://www.perlmonks.org/index.pl?node=perlre" rel="external">here</a>.
  Note that flags are "si" and the header as well as body is scanned.<br />
  Some things you might include here are your office phone number or street address, spam rarely includes these details.'],
 [blackRe,'Expression to Identify Spam*',60,textinput,'http://[\\w\\.]+@|\w<[a-z0-9]+[abcdfghjklmnpqrstuvwxyz0-9]{4}[a-z0-9]*>|subject: [^\\n]*     \S','(.*)',ConfigCompileRe,
  'If an incoming email that\'s not local or whitelisted matches this Perl regular expression it will be considered spam.<br />
  May match text from the body or header of the email. For example: penis|virgin|X-Priority: 1'],
 [redRe,'Expression to Identify Redlisted Mail*',60,textinput,'file:redre.txt','(.*)',ConfigCompileRe,
  'If an email header matches this Perl regular expression it will be considered redlisted. For example: \\[autoreply\\]'],
 [npRe,'Expression to Identify No-processing Mail*',60,textinput,'','(.*)',ConfigCompileRe,
  'If an email header matches this Perl regular expression it will pass through unprocessed. For example: \\[autoreply\\]'],
[contentOnlyRe,'Check Contents Only RegEx ',60,textinput,'','(.*)',ConfigCompileRe,
  "Put anything here to identify messages which should only be checked for content. For example:  mailadresses of people who are forwarding from other accounts to their mailbox on your server.These addresses will bypass PB, Sender Validation, Greylist, IP Limiting, Delaying, SPF, RBL &amp; SRS checks.
"],
 
 [noGreyListUpload,'Don\'t Upload Greylist Stats',0,checkbox,0,'(.*)',undef,
  'Check this to disable the greylist upload when rebuildspamdb runs.'],
 [nogreydownload,'Don\'t auto-download the greylist file',0,checkbox,0,'(.*)',undef,
  'Set this checkbox if don\'t use the greylist or want to download it manually.'],
 [AddSpamProbHeader,'Add Spam Probability Header',0,checkbox,0,'(.*)',undef,
  'Adds a line to the email header "X-Assp-Spam-Prob: 0.0123" Probs range from 0 to +1 where > 0.6 = spam.'],
 [AddConfidenceHeader,'Add Bayes Confidence Header',0,checkbox,0,'(.*)',undef,
  'Adds a line to the email header "X-Assp-Bayes-Confidence: 0.0123" .'],
 [NoExternalSpamProb,'Block Outgoing Spam-Prob header',0,checkbox,1,'(.*)',undef,
  'Check this box if you don\'t want your X-Assp-Spam-Prob header on external mail<br />
  Note this means mail from local users to local users will also be missing the header.'],
   [AddRegexHeader,'Add Black/White RegEx Header',0,checkbox,0,'(.*)',undef,
  ''],

 [AddSpamHeader,'Add Spam Header',0,checkbox,1,'(.*)',undef,
  'Adds a line to the email header "X-Assp-Spam: YES" if the message is spam.'],
 [AddSpamReasonHeader,'Add Spam Reason Header',0,checkbox,1,'(.*)',undef,
  'Adds a line to the email header "X-Assp-Spam-Reason: " explaining why the message is spam.'],
 [UseSubjectsAsMaillogNames,'Use Subject as Maillog Names',0,checkbox,1,'(.*)',undef,
 
  'You can turn this on to help you manually identify mail in your spam and non-spam collections.
  <br />
  <hr />
  <div class=\"menuLevel1\">Notes On Spam Control</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/spamcontrol.txt\',3);">
  '],

[0,0,0,'heading','SPAM Lover Options'],
 [spamLovers,'Spam-Lover Addresses*',60,textinput,'postmaster','(.*)',ConfigMakeRe,
  'Spam addressed entirely to spam lovers is not blocked. Mail addressed to both spam lovers and non spam lovers IS blocked.<br />
  Accepts specific addresses (user@domain.com), addresses at local domains (user), or entire local domains (@domain.com).<br />
  Separate entries with pipes: |. For example: jhanna@thisdomain.com|fhanna|@sillyguys.org'],
 [baysSpamLovers,'Bayesian Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'Bayesian Spam-Lover Addresses.'],
 [blSpamLovers,'Blacklisted Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'Blacklisted Spam-Lover Addresses.'],
 [hlSpamLovers,'HELO Listed Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'HELO Listed Spam-Lover Addresses.'],
 [spfSpamLovers,'SPF Failures Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'SPF Failures Spam-Lover Addresses.'],
 [rblSpamLovers,'RBL Failures Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'RBL Failures Spam-Lover Addresses.'],
 [srsSpamLovers,'Not SRS Signed Bounces Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,'Not SRS Signed Bounces Spam-Lover Addresses.'],
 [delaySpamLovers,'Not Delaying Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,'Not Delaying Spam-Lover Addresses.'],
 [isSpamLovers,'Invalid Sender Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'This includes -Invalid Format Helo-,-Reversed Lookup-,-Missing MX/A- failed messages. '],
 [pbSpamLovers,'Penalty Box Blocking Spam-Lover Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'Penalty Box Blocking Spam-Lover Adresses.'],

  [spamSubjectSL,"Suppress Spam Subject to Spam-Lover-mail",0,checkbox,0,'(.*)',undef,
  'If set  spamSubject gets NOT prepended to the subject of the Spam-Lover-email.
  <br /><hr />
  <div class=\"menuLevel1\">Notes On Spam Lover</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/spamlover.txt\',3);">
'],

[0,0,0,'heading','Whitelist Options'],
 [whiteListedDomains,'Whitelisted Domains*',60,textinput,'sourceforge.net','(.*)',ConfigMakeRe,
  'Domains from which you want to receive all mail<br />
  Your ISP, domain registration, mail list servers, stock broker, or other key business partners might be good candidates.<br />
  Note this matches the end of the address, so if you don\'t want to match subdomains then include the @.<br />
  Note that buy.com would also match spambuy.com but .buy.com won\'t match buy.com.<br />
  DO NOT put your local domains on this list. For example: sourceforge.net|@google.com|.buy.com'],
 [MaxWhitelistDays,'Max Whitelist Days',5,textinput,'90','(\d+)',undef,
  'This is the number of days an address will be kept on the whitelist without any email to/from this address.'],
 [WhitelistOnly,'Reject All But Whitelisted Mail',0,checkbox,0,'(.*)',undef,
  'Check this if you don\'t want Bayesian filtering and want to reject all mail from anyone not whitelisted.<br />
  Note: this turns the redlist into a blacklist.'],
 [NoMaillog,'Don\'t log mail',0,checkbox,0,'(.*)',undef,
  'Check this if you\'re using Whitelist-Only and don\'t care to save mail to build the Bayesian database.'],
 [NotGreedyWhitelist,'Only the envelope-sender is added/compared to the whitelist',0,checkbox,0,'(.*)',undef,
  'Normal operation includes addresses in the FROM, SENDER, REPLY-TO, ERRORS-TO, or LIST-* header fields.<br />
  This allows nearly all list email to be whitelisted. Check this option to disable this.'],
 [WhitelistLocalOnly,'Only local or authenticated users contribute to the whitelist.',0,checkbox,0,'(.*)',undef,
  'Normal operation allows all local, authenticated, or whitelisted users to add to the whitelist.<br />
  Check this box to not allow whitelisted users to add to the whitelist.'],
 [WhitelistLocalFromOnly,'Only users with a local domain in mailfrom contribute to the whitelist.',0,checkbox,1,'(.*)',undef,
  'Check this box to prevent *sender* with remote domain from being added to the whitelisted. (eg. redirected messages).'],
 [KeepWhitelistedSpam,'Keep Whitelisted Spam',0,checkbox,0,'(.*)',undef,
  'Check this box if you don\'t want rebuildspamdb to remove entries from the spam collection
   after subsequent whitelisting.<br /> Checking this box will speed up your rebuild.'],
 [UpdateWhitelist,'Save Whitelist',10,textinput,3600,'(\d+)',undef,
  'Save a copy of the white list every this many seconds.<br />
  Note: the current timeout must expire before the new setting is loaded, or you can restart.
  <br /><hr />
  <div class=\"menuLevel1\">Notes On Whitelist</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/whitelist.txt\',3);">
'],

 [0,0,0,'heading','Relaying'],
 [ispip,'ISP/Secondary MX Servers*',60,textinput,'','(\S*)',ConfigMakeRe,
  'Enter any addresses that are your ISP or backup MX servers, separated by pipes (|). <br />
  These addresses will (necessarily) bypass Greylist, IP Limiting, Delaying, SPF, RBL &amp; SRS checks. For example: 127.0.0.1|10.'],
 [ispgreyvalue,'ISP/Secondary MX Grey Value',5,textinput,'','(\S*)',undef,
  'It is recommended that for ISP &amp; Secondary MX servers to bypass their greylist values<br />
  For eg. 0.5 (Completely grey). If left blank then the greylist "X" value is used.<br />
  Note: value should be greater than 0 and less than 1, where 0 = never spam &amp; 1 = always spam'],
 [acceptAllMail,'Accept All Mail*',60,textinput,'','(.*)',ConfigMakeRe,
  'These hosts contribute to the whitelist.<br />
  For example: 127.0.0.1|10.|169.254.|172.16.|192.168.'],
 [relayHostFile,'Relay Host File',40,textinput,'','(.*)',undef,
  'Like Accept All Mail, but <b>OBSOLETE! Please use -><i>Accept All Mail</i>.</b>'],
 [localDomains,'Local Domains*',60,textinput,'putYourDomains.com|here.org','(.*)',ConfigMakeRe,
  'Addresses in these domains are considered local delivery. Separate addresses with |. Include all subdomains.<br />
  For example: put.YourDomains.com|here.org'],
 [localDomainsFile,'Local Domains File',40,textinput,'','(.*)',undef,
  'Like Local Domains, but <b>OBSOLET! Please use -><i>Local Domains</i>.</b>'],
 [BounceSenders,'Bounce Senders*',60,textinput,'postmaster|mailer-daemon','(.*)',ConfigMakeRe,
  'Envelope sender addresses treated as bounce origins. Null sender (&lt;&gt;) is always included.<br />
  Accepts specific addresses (postmaster@domain.com), usernames (mailer-daemon), or entire domains (@bounces.domain.com)<br />
  Separate entries with pipes: |. For example: postmaster|mailer-daemon'],
 [PopB4SMTPFile,'Pop Before SMTP DB File',40,textinput,'','(.*)',undef,
  'Enter the DB database filename of your POP before SMTP implementation with records stored for
  dotted-quad IP addresses<br />
  For example: /etc/mail/popip.db If it\'s got something else, you\'ll need to edit the PopB4SMTP subroutine.'],
 [relayHost,'Relay Host',20,textinput,'','(\S*)',undef,
  'Your isp\'s mail relayhost (smarthost). For example: mail.isp.com:25<br />
  If you run Exchange/Notes and you want assp to update the nonspam database and the whitelist, then enter your isp\'s<br />
  smtp relay host here. Blank means no relayhost. Only required if clients don\'t deliver through SMTP, or when SRS is enabled.'],
 [relayPort,'Relay Port',20,textinput,'','(\S*)',ConfigChangeRelayPort,
  'Tell your mail server to connect to this port (e.g. 127.0.0.1:225 or 127.0.0.2) as its smarthost / relayhost.
  For example: 225<br /> Note that you\'ll want to keep the relayPort protected from external access by your firewall.<br />
  You can supply an interface:port to limit connections.'],
  
 [NoRelaying,'No Relaying Error',80,textinput,'530 Relaying not allowed','(5\d\d .*)',undef,
  'SMTP error message to deny relaying.'],
 [defaultLocalHost,'Default Local Host',40,textinput,'','(\S*)',undef,
  'If you want to be able to send mail to local users without a domain name then put the
  default local domain here.<br /> Blank disables this feature. For example: mydomain.com'],
 
[0,0,0,'heading','Validate Local Addresses'],
 [NoValidRecipient,'No-Valid-Local-User Reply',80,textinput,'550 5.1.1 User unknown','([5|2]\d\d .*)',undef,
  'SMTP reply for invalid Users. Default: \'550 5.1.1 User unknown\'<br />
  You may reply with a \'fake OK\' by entering \'250 OK - Recipient &lt;EMAILADDRESS&gt;\'
  to confuse address harvesters.<br />
  The literal EMAILADDRESS (case sensitive) is replaced by the fully qualified SMTP recipient (e.g. thisuser@yourcompany.com).'],
 [NoValidRecipientSleepTime,'Sleep time when rejecting a recipient',2,textinput,0,'(\d*)',undef,
  'Setting this  slows down email address harvesters, making email harvesting against your server almost useless. For example: 5 (seconds). Make sure this sleep time is lower than the idle-timeout of the MTA behind ASSP! '],    
[DoRFC822,'Validate local addresses to conform with RFC 822',0,checkbox,1,'(.*)',undef,
  'If activated, each local address is checked to conform with the email format defined in RFC 822.<br />
  This requires an installed <a href="http://search.cpan.org/~maurice/Email-Valid-0.15/Valid.pm" rel="external">Email::Valid</a> module in PERL.'],
 [LocalAddresses_Flat,'Local Addresses*',60,textinput,'','(.*)',ConfigMakeRe,
  'These email addresses are considered local by ASSP. You can list specific addresses (user@mydomain.com),<br />
  addresses at any local domain (user), or entire local domains (@mydomain.com). Separate entries with pipes: |.<br />
  For example: jhanna@thisdomain.com|fhanna|@sillyguys.org or place them in a plain ASCII file one address per line.'],
 [DoLDAP,'Do LDAP lookup for valid local addresses',0,checkbox,0,'(.*)',undef,
  'Check local addresses against an LDAP database before accepting the message.<br />
  Note: Checking this requires filling in all the other values below.
  This requires an installed <a href="http://search.cpan.org/~gbarr/perl-ldap-0.31/lib/Net/LDAP.pod" rel="external">NET::LDAP</a> module in PERL.'],
 [LDAPHost,'LDAP Host(s)',60,textinput,'localhost','(\S*)',updateLDAPHost,
  'Enter the DNS-name(s) or IP address(es) of the server(s) that run(s) the LDAP database. For example: localhost. Separate entries with pipes: eg. LDAP-1.domain.com|LDAP-2.domain.com' ],
 [LDAPLogin,'LDAP Login',60,textinput,'','(.*)',undef,
  'Most LDAP servers require a login and password before they allow queries.<br />
  Enter the DN specification for a user with sufficient permissions here.<br />
  For example: cn=Administrator,cn=Users,DC=yourcompany,DC=com'],
 [LDAPPassword,'LDAP Password',20,textinput,'','(.*)',undef,
  'Enter the password for the specified LDAP login here.'],
 [LDAPRoot,'LDAP Root container',60,textinput,'','(.*)',undef,
  'The LDAP lookup will use this container and all sub-containers to match the query.<br />
  For example: DC=yourcompany,DC=com'],
 [LDAPFilter,'LDAP Filter',60,textinput,'','(\S*)',undef,
  'This filter is used to query the LDAP database. This strongly depends on the LDAP structure.<br />
  The filter must return an entry if the recipient address matches with that of any user.<br />
  The literal EMAILADDRESS is replaced by the fully qualified SMTP recipient (eg. user@domain.com) during the search.<br />
  For example: (proxyaddresses=smtp:EMAILADDRESS)'],
 [ValidateLog,'Enable Validation logging',0,checkbox,0,'(.*)',undef,
  'Enables verbose logging of local address validation actions in the maillog. Default is to log validation errors only.
<br /><hr />
  <div class=\"menuLevel1\">Notes On Validate Recipients</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/recipients.txt\',3);">
'],
[0,0,0,'heading','Penalty Box'],
 [DoPenalty,'Penalize Bad IP\'s',1,textinput,0,'(\d*)',undef,
  'If activated, bad behaving IP\'s will be send to the Penalty Box.<br />Entries in <i>Don\'t Delay these IP\'s</i> or <i>ISP/Secondary MX Servers</i> will prevent from penalties. <b>Attention! The Penalty Box should be used very carefully und closely monitored to find the right combination of scores for the installation. Switch it off if you are unsure.</b>.
<span class="negative"> 0 = deactivate, 1 = activate, 2 = logging only, 3 = score only</span>'],

[PenaltyLog,'Enable PB logging',1,textinput,1,'(\d*)',undef,
  'Enables verbose logging of all PB actions in the maillog.<span class="negative"> 0 = no log, 1 = denying, 2 = all.</span>'],
[AddScoringHeader,'Add PB Scoring Header',0,checkbox,1,'(.*)',undef,
  'Adds a line to the email header "X-Assp-PB-Score: " showing the score of the check.'],

[pbdb,'Penalty Box Database',40,textinput,'pb/pbdb','(\S*)',undef,'The directory/file with the penaltybox database files.<b> Do not change this!</b><br /><input type="button" value=" Show Black" onClick="javascript:popFileEditor(\'pb/pbdb.black.db\',2);"><input type="button" value="Show White" onClick="javascript:popFileEditor(\'pb/pbdb.white.db\',2);">'],
[PenaltyUseNetblocks,'Use IP Netblocks',0,checkbox,0,'(.*)',undef,
  'Perform the IP address checks of the sending host based on the /24 subnet  rather than on the specific IP.'],

[PenaltyError,'Penalty Reply',60,textinput,'','(.*)',undef,
  'If set SMTP reply for Penalty Deny. eg: \'554 5.7.1 Error, send your mail to helpdesk@yourdomain.com to ensure delivery\'.'],
[PenaltyDuration,'Collection Interval',4,textinput,60,'(\d?\d?\d?\d?)',updatePenaltyDuration,
"IP\'s will be blocked if their score exceeds the threshhold during this interval (minutes)."],
[PenaltyLimit,'Threshhold',3,textinput,50,'(\d*)',undef,
  'PB will block IP\'s whose score exceeds this threshhold during the Penalty Interval. <br /> <br />Successfull ASSP checks will increase the internal score per IP. If you set the score higher, the threshold will be reached earlier. For example: 50'],
[PenaltyExpiration,'Expiration Time',4,textinput,360,'(\d?\d?\d?\d?)',updatePenaltyExpiration,
"Penalties will expire after this number of minutes. If set to Zero the Penalty DB (black) will be deleted and start from scratch."],

[PenaltyExtreme,'Extreme Threshold',3,textinput,150,'(\d*)',undef,
  'If set PB will deny  SMTP-connections from IP\'s whose score exceed this level. For example: 150'],

[DoExtremeWL,'Whitelisted Denying',0,checkbox,0,'(.*)',undef,
  'Enable Denying for whitelisted addresses.'],
[DoExtremeNP,'NonProcessing Denying',0,checkbox,0,'(.*)',undef,
  'Enable Denying for addresses on the Non-Processing-List.'],
[ExtremeExpiration,'Expiration Time for Extreme Denials',4,textinput,7,'(\d?\d?\d?\d?)',undef,,
"Extreme Penalties will expire after this number of days. For example: 7"],

[exportExtremeFile,'Exported Black Extreme  IP\'s *',40,textinput,'','(\S*)',ConfigMakeRe,
  'IP\'s in black.db which surpassed the extreme level will be regularly stored to this file - if defined. For example: file:pb/exportextreme.txt'],


[baysValencePB,'Bayesian Score',3,textinput,0,'(\d*)',undef,
  ''],

[blValencePB,'Blacklisted Domain Score',3,textinput,5,'(\d*)',undef,
  ''],
[bombValencePB,'Bomb Expression Score',3,textinput,5,'(\d*)',undef,
  ''],

[ihValencePB,'Invalid HELO Score',3,textinput,15,'(\d*)',undef,
  ''],
[fhValencePB,'Forged HELO Score',3,textinput,200,'(\d*)',undef,
  ''],
[hlValencePB,'Blacklisted HELO Score',3,textinput,5,'(\d*)',undef,
  ''],
[flValencePB,'Forged Local Sender Score',3,textinput,10,'(\d*)',undef,
  ''],
[mxValencePB,'Missing MX/A Record Score',3,textinput,10,'(\d*)',undef,
  ''],
[ptValencePB,'Missing PTR Record Score',3,textinput,10,'(\d*)',undef,
  ''],

[saValencePB,'Spam Bucket Address Score',3,textinput,25,'(\d*)',undef,
  ''],
[stValencePB,'Spam Trap Address Score',3,textinput,25,'(\d*)',undef,
  ''],

[rlValencePB,'Failed Relay Attempt Score',3,textinput,15,'(\d*)',undef,
  ''],
[irValencePB,'Invalid Recipient Score',3,textinput,5,'(\d*)',undef,
  ''],
[ilValencePB,'IP Limit Score',3,textinput,25,'(\d*)',undef,
  ''],
[erValencePB,'Empty Recipients Score',3,textinput,5,'(\d*)',undef,
  ''],
[meValencePB,'Max Errors Exceeded Score',3,textinput,15,'(\d*)',undef,
  ''],

[vdValencePB,'Virus Detected Score',3,textinput,5,'(\d*)',undef,
  '
  <br /><hr />
  <div class=\"menuLevel1\">Notes On Penalty Box</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/penaltybox.txt\',3);">
'],

 
[0,0,0,'heading','Validate Sender'],


[ValidateSenderLog,'Enable Validate Sender Logging',0,checkbox,1,'(.*)',undef,
  'Enables verbose logging of all  actions in the maillog.'],
[DoFakedLocalHelo,'Validate Local HELOs',1,textinput,1,'(\d*)',undef,
'If activated, the HELO is checked against Local Domains/Hosts. Even whitelisted and NP-listed addresses will be blocked (and reported) if the check apply. No mail will go into the corpus. If testmode is set here, ccallspam will occur.<br /><span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>.'],
[DoFakedWL,'Skip VLH for Whitelisted',0,checkbox,0,'(.*)',undef,
  'Disable "Validate Local HELOs" for whitelisted addresses. That check is considered a sure bet, but you may decide here to let whitelisted addresses pass.'],
[DoFakedNP,'Skip VLH for NP-listed',0,checkbox,0,'(.*)',undef,
  'Disable "Validate Local HELOs" for addresses on the Non-Processing-List. That check is considered a sure bet, but you may decide here to let NP-listed addresses pass.'],
 [myServerRe,"Secondary Hostnames/IP-Nr(s) of this server: $localhostname ( $localhostaddr ) ",80,textinput,'','(.*)',undef,
  "Validate Helo will check incoming HELOs for this. Put all secondary hostnames and ip-nrs besides $localhostname and $localhostaddr here.<br />
  For example: 213\\.13\\.22\\.3|mail1\\.domain\\.com"],
  
  [DoValidFormatHelo,'Validate Format of HELOs',1,textinput,0,'(\d*)',undef,
  'If activated, the HELO is checked against the expression below.<br />
<span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>'],

 [validFormatHeloRe,'Expression to Validate Format of HELO*',80,textinput,'^(([a-z\d][a-z\d\-]*)?[a-z\d]\.)+[a-z]{2,6}$','(.*)',ConfigCompileRe,
  'Validate Format HELO will check incoming HELOs according to rfc1123. <br />Default:^(([a-z\d][a-z\d\-]*)?[a-z\d]\.)+[a-z]{2,6}$ . '],


  [DoInvalidFormatHelo,'Invalidate Format of HELOs',1,textinput,1,'(\d*)',undef,
  'If activated, the HELO is checked against the expression below.<br />
<span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>'],
 [invalidFormatHeloRe,'Expression to Invalidate Format of HELO*',80,textinput,'^\d+\.\d+\.\d+\.\d+$|^[^\.]+\.?$','(.*)',ConfigCompileRe,
  'Validate Format HELO will check incoming HELOs for this. <br />
  Default: ^\d+\.\d+\.\d+\.\d+$|^[^\.]+\.?$. '],
[heloBlacklistIgnore,'Don\'t block these HELO\'s*',60,textinput,'','(.*)',ConfigMakeRe,
  'HELO / EHLO greetings on this list will be excluded from the HELO checks. For example: host123.isp.com|host456.isp.com'],
 [useHeloBlacklist,'Use the Helo Blacklist',1,textinput,0,'(.*)',undef,
  'Use the list of blacklisted-helo hosts built by rebuildspamdb.<br />
  You probably want to disable the HELO blacklist in the initial training phase for ASSP.<span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>'],

 [DoNoValidLocalSender,'Validate Local Sender Addresses','1',textinput,0,'(\d*)',undef,
'If activated, each sender address with a local domain is checked against Local Addresses and/or LDAP. <br /><span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>.'],
[DoNoSpoofing,'Block All Local Sender Addresses (No Spoofing)',0,checkbox,0,'(.*)',undef,
'If activated, all local sender addresses with a local domain are blocked. '],

 [DoReversed,'Reversed Lookup',1,textinput,'0','(.*)',undef,
  'If activated, each sender IP is checked for a valid PTR record. This requires an installed <a href="http://search.cpan.org/search?query=Net::DNS" rel="external">Net::DNS</a> module in PERL.<br />
<span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>'],
 
 [DoDomainCheck,'Validate Sender Domain MX/A',1,textinput,'0','(.*)',undef,
  'If activated, each sender address is checked for a valid MX/A record.
  This requires an installed <a href="http://search.cpan.org/~maurice/Email-Valid-0.15/Valid.pm" rel="external">Email::Valid</a> module in PERL.<br />
<span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>'],
[SenderInvalidError,'Sender Validation Error',80,textinput,'554 5.7.7 REASON .','(.*)',undef,
  'SMTP error message to reject invalid senders. The literal REASON is replaced by (missing MX,missing PTR,invalid Helo,invalid user) depending on the check.<br /><hr />
  <div class=\"menuLevel1\">Notes On Validate Sender</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/validatesender.txt\',3);">'],
[0,0,0,'heading','Delaying'],
 [EnableDelaying,'Enable Delaying',0,checkbox,0,'(.*)',undef,
  'Enable Greylisting (to avoid name clash let\'s call it Delaying) as described at <a href="http://projects.puremagic.com/greylisting/" rel="external">projects.puremagic.com/greylisting</a>.<br />
  It\'s a new method of blocking significant amounts of spam at the mailserver level, but without resorting to heavyweight <br />
  statistical analysis or other heuristical approaches.'],
 [DelayWL,'Whitelisted Delaying',0,checkbox,0,'(.*)',undef,
  'Enable Delaying for whitelisted users also.'],
 [DelaySL,'Spamlovers Delaying',0,checkbox,0,'(.*)',undef,
  'Enable Delaying for spamlovers also.'],
 [DelayAddHeader,'Add X-Assp-Delayed Header',0,checkbox,1,'(.*)',undef,
  'Add X-Assp-Delayed header to header of all delayed or whitelisted emails.'],
 [DelayLog,'Enable Delaying logging',0,checkbox,0,'(.*)',undef,
  'Enables verbose logging of all Delaying actions in the maillog.'],
 [DelayEmbargoTime,'Embargo Time',5,textinput,5,'(\d+)',undef,
  'Enter the number of minutes for which delivery, related with new \'triplet\' (IP address of the sending<br />
  host + mail from + rcpt to), is refused with a temporary failure. Default is 5 minutes.'],
 [DelayWaitTime,'Wait Time',5,textinput,28,'(\d+)',undef,
  'Enter the number of hours to wait for delivery attempts related with recognised \'triplet\'; delivery is accepted <br />
  immediately and the \'tuplet\' (IP address of the sending host + sender\'s domain) is whitelisted. Default is 28 hours.'],
 [DelayExpiryTime,'Expiry Time',5,textinput,36,'(\d+)',undef,
  'Enter the number of days for which whitelisted \'tuplet\' is considered valid. Default is 36 days.'],
 [DelayUseNetblocks,'Use IP Netblocks',0,checkbox,1,'(.*)',undef,
  'Perform the IP address checks of the sending host based on the /24 subnet it is at rather than the specific IP. <br />
  This feature may be useful for legitimate mail systems that shuffle messages among SMTP clients between retransmissions.'],
 [DelayNormalizeVERPs,'Normalize VERP Addresses',0,checkbox,1,'(.*)',undef,
  'Some mailing lists (such as Ezmlm) try to track bounces to individual mails, rather than just individual recipients, <br />
  which creates a variation on the VERP method where each email has it\'s own unique envelope sender. Since the automatic <br />
  whitelisting that is built into Delaying depends on the envelope addresses for subsequent emails being the same, <br />
  the delay filter will attempt to normalize the unique sender addresses, when this option is checked.'],
 [DelayExpireOnSpam,'Expire Spamming Whitelisted Tuplets',0,checkbox,1,'(.*)',undef,
  'If a whitelisted \'tuplet\' is ever associated with spam, viri, failed rbl, spf etc, it is deleted from the whitelist. <br />
  This renews the temporary embargo for subsequent mail involving the tuplet.'],
 [CleanDelayDBInterval,'Clean Up Delaying Database',10,textinput,3600,'(\d+)',undef,
  'Delete outdated entries from triplets and whitelisted tuplets databases every this many seconds.<br />
  Note: the current timeout must expire before the new setting is loaded, or you can restart.
  Defaults to 1 hour.'],
 [noDelay,'Don\'t Delay these IP\'s*',60,textinput,'file:nodelay.txt','(.*)',ConfigMakeRe,
  'Enter IP addresses that you don\'t want to be delayed, separated by pipes (|). There are misbehaving MTAs that will <br />
  not be able to get a legitimate email through a greylisting server because they do not try again later. An INCOMPLETE <br />
  list of such mailers is available at <a href="http://cvs.puremagic.com/viewcvs/greylisting/schema/whitelist_ip.txt" rel="external">cvs.puremagic.com/viewcvs/greylisting/schema/whitelist_ip.txt</a>. <br />
  When using mentioned list remember to add trailing dots in IP addresses which specify subnets (eg. 192.168 -> 192.168. ).<br />
  For example: 127.0.0.1|192.168.'],
 [DelayError,'Reply Message to Refuse Delayed E<!--get rid of google autofill-->mail',80,textinput,'451 4.7.1 Please try again later','(45\d .*)',undef,
  'SMTP reply message to refuse delayed mail. Default: 451 4.7.1 Please try again later
  <br /><hr />
  <div class=\"menuLevel1\">Notes On Delaying</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/delaying.txt\',3);">
'],

  [0,0,0,'heading','SPF Options'],
 [ValidateSPF,'Enable SPF Validation',0,checkbox,1,'(.*)',undef,
  'Enable Sender Policy Framework Validation as described at <a href="http://spf.pobox.com" rel="external">spf.pobox.com</a>.<br />
  This requires an installed <a href="http://spf.pobox.com/downloads.html" rel="external">Mail::SPF::Query</a> module in PERL.<br />
  Senders that fail SPF validation will receive a 550 5.7.1 [Sender not authorized by domain policy] SMTP error code.<br />
  Note: no error is sent if SPF is in test mode.'],
 [SPFWL,'Whitelisted SPF Validation',0,checkbox,1,'(.*)',undef,
  'Enable Sender Policy Framework Validation for whitelisted users also.'],
  [SPFNP,'Non-Processing SPF Validation',0,checkbox,1,'(.*)',undef,
  'Enable Sender Policy Framework Validation for nonprocessed users also.'],
 [AddSPFHeader,'Add Received-SPF Header',0,checkbox,1,'(.*)',undef,
  'Add Received-SPF header to header of all emails processed by SPF.'],
 [SPFLog,'Enable SPF logging',0,checkbox,0,'(.*)',undef,
  'Enables verbose logging of all SPF checks in the maillog. Default is to log failures only.'],
 [LocalPolicySPF,'Local SPF Policy',60,textinput,'v=spf1 a/24 mx/24 ptr ~all','(.*)',undef,
  'If the sending domain does not publish its own SPF Records a local policy can be defined.<br />
  The default is v=spf1 a/24 mx/24 ptr ~all'],

[DebugSPF,'Enable SPF Debug output to ASSP Logfile',0,checkbox,0,'(.*)',undef,
  'Enables verbose debugging of SPF queries within the Mail::SPF::Query module.
  <br /><hr />
  <div class=\"menuLevel1\">Notes On SPF</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/spf.txt\',3);">
  '],

  [0,0,0,'heading','RBL Options'],
 [ValidateRBL,'Enable Realtime Blacklist Validation',0,checkbox,1,'(.*)',updateRBL,
  'Senders that fail RBL validation will receive a 550 5.7.1 [Sender not authorized by domain policy] SMTP error code.<br />
  Note: no error is sent if RBL is in test mode.'],
 
 [RBLWL,'Whitelisted RBL Validation',0,checkbox,1,'(.*)',undef,
  'Enable RBL for whitelisted users also'],

 [AddRBLHeader,'Add X-Assp-Received-RBL Header',0,checkbox,1,'(.*)',undef,
  'Add X-Assp-Received-RBL header to header of all emails processed by RBL.'],
[RBLError,'RBL Failed Reply',80,textinput,'550 5.7.1 Blacklisted by RBLLISTED','(.*)',undef,
  'SMTP reply for RBL failed messages. Default: \'550 5.7.1 Blacklisted by RBLLISTED\'<br />
 The literal RBLLISTED (case sensitive) is replaced by the actual serviceproviders(s).'],

 [RBLLog,'Enable RBL logging',0,checkbox,0,'(.*)',undef,
  'Enables verbose logging of all RBL checks in the maillog. Default is to log failures only.'],
 [RBLServiceProvider,'RBL Service Providers',60,textinput,'sbl-xbl.spamhaus.org|combined.njabl.org|list.dsbl.org|dul.dnsbl.sorbs.net','(\S*)',updateRBLSP,
  'Domain Names of RBLs to use separated by "|". Defaults are...<br />
  sbl-xbl.spamhaus.org|combined.njabl.org|list.dsbl.org|dul.dnsbl.sorbs.net<br />
  You may add bl.spamcop.net and increase Maxhits to 2. '],
 [RBLmaxreplies,'Maximum Replies',5,textinput,3,'(\d*)',updateRBLMR,'A reply is affirmative or negative reply from a RBL.<br />
  The RBL module will wait for this number of replies (negative or positive) from the RBLs listed under Service Provider for up to the Maximum Time below.<br />
  This number should be equal to or less than the number of RBL Service Providers listed to allow for randomly unavailable RBLs'],
 [RBLmaxhits,'Maximum Hits',5,textinput,1,'(\d*)',updateRBLMH,'A hit is an affirmative response from a RBL.<br />
  The RBL module will check all of the RBLs listed under Service Provider,<br />
  and flag the email with a RBL failure flag if at least this number of RBLS return a positive blacklisted response.<br />
  This number should be less than or equal to Maximum Replies above and greater than 0.<br />
   If the number of hits is greater or equal Maximum Hits, the email is flagged <b>failed</b>.<br /> If the number of hits is greater 0 and less Maximum Hits, the email is flagged <b>neutral</b>'],

 [RBLmaxtime,'Maximum Time',5,textinput,10,'(\d*)',undef,'This sets the maximimum time in seconds to spend on each message performing RBL checks.'],
 [RBLsocktime,'Socket Timeout',5,textinput,1,'(\d*)',undef,'This sets the RBL socket read timeout in seconds.'],
[DoRBLCache,'Cache RBL Hits ',0,checkbox,1,'(.*)',undef,
  'If set, ASSP will remember RBL Hits and block the failed IP\'s as early as possible.<b>This is done if RBLFailLog >= 6 (discard) RBL Testmode or RBL Spamlover will also disable this!</b><input type="button" value=" Show RBL Cache" onClick="javascript:popFileEditor(\'pb/pbdb.rbl.db\',2);">'],
[ForceRBLCache,'Enforce Cache RBL ',0,checkbox,1,'(.*)',undef,
  'If set, ASSP will remember RBL Hits and block the failed IP\'s as early as possible even if RBLFailLog IS NOT >= 6 (discard). RBL Testmode or RBL Spamlover will be ignored.'],
 [RBLUseNetblocks,'Use IP Netblocks in RBL Cache',0,checkbox,1,'(.*)',undef,
  'Perform the IP address checks of the sending host based on the /24 subnet rather than the specific IP.'],
[RBLCacheRefresh,'RBL Cache Refresh Interval',4,textinput,72,'(\d?\d?\d?\d?)',updateRBLCR,
'IP\'s in cache will be removed after this interval(hours).<br /><hr />
  <div class=\"menuLevel1\">Notes On RBL</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/rbl.txt\',3);">'],



  [0,0,0,'heading','SRS Options'],
 [EnableSRS,'Enable Sender Rewriting Scheme',0,checkbox,0,'(.*)',updateSRS,
  'Enable Sender Rewriting Scheme as described at <a href="http://spf.pobox.com/srs.html" rel="external">spf.pobox.com/srs.html</a>.<br />
  This requires an installed <a href="http://spf.pobox.com/downloads.html" rel="external">Mail::SRS</a> module in PERL.<br />
  You should use SRS if your message handling system forwards email for domains with published spf records.<br />
  Note that you have to setup the outgoing path (Relay Host &amp; Port) to let ASSP see and rewrite your outgoing traffic.'],
 [SRSAliasDomain,'Alias Domain',40,textinput,'thisdomain.com','(.*)',updateSRSAD,
  'SPF requires the SMTP client IP to match the envelope sender (return-path). When a message is forwarded through<br />
  an intermediate server, that intermediate server may need to rewrite the return-path to remain SPF compliant.<br />
  For example: thisdomain.com'],
 [SRSSecretKey,'Secret Key',20,passinput,'','(.*)',updateSRSSK,
  'A key for the cryptographic algorithms -- Must be at least 5 characters long.'],
 [SRSTimestampMaxAge,'Maximum Timestamp Age',5,textinput,21,'(\d+)',undef,
  'Enter the maximum number of days for which a timestamp is considered valid. Default is 21 days.'],
 [SRSHashLength,'Hash Length',5,textinput,4,'(\d+)',undef,
  'The number of bytes of base64 encoded data to use for the cryptographic hash.<br />
  More is better, but makes for longer addresses which might exceed the 64 character length suggested by RFC2821.<br />
  This defaults to 4, which gives 4 x 6 = 24 bits of cryptographic information, which means that a spammer will have <br />
  to make 2^24 attempts to guarantee forging an SRS address.'],
 [SRSValidateBounce,'Enable Bounce Recipient Validation',0,checkbox,1,'(.*)',undef,
  'Bounce messages that fail reverse SRS validation (but not a valid SMTP probes)<br />
  will receive a 550 5.7.5 [Bounce address not SRS signed] SMTP error code.'],
 [noSRS,'Don\'t Validate Bounces From these IP\'s*',60,textinput,'','(.*)',ConfigMakeRe,
  'Enter IP addresses that you don\'t want to validate bounces from, separated by pipes (|).<br />
  For example: 127.0.0.1|192.168.<br /><hr />
  <div class=\"menuLevel1\">Notes On SRS</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/srs.txt\',3);">
'],

[0,0,0,'heading','Virus Control'],
 [BlockExes,'External Attachment Blocking',1,textinput,0,'(\d*)',undef,
  'Enter a number from 0-3 to determine which level of attachment protection to provide for external mail.<br />
  Enter 0 or leave blank for no attachment blocking.'],
 [BlockWLExes,'Whitelisted &amp; Local Attachment Blocking',1,textinput,0,'(\d*)',undef,
  'Enter a number from 0-3 to determine which level of attachment protection for whitelisted &amp; local senders.'],
 [BlockNPExes,'NoProcessing Attachment Blocking',1,textinput,0,'(\d*)',undef,
  'Enter a number from 0-3 to determine which level of attachment protection for no processing senders.'],
 [BadAttachL1,'Level 1 Blocked File Extensions',60,textinput,'exe|scr|pif|vb[es]|js|jse|ws[fh]|sh[sb]|lnk|bat|cmd|com|ht[ab]','(.*)',updateBadAttachL1,
  'This regular expression is used to identify Level 1 attachments that should be blocked.<br />
  Separate entries with a pipe |. The dot . is assumed to precede these, so don\'t include it. For example:<br />
  ad[ep]|asx|ba[st]|chm|cmd|com|cpl|crt|dbx|exe|hlp|ht[ab]|in[fs]|isp|js|jse|lnk|md[abez]|mht|ms[cipt]|nch|pcd|pif|prf|reg|sc[frt]|sh[bs]|vb|vb[es]|wms|ws[cfh]'],
 [BadAttachL2,'Level 2 Blocked File Extensions',60,textinput,'','(.*)',updateBadAttachL2,
  'This regular expression is used to identify Level 2 attachments that should be blocked.<br />
  Level 2 already includes all blocked extensions from Level 1. For example:<br />
 (ad[ep]|asx|ba[st]|chm|cmd|com|cpl|crt|dbx|exe|hlp|ht[ab]|in[fs]|isp|js|jse|lnk|md[abez]|mht|ms[cipt]|nch|pcd|pif|prf|reg|sc[frt]|sh[bs]|vb|vb[es]|wms|ws[cfh]).zip'],
 [BadAttachL3,'Level 3 Blocked File Extensions',60,textinput,'zip','(.*)',updateBadAttachL3,
  'This regular expression is used to identify Level 3 attachments that should be blocked.<br />
  Level 3 includes Level 2 and Level 1. For example: zip|url'],
 [AttachmentError,'Attachment Error',80,textinput,'500 These attachments are not allowed -- Compress before mailing.','(5\d\d .*)',undef,
  'SMTP error message to reject attachments.'],
 [AvPath,'Path to Anti-virus Databases',40,textinput,'','(.*)',undef,
  'The directory path to your anti-virus databases, uses ASSP\'s base if left blank. For example: /usr/share/clamav/db'],
 [AvDbs,'List of Anti-virus Signature Database Files',40,textinput,'main.db,daily.db','(.*)',undef,
  'A comma (no space!) separated list of virus signature files. Blank this out to disable virus scanning.<br />
  For example: main.db,daily.db. These files are available on http://assp.sourceforge.net<br />
  NOTE: Changing this field requires restarting ASSP before changes take effect.'],
 [AvError,'Error Message to Reject Infected E<!--get rid of google autofill-->mail',80,textinput,'500 Mail appears infected with \'$infection\' -- disinfect and resend.','(5\d\d .*)',undef,
  'SMTP error message to reject infected mail. The string $infection is replaced with the name of the detected virus.<br />
  For example: 500 Mail appears infected with \'$infection\' -- disinfect and resend.'],
 [Avlocal,'Virus Scan Local',0,checkbox,1,'(.*)',undef,
  'Check this box to scan local users email as well.'],
 [AVBytes,'AV Bytes',10,textinput,100000,'(\d*)',undef,
  'How many bytes of the message will be Virus scanned? For example: 100000<br />
  Leave Blank to scan entire email which results in a significant performance penalty on large attachments.<br />
  Most virus signatures match in the first 20-100K of the message.<br /><hr />
  <div class=\"menuLevel1\">Notes On Virus Control</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/viruscontrol.txt\',3);">
 '],
 
[0,0,0,'heading','Spam Bombs &amp; Scripting'],
 [DoBombRe,'Use Bomb Regular Expressions','1',textinput,1,'(\d*)',undef,
'If activated, each each message is checked  against the Bomb Regular Expression. Whitelisted and NP-listed messages will not be checked besides the header.<br /><span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>.'],
[bombRe,'Expression to Identify Spam *',80,textinput,'','(.*)',ConfigCompileRe,
  'Header and Data will be checked against the Regex'],
[bombReWL,'Do Bomb Check Whitelisted',0,checkbox,0,'(.*)',undef,''],
[bombReNP,'Do Bomb Check for NP-Listed',0,checkbox,0,'(.*)',undef,''],
[bombReRelay,'Do Bomb Check for Local Mails',0,checkbox,0,'(.*)',undef,''],
[testRe,'Expressions to Test*',80,textinput,'','(.*)',ConfigCompileRe,
  'Use this for testing purposes. Logging is alway verbose, no action taken.'],
[bombError,'Spam Bomb Error',80,textinput,'550 Your message was rejected because it appears to be part of a spam bomb -- .','(.*)',undef,
  'SMTP error message to reject spam bombs.'],

[bombErrorReason,'Reason will be added',0,checkbox,1,'(.*)',undef,
  'Check this box to add the triggering expression to Spam Bomb Error.'],

 [DoScriptRe,'Use Script Regular Expressions','1',textinput,1,'(\d*)',undef,
'If activated, each each message is checked  against the Script Regular Expression.<br /><span class="negative"> 0 = deactivate, 1 = activate, 2 = log only, 3 = score only.</span>.'],
 [scriptRe,'Expression to Identify Mobile Scripts*',80,textinput,'','(.*)',ConfigCompileRe,
  'Spam emails may contain mobile scripting code, eg activex and java. You can use this feature to block those messages.<br />
  Leave this blank to disable the feature. For example:<br /> \&lt;applet|\&lt;embed|\&lt;iframe|\&lt;object|\&lt;script|onmouseover|javascript:'],
 [scriptError,'Script Error',80,textinput,'550 Your email contains html scripting code -- please resend as plain text.','(.*)',undef,
  'SMTP error message to reject scripts.
  <br /><hr />
  <div class=\"menuLevel1\">Notes On Bomb Regex</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/bombre.txt\',3);">'],


[0,0,0,'heading','TestMode Options'],
 [spamSubject,'Prepend Spam Subject',20,textinput,'','(.*)',undef,
  'If TestMode or Spamlover and message is spam this gets prepended to the subject of the email. For example; [SPAM]'],

 [baysTestMode,'Bayesian Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [blTestMode,'Blacklist Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [hlTestMode,'Helo-Blacklist Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [sbTestMode,'Spam Address Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [spfTestMode,'SPF Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [rblTestMode,'RBL Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [srsTestMode,'SRS Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [bombTestMode,'Bomb Regex Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [scriptTestMode,'Script Regex Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [mxaTestMode,'Missing MX/A Record Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [ptrTestMode,'Reversed Lookup Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [ihTestMode,'Invalid Helo Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [fhTestMode,'Forged Local Helo Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
  [flsTestMode,'Forged Local Sender Test Mode',0,checkbox,0,'(.*)',undef,
  ''],
 [pbTestMode,'Penalty Box Test Mode',0,checkbox,0,'(.*)',undef,
  '',],

 

[0,0,0,'heading','Send All SPAM/HAM '],
[sendAllSpam,'Address to CC All Spam',20,textinput,'','(.*)',undef,
  'If you put an email address in this box  ASSP will try to deliver a copy of all spam email to this address.<br />
For example: spammeister@mydomain.com'],
  [ccAddressesMode,'CC Select Mode',0,checkbox,0,'(.*)',undef,
  'If set CC-all-Spam will work for selected recipients only .<br />
  Accepts specific addresses (user@domain.com), user parts (user) or entire local domains (@domain.com).'],
[ccAddresses,'CC for this recipients only',40,textinput,'','(.*)',ConfigMakeRe,
  'Restricts CC all Spam to this recipients. <br />'],
[spamSubjectCC,'Prepend Spam Subject to CC-mail',0,checkbox,1,'(.*)',undef,
  'If set  spamSubject gets prepended to the subject of the CC-email.
 '],
 [sendHamRec,'Address to CC Ham for selected RECIPIENTS',20,textinput,'','(.*)',undef,
  'If you put an email address in this box  ASSP will try to forward a copy of all notspam email for selected RECIPIENTS to this address. Nonprocessing Messages will not be copied.<br />
For example: archiv@mydomain.com'],
  [ccArchivModeRec,'Activate CC Ham ',0,checkbox,1,'(.*)',undef,
  ''],
[ccArchivAddressesRec,'CC for this recipients',40,textinput,'','(.*)',ConfigMakeRe,
  'CC  HAM to these recipients. Accepts specific addresses (user@domain.com), user parts (user) or entire local domains (@domain.com). <br /><hr />
  <div class=\"menuLevel1\">Notes On Send All HAM/SPAM</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/SendAllHAMSPAM.txt\',3);">'],
  

[0,0,0,'heading','Email Interface'],
 [EmailInterfaceOk,'Enable Email Interface',0,checkbox,1,'(.*)',undef,
  'Checked means that you want to ASSP to intercept and parse mail to the following usernames at any localdomains.<br />
  If you are using RelayHost and RelayPort see
  <a href="http://assp.sourceforge.net/fom/cache/45.html" rel="external">this note</a>.'],
  
  [EmailAdminReportsTo,'Admin Mail Address',40,textinput,'','(.+)',undef,
  'If set internal warnings/infos  will be sent to this address. For example: admin@domain.com'],

 [EmailSpam,'Report Spam Address',20,textinput,'asspspam','(.*)',undef,
  'Any mail sent by local/authenticated users to this username will be interpreted as a spam report.<br />
  No mail is delivered! For example: asspspam
  <input type="button" value=" Edit spamreport.txt file" onClick="javascript:popFileEditor(\'spamreport.txt\',2);">'],

 [EmailHam,'Report not-Spam Address',20,textinput,'asspnotspam','(.*)',undef,
  'Any mail sent by local/authenticated users to this username will be interpreted as a false-positive report.<br />
  No mail is delivered! For example: asspnotspam
  <input type="button" value=" Edit notspamreport.txt file" onClick="javascript:popFileEditor(\'notspamreport.txt\',2);">'],
[EmailErrorsReply,'Reply to Spam/Not-Spam Reports',1,textinput,1,'(\d*)',undef,
  '<span class="negative"> 0 = no report, 1 = to user, 2 = to TO address, 3 = both</span>'],
[EmailErrorsTo,'TO Address for Spam/Ham-Reports',40,textinput,'','(.+)',undef,
  'Email sent from ASSP acknowledging your submissions will be sent to this address. For example: admin@domain.com<br />
  '],
  
[EmailNoWhiteToRed,'Suppress automatic adding to redlist ',0,checkbox,'1','(.*)',undef,
  'If set Removals from Whitelist will not automatically be added to the Redlist'],

[EmailErrorsModifyWhite,'Spam/Ham Report & Whitelist Add/Remove',0,checkbox,'','(.*)',undef,
  'If set Ham Reports will add addresses to the Whitelist, Spam Reports will remove from the Whitelist.'],
 [EmailWhitelistAdd,'Add to Whitelist Address',20,textinput,'asspwhite','(.*)',undef,
  'Any mail sent by local/authenticated users to this username will be interpreted as a request to add addresses to the whitelist.For example: asspwhite.<br />
<input type="button" value=" Edit whitereport.txt file" onClick="javascript:popFileEditor(\'whitereport.txt\',2);">'],

 [EmailWhitelistRemove,'Remove from Whitelist Address',20,textinput,'asspnotwhite','(.*)',undef,
  'Any mail sent by local/authenticated users to this username will be interpreted as a request to remove addresses from the whitelist.For example: asspnotwhite<br />
<input type="button" value=" Edit whiteremovereport.txt file" onClick="javascript:popFileEditor(\'whiteremovereport.txt\',2);">'],
[EmailNoNPRemove,'Suppress automatic removing from NP-List ',0,checkbox,'1','(.*)',undef,
  'If set removals from NonProcessing-list will not be done automatically. If not set WhiteRemove Email looks for entries in the NP-List and removes them'],
[EmailWhitelistReply,'Reply to Add to/Remove from Whitelist',1,textinput,1,'(\d*)',undef,
  '<span class="negative"> 0 = no report, 1 = to user, 2 = to TO address, 3 = both</span>'],

[EmailWhitelistTo,'To Address for Whitelist-Reports',40,textinput,'','(.+)',undef,
  'Email sent from ASSP acknowledging your submissions will be sent to this address. For example: admin@domain.com'],
 [EmailRedlistAdd,'Add to Redlist Address',20,textinput,'asspred','(.*)',undef,
  'Any mail sent by local/authenticated users to this username will be interpreted as a request to add addresses to the redlist.For example: asspred.<br />
<input type="button" value=" Edit redreport.txt file" onClick="javascript:popFileEditor(\'redreport.txt\',2);">'],

 [EmailRedlistRemove,'Remove from Redlist Address',20,textinput,'asspnotred','(.*)',undef,
  'Any mail sent by local/authenticated users to this username will be interpreted as a request to remove addresses from the redlist.<br />
  No mail is delivered! For example: asspnotred
  <input type="button" value=" Edit redremovereport.txt file" onClick="javascript:popFileEditor(\'redremovereport.txt\',2);">'],

[EmailRedlistReply,'Reply to Add to/Remove from Redlist',1,textinput,1,'(\d*)',undef,
  '<span class="negative"> 0 = no report, 1 = to user, 2 = to TO address, 3 = both</span>'],
[EmailRedlistTo,'To Address for Redlist-Reports',40,textinput,'','(.+)',undef,
  'Email sent from ASSP acknowledging your submissions will be sent to this address. For example: admin@domain.com'],
 [EmailFrom,'From Address for Reports',40,textinput,'<postmaster@yourdomain.com>','(.+)',undef,
  'Email sent from ASSP acknowledging your submissions will be sent from this address.<br />
  Some mailers don\'t like the default setting. For example: ASSP &lt;&gt; or Mail Administrator
  &lt;mailadmin@mydomain.com&gt;
'],
 [NoHaiku,'Don\'t reply to messages to the Email Interface',0,checkbox,0,'(.*)',undef,
  'Check this option to suppress email reports for spam and not-spam reports, whitelist and redlist additions/deletions via the email interface (legacy). <br /><hr />
  <div class=\"menuLevel1\">Notes On Email Interface</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/emailinterface.txt\',3);">'],
  


[0,0,0,'heading','File Paths'],
 ['base','Directory Base',40,textinput,'.','',undef,'All paths are relative to this folder.<br />
 <b>Note: this must be changed as a command line parameter and is displayed here for reference only.</b>'],
 [spamlog,'Spam Collection',40,textinput,'spam','(\S+)',undef,'The folder to save the collection of spam emails. For example: spam'],
 [notspamlog,'Not-spam Collection',40,textinput,'notspam','(\S+)',undef,'The folder to save the collection of not-spam emails. For example: notspam'],
 [incomingOkMail,'External OK mail',40,textinput,'','(.*)',undef,'The folder to save Bayesian non-spam (message ok).
 Leave this blank to not save these files (default).<br />
 If you want to keep copies of OK mail then put in a directory name. Note: you must create the directory. For example: okmail'],
 [viruslog,'Virus Collection',40,textinput,'','(.*)',undef,
'The folder to save virii, blocked attachments and scripting/bombing. Leave this blank to not save these files (default).<br />
 If you want to keep copies of blocked content then put in a directory name. Note: you must create the directory. For example: virii'],
 [correctedspam,'False-negative Collection',40,textinput,'errors/spam','(\S+)',undef,
'Spam that got through -- counts double. For example: errors/spam'],
 [correctednotspam,'False-positive Collection',40,textinput,'errors/notspam','(\S+)',undef,
'Good mail that was listed as spam, count 4x. For example: errors/notspam'],
 [maillogExt,'Extension for Mail Files',20,textinput,'.eml','(\S*)',undef,
'Enter the file extension (include the period) you want appended to the mail files in the mail collections.<br />
 Leave it blank for no extension. For Example: .eml'],
 [spamdb,'Spam Bayesian Database File',40,textinput,'spamdb','(\S+)',undef,'The output file from rebuildspamdb.pl.'],
 [whitelistdb,'E<!--get rid of google autofill-->mail Whitelist Database File',40,textinput,'whitelist','(\S+)',undef,'The file with the whitelist.'],
 [redlistdb,'E<!--get rid of google autofill-->mail Redlist Database File',40,textinput,'redlist','(\S+)',undef,'The file with the redlist.'],
 [dnsbl,'DNS Blacklist Database File',40,textinput,'','(\S*)',undef,'The file with the current DNSBL -- make this blank if you don\'t use it.'],
 [greylist,'Greylist Database',40,textinput,'greylist','(\S*)',undef,'The file with the current greylist database -- make this blank if you don\'t use it.'],
 [delaydb,'Delaying Database',40,textinput,'delaydb','(\S*)',undef,'The file with the delay database.'],

 [logfile,'ASSP Logfile',40,textinput,'maillog.txt','(\S*)',ConfigChangeLogfile,
'Blank if you don\'t want a log file. Change it to maillog.log if you don\'t want auto rollover.
NOTE: Changing this field requires restarting ASSP before changes take effect.'],
 [pidfile,'PID File',40,textinput,'pid','(\S*)',undef,'Blank to skip writing a pid file. *nix users need pid files.
 Leave it blank in Windows.<br /> You have to restart the service before you get a pid file in the new location.<br /><hr />
  <div class=\"menuLevel1\">Notes On File Path</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/filepath.txt\',3);">
 '],

[0,0,0,'heading','Logging'],
 [silent,'Silent Mode',0,checkbox,0,'(.*)',undef,
  'Checked means don\'t print log messages to the console. AsADaemon overrides this.'],
[asspLog,'ASSP local logging',0,checkbox,'1','(.*)',undef,'ASSP manages local logging. The logs are stored inside the directory where ASSP is installed.'],
[sysLog,'SYSLOG Centralized Logging',0,checkbox,0,'(.*)',undef,'Enables logging to Syslog. Needs Sys::Syslog.'],
[fileLogging,'File name logging',0,checkbox,1,'(.*)',undef,'Show file names in log '],
[MaintenanceLog,'Enable Maintenance logging',0,checkbox,0,'(.*)',undef,
  'Enables verbose logging of all maintenance actions (whitelist saving, delaying databases cleaning,<br />
   stats uploading, greylist freshening) in the maillog.'],
[RegExLength,'RegEx Length in Log',2,textinput,20,'(\d*)',undef,
  'Defines how many bytes of a matching Regex will be shown in the log<br /> 
  Some matching expression are too long for one line. Default: 20'],
[MaillogTailBytes,'Maillog Tail Bytes',10,textinput,10000,'(\d+)',undef,
  'How many bytes of the maillog will be shown in a tail window? Default: 10000.'],
[MaillogTailWrapColumn,'Maillog Tail Wrap Column',5,textinput,80,'(\d+)',undef,
  'Wrap the maillog tail window text at a specific column. Enter 0 for no wrapping.'],
[DEBUG,'Debug Mode',0,checkbox,0,'(.*)',ConfigDEBUG,
  'Checked sends debugging info to a .dbg file.
 Leave this unchecked unless there is a program error you are trying to track down.'],
 [sendNoopInfo,'Send NOOP Info',0,checkbox,0,'(.*)',undef,
  'Checked means you want ASSP to send a "NOOP Connection from $ip" message to your SMTP server. (Postfix croaks on this.)'],
 [wlAttachLog,'Whitelisted Blocked Attachments',1,textinput,5,'(\d*)',undef,
'Where to store Whitelisted blocked attachments. Recommended : 5 <br /><span class="negative"> 2 = notspam folder, 3 = spamfolder, 4 = mailok folder, 5 = virii folder, 6 = discard, 7 = discard \& ccallspam.</span><br />'],
 [npAttachLog,'No Processing Blocked Attachments',1,textinput,5,'(\d*)',undef,'Where to store external blocked attachments. Recommended: 5'],
 [extAttachLog,'External Blocked Attachments',1,textinput,5,'(\d*)',undef,'Where to store external blocked attachments. Recommended: 5'],
 [spamBombLog,'Spam Bombs',1,textinput,6,'(\d*)',undef,'Where to store spam bombs. Recommended: 6'],
 [scriptLog,'Scripts',1,textinput,3,'(\d*)',undef,'Where to store scripted emails. Recommended: 3'],
 [baysNonSpamLog,'Bayesian Non Spam',1,textinput,4,'(\d*)',undef,'Where to store Bayesian non spam (message ok) emails. '],
 [blDomainLog,'Blacklisted Domains',1,textinput,3,'(\d*)',undef,'Where to store blacklisted domain emails. Recommended: 3'],
 [spamHeloLog,'Spam Helos',1,textinput,6,'(\d*)',undef,'Where to store spam helo emails. Recommended: 6'],
 [spamBucketLog,'Spam Addresses',1,textinput,3,'(\d*)',undef,'Where to store has spam address emails. Recommended: 3'],
 [baysSpamLog,'Bayesian Spams',1,textinput,3,'(\d*)',undef,'Where to store Bayesian spam emails. Recommended: 3'],
 [SPFFailLog,'SPF Failures',1,textinput,3,'(\d*)',undef,'Where to store SPF Failure spam emails. Recommended: 3'],
 [RBLFailLog,'RBL Failures',1,textinput,3,'(\d*)',undef,'Where to store RBL Failure spam emails. Recommended: 3'],
 [SRSFailLog,'SRS Failures',1,textinput,3,'(\d*)',undef,'Where to store SRS Failure (not signed bounces) spam emails. Recommended: 3'],
 [spamISLog,'Invalid Sender Failures',1,textinput,6,'(\d*)',undef,'Where to store Invalid Sender blocked emails. Recommended: 6'],
 [spamPBLog,'PB Blocks',1,textinput,6,'(\d*)',undef,'Where to store PB blocked emails. Recommended: 6'],
 [freqNonSpam,'Non Spam Log Frequency',5,textinput,1,'(\d*)',updateLog2,'Store every n\'th non spam message.
eg. If you set the value to 10 then every 10th message is logged.<br />
These frequency settings are for ASSP users with a mature installation who experience heavy mail or spam volumes.<br />
Enter a larger value if the non spam corpus is being refreshed too quickly. Default Value = 1, log every message.'],
 [freqSpam,'Spam Log Frequency',5,textinput,1,'(\d*)',updateLog3,'Store every n\'th spam message.
The same as for non spam but helps prevent spam corpuses being skewed by flooding.<br />
It is recommended that this be set depending on spam volume. Default value = 1, log every message.'],
 [noLog,'Don\'t Log these IP\'s*',60,textinput,'','(\S*)',ConfigMakeRe,
  'Enter IP addresses that you don\'t want to be logged, separated by pipes (|).<br />
  This can be IP address of the SMTP service monitoring agent. For example: 127.0.0.1|10.'],
[MaillogTailJump,'Jump to the End of the Maillog',0,checkbox,0,'(.*)',undef,
  'Enable jumping to the end of the Maillog. The browser window will hyperlink to the bottom of the Maillog instead of sitting at the top of the display.'],
 [LogRollDays,'Roll the Logfile How Often?',5,textinput,'7','([\d\.]+)',undef,
'ASSP closes and renames the log file after this number of days.<br /><hr />
  <div class=\"menuLevel1\">Notes On Logging</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/logging.txt\',3);">
  '],

[0,0,0,'heading','Security'],
 [runAsUser,'Run as UID',20,textinput,'nobody','(\S*)',undef,
  'The *nix user name to assume after startup: assp or nobody -- requires ASSP restart.'],
 [runAsGroup,'Run as GID',20,textinput,'nobody','(\S*)',undef,
  'The *nix group to assume after startup: assp or nogroup -- requires ASSP restart.'],
 [ChangeRoot,'Change Root',40,textinput,'','(.*)',undef,
  'Non-blank means to run in chroot jail in *nix. You need an etc/protocols file to make this work<br />
  Copy or link the file to your new root directory -- requires ASSP restart.'],

 # I hate password input, but if you like it, uncomment this line and comment the next one. -- just quit bugging me about it!
 [webAdminPassword,'Web Admin Password',20,passinput,'nospam4me','(.{5,})',undef,
 #[webAdminPassword,'Web Admin Password',20,textinput,'nospam4me','(.{5,})',undef,
  'This is your password for the administrative interface -- Must be at least 5 characters long.'],
[denySMTPConnectionsFrom,'Deny SMTP Connections From these IP\'s*',40,textinput,'','(\S*)',ConfigMakeRe,
  'Manually maintained list of IP\'s which should be denied access.'],
[denySMTPnoLog,'Suppress Logging by \'Deny SMTP Connections From\'',0,checkbox,0,'(.*)',undef,
  ''],
 [allowAdminConnectionsFrom,'Allow Admin Connections From*',60,textinput,'','(.*)',ConfigMakeRe,
  'This is an optional list of IP addresses from which you will accept web admin connections, separated by pipes (|).<br />
  For example: 127.0.0.1|10. Blank means accept all connections. 127.0.0.1 means accept connections from the localhost.<br />
  Note that IP source addresses are very easy to spoof, so this should not be considered as a security feature.<br />
  <span class="negative">If you make a mistake here you will disable your web admin interface and have to manually edit your configuration file to fix it.</span><br /><hr />
  <div class=\"menuLevel1\">Notes On Security</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'security/spf.txt\',3);">
'],

[0,0,0,'heading','Other Settings'],
 [MaxFiles,'Max Files',10,textinput,14009,'(\d+)',undef,
  'If you\'re not using subjects as file names, this is the maximum
 number of files to keep in each collection (spam &amp; nonspam)<br />
 It\'s actually less than this -- files get a random number between 1 and $MaxFiles.'],
 [MaxBytes,'Max Bytes',10,textinput,8000,'(\d+)',undef,
  'How many bytes of the message will ASSP look at? For example: 20000'],
 [RamSaver,'Use less RAM to rebuild the spamdb',0,checkbox,0,'(.*)',undef,
  'Checking this slows down your rebuildspamdb process, but will do so with less ram.'],
 [OutgoingBufSize,'Size of TCP/IP Buffer',10,textinput,102400,'(\d+)',undef,
  'If ASSP talks to the internet over a modem change this to 4096, 102400 is the default.
  For example: 102400'],
 [OrderedTieHashSize,'Ordered-Tie hash table size',10,textinput,5000,'(\d+)',undef,
  'Tunable value of the size of the hash tables used by both ASSP and rebuildspamdb.pl (default = 5000).<br />
 Larger numbers mean more RAM, fewer disk hits. Adjust down to use less RAM.'],
 [MaxErrors,'Max Errors',5,textinput,'10','(\d+)',undef,
  'If the smtp destination sends $MaxErrors 501s, 502s, 503s... the connection is dropped.'],
 [RestartEvery,'Restart Every',10,textinput,'0','(\d+)',undef,
  'Program terminates after this many seconds, this is really only useful if ASSP runs as a service or in a script that restarts<br />
  it after it stops. Note: the current timeout must expire before the new setting is loaded.'],

 [totalizeSpamStats,'Upload Consolidated Spam Statistics',0,checkbox,1,'(.*)',undef,
  'Checked means your ASSP will upload its totalled statistics to the <a href="http://assp.sourceforge.net/cgi-bin/total.pl" rel="external">ASSP web site totals</a>.<br />
  This is a great marketing tool for the ASSP project; please don\'t disable it unless you\'ve got
  a good reason to.<br /> No private information is being disclosed by this upload.'],

 [EnableHTTPCompression,'Enable HTTP Compression for Web Admin interface',0,checkbox,1,'(.*)',undef,
  'Enable HTTP Compression for faster Web Admin interface loading.<br />
  This requires an installed <a href="http://search.cpan.org/dist/Compress-Zlib/" rel="external">Compress::Zlib</a> module in PERL.'],
 [EnableFloatingMenu,'Enable floating of Menu Panel for Web Admin Interface',0,checkbox,1,'(.*)',undef,
  'Enable floating of menu panel for Web Admin interface. Floating Div code taken from <a href="http://www.javascript-fx.com" rel="external">www.javascript-fx.com</a> site.'],

[UseLocalTime,'Use Local Time',0,checkbox,1,'(.*)',undef,
  'Use local time and timezone offset rather than UTC time in the mail headers.<br /><hr />
  <div class=\"menuLevel1\">Notes On Other Settings</div>
  <input type="button" value="Notes" onClick="javascript:popFileEditor(\'notes/othersettings.txt\',3);">
'],
 );

 $MakeRE{ispip}=\&setISPRE;
 $MakeRE{allowAdminConnectionsFrom}=\&setACFRE;
 $MakeRE{acceptAllMail}=\&setAMRE;
 $MakeRE{localDomains}=\&setLDRE;
 $MakeRE{spamaddresses}=\&setSARE;
 $MakeRE{spamtrapaddresses}=\&setSTRE;
 $MakeRE{noProcessing}=\&setNPREL;
 $MakeRE{ccAddresses}=\&setCCRE;
 $MakeRE{ccArchivAddressesRec}=\&setCCARRE;
 $MakeRE{whiteListedDomains}=\&setWLDRE;
 $MakeRE{blackListedDomains}=\&setBLDRE;
 $MakeRE{heloBlacklistIgnore}=\&setHBIRE;
 $MakeRE{spamLovers}=\&setSLRE;
 $MakeRE{baysSpamLovers}=\&setBSLRE;
 $MakeRE{blSpamLovers}=\&setBLSLRE;
 $MakeRE{hlSpamLovers}=\&setHLSLRE;
 $MakeRE{spfSpamLovers}=\&setSPFSLRE;
 $MakeRE{rblSpamLovers}=\&setRBLSLRE;
 $MakeRE{srsSpamLovers}=\&setSRSSLRE;
 $MakeRE{delaySpamLovers}=\&setDLSLRE;
 $MakeRE{pbSpamLovers}=\&setPBSLRE;
 $MakeRE{isSpamLovers}=\&setISSLRE;
 $MakeRE{LocalAddresses_Flat}=\&setLAFRE;
 $MakeRE{BounceSenders}=\&setBSRE;
 $MakeRE{noLog}=\&setNLOGRE;
 $MakeRE{noDelay}=\&setNDRE;
 $MakeRE{noSRS}=\&setNSRSRE;
 $MakeRE{denySMTPConnectionsFrom}=\&setDSMTPCFRE;
 $MakeRE{exportExtremeFile}=\&setEXEXRE;
 # allow override for default web admin port
 if($ARGV[1]=~/^\d+$/) {
  foreach (@Config) {
   if($_->[0] eq 'webAdminPort' ) {
    $_->[4]=$ARGV[1];
    last;
   }
  }
 }
 # load configuration file
 open(F,"<$base/assp.cfg"); local $/; (%Config)=split(/:=|\n/,<F>); close F;
 # set nonexistent settings to default values
 foreach $c (@Config) {
  if ($c->[0] && !(exists $Config{$c->[0]})) {
   $Config{$c->[0]}=$c->[4];
  }
 }
 fixConfigSettings();
 $SIG{HUP}=\&reloadConfigFile;
 $SIG{PIPE} = "IGNORE";
}

renderConfigHTML();
sub renderConfigHTML {
if ($MaillogTailJump) {
 $maillogEnd = '#End';
 $maillogJump = '<a href="#Top">Go to Top</a><a name="End">';
}
$noDelayFile=$noDelay;
 $plusIcon = "get?file=images/plusIcon.png";
 
 $minusIcon = "get?file=images/minusIcon.png";
 $noIcon = "get?file=images/noIcon.png";
 $NavMenu = '
<a href="lists"><img src="' . $noIcon . '" alt="noicon" /> <b>Whitelist/Redlist</b></a><br />
  <a href="maillog#End"><img src="' . $noIcon . '" alt="noicon" /> <b>Maillog Tail</b></a><br />
  <a href="analyze"><img src="' . $noIcon . '" alt="noicon" /> <b>Mail Analyzer</b></a><br />
  <a href="infostats"><img src="' . $noIcon . '" alt="noicon" /> <b>Info and Stats</b></a><br />
  <a href="shutdown_list" target="_blank"><img src="' . $noIcon . '" alt="noicon" /> <b>SMTP Connections</b></a><br />
  <a href="shutdown"><img src="' . $noIcon . '" alt="noicon" /> <b>Shutdown/Restart</b></a><br />
  <a href="donations"><img src="' . $noIcon . '" alt="noicon" /> <b>Donations</b></a><br />';
 $JavaScript = "
<script type=\"text/javascript\">
<!--
function toggleDisp(nodeid)
{
  if(nodeid.substr(0,9) == 'setupItem')
    nodeid = nodeid.substr(9);
  layer = document.getElementById('treeElement' + nodeid);
  img = document.getElementById('treeIcon' + nodeid);
  if(layer.style.display == 'none')
  {
    layer.style.display = 'block';
    img.src = '$minusIcon';
    if(document.getElementById('setupItem' + nodeid))
      document.getElementById('setupItem' + nodeid).style.display = 'block';
  }
  else
  {
    layer.style.display = 'none';
    img.src = '$plusIcon';
    if(document.getElementById('setupItem' + nodeid))
      document.getElementById('setupItem' + nodeid).style.display = 'none';
  }
}
function expand(expand, force)
{
  counter = 0;
  while(document.getElementById('treeElement' + counter))
  {
    if(!expand)
    {
      //dont shrink if this element is the one passed in the URL
      arr = document.getElementById('treeElement' + counter).getElementsByTagName('a');
      txt = ''; found = 0;
      loc = new String(document.location);
      for(i=0; i < arr.length; i++)
      {
        txt = txt + arr.item(i).href;
        tmpHref = new String(arr.item(i).href);
        if(tmpHref.substr(tmpHref.indexOf('#')) == loc.substr(loc.indexOf('#')))
        {
          //give this tree node the right icon
          document.getElementById('treeIcon' + counter).src = '$minusIcon';
          found = 1;
        }
      }
      if(!found | force)
      {
        document.getElementById('treeIcon' + counter).src = '$plusIcon';
        document.getElementById('treeElement' + counter).style.display = 'none';
        if(document.getElementById('setupItem' + counter))
          document.getElementById('setupItem' + counter).style.display = 'none';
      }
    }
    else
    {
      document.getElementById('treeElement' + counter).style.display = 'block';
      document.getElementById('treeIcon' + counter).src = '$minusIcon';
      if(document.getElementById('setupItem' + counter))
        document.getElementById('setupItem' + counter).style.display = 'block';
    }
    counter++;
  }
}
//make the 'rel's work
function externalLinks()
{
  if (!document.getElementsByTagName)
    return;
  var anchors = document.getElementsByTagName(\"a\");
  for (var i=0; i<anchors.length; i++)
  {
    var anchor = anchors[i];
    if (anchor.getAttribute(\"href\")
      && anchor.getAttribute(\"rel\") == \"external\")
      anchor.target = \"_blank\";
  }
}";
 if ($EnableFloatingMenu) {
  $JavaScript .= "
function docHeight()
{
  if (typeof document.height != 'undefined') {
    return document.height;
  } else if (document.compatMode && document.compatMode != 'BackCompat') {
    return document.documentElement.scrollHeight;
  } else if (document.body && typeof document.body.scrollHeight !='undefined') {
    return document.body.scrollHeight;
  }
}
//********************************************************
//* You may use this code for free on any web page provided that
//* these comment lines and the following credit remain in the code.
//* Floating Div from http://www.javascript-fx.com
//********************************************************
// Modified in May 2005 by Przemek Czerkas:
//  - added calls to docHeight()
//  - added bounding params tlx, tly, brx, bry
var ns = (navigator.appName.indexOf(\"Netscape\") != -1);
var d = document;
var px = document.layers ? \"\" : \"px\";
function JSFX_FloatDiv(id, sx, sy, tlx, tly, brx, bry)
{
  var el=d.getElementById?d.getElementById(id):d.all?d.all[id]:d.layers[id];
  window[id + \"_obj\"] = el;
  if(d.layers)el.style=el;
  el.cx = el.sx = sx;
  el.cy = el.sy = sy;
  el.tlx = tlx;
  el.tly = tly;
  el.brx = brx;
  el.bry = bry;
  el.sP=function(x,y){this.style.left=x+px;this.style.top=y+px;};
  el.flt=function()
  {
    var pX, pY;
    pX = ns ? pageXOffset : document.documentElement && document.documentElement.scrollLeft ? document.documentElement.scrollLeft : document.body.scrollLeft;
    pY = ns ? pageYOffset : document.documentElement && document.documentElement.scrollTop ? document.documentElement.scrollTop : document.body.scrollTop;
    if(this.sy<0)
      pY += ns ? innerHeight : document.documentElement && document.documentElement.clientHeight ? document.documentElement.clientHeight : document.body.clientHeight;
    this.cx += (pX + Math.max(this.sx-pX, this.tlx) - this.cx)/4;
    this.cy += (pY + Math.max(this.sy-pY, this.tly) - this.cy)/4;
    this.cx = Math.min(this.cx, this.brx);
    this.cy = Math.min(this.cy, this.bry);
    if (ns) {
      this.sP(
        Math.max(Math.min(this.cx+this.clientWidth,document.width)-this.clientWidth,this.sx),
        Math.max(Math.min(this.cy+this.clientHeight,document.height)-this.clientHeight,this.sy)
      );
    } else {
      var oldh, newh;
      oldh = docHeight();
      this.sP(this.cx, this.cy);
      newh = docHeight();
      if (newh>oldh) {
        this.sP(this.cx, this.cy-(newh-oldh));
      }
    }
    setTimeout(this.id + \"_obj.flt()\", 20);
  }
  return el;
}";
 }
 $JavaScript .= '
function popFileEditor(filename,note)
{
  var height = (note == 0) ? 420 : 460;
  window.open(
    \'edit?file=\'+filename+\'&note=\'+note,
    \'FileEditor\',
    \'width=720,height=\'+height+\',toolbar=no,menubar=no,location=no,personalbar=no,scrollbars=no,status=no,directories=no,resizable=yes\'
  );
}
window.onload = externalLinks;
// -->
</script>';
 $headerHTTP = 'HTTP/1.1 200 OK
Content-type: text/html
Cache-control: no-cache
';
 $headerDTDStrict = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
';
 $headerDTDTransitional = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
';
 $headers = "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\">
<head>
  <meta http-equiv=\"content-type\" content=\"application/xhtml+xml; charset=utf-8\" />
  <title>ASSP (Anti SPAM SMTP Proxy)</title>
  <link rel=\"stylesheet\" href=\"get?file=images/assp.css\" type=\"text/css\" />
  <link rel=\"shortcut icon\" href=\"get?file=images/favicon.ico\" />
$JavaScript
</head>
<body><a name=\"Top\">
<p>
  <a href=\"http://assp.sourceforge.net/\"><img src=\"get?file=images/logo.jpg\" alt=\"ASSP\" /></a>
</p>
<div class=\"navMenu\"";
 $headers .= ' id="navMenu" style="position:absolute"' if $EnableFloatingMenu;
 $headers .= "><div><div style=\"text-align: center;\">
  <a onmousedown=\"expand(1, 1)\">Expand All</a>&nbsp;&nbsp;&nbsp;
  <a onmousedown=\"expand(0, 1)\">Collapse All</a></div>
  <hr />

  <div class=\"menuLevel1\"><a href=\"/\"><img src=\"$plusIcon\" alt=\"plusicon\" /> Main</a><br /></div>";
 my $counter = 0;
 foreach $c (@Config) {
   if(@{$c} == 5) {
     $headers .= "</div>\n  <div class=\"menuLevel2\">\n  <a onmousedown=\"toggleDisp('$counter')\">" .
       "<img id=\"treeIcon$counter\" src=\"$plusIcon\" alt=\"plusicon\" /> " .
       "$c->[4]</a>\n</div>\n<div id=\"treeElement$counter\" style=\"padding-left: 3px; display: block\">";
     $counter++;
   } else {
     $headers .= "\n    <div class=\"menuLevel3\"><a href=\"/#$c->[0]\">$c->[0]</a></div>";
   }
 }
 $headers .= "</div>
  <div class=\"menuLevel1\">$NavMenu</div>
  <hr />
  <div style=\"text-align: center;\">
    <a href=\"http://assp.sourceforge.net\">ASSP</a> v$version$modversion<br />
      $starttime  
  </div>
 
   <hr />
  </div>
  <script type=\"text/javascript\">
  <!--
  ";
 $headers .= 'JSFX_FloatDiv("navMenu",2,50,2,-2,2,99999).flt();' if $EnableFloatingMenu;
 $headers .= '
  expand(0,0);
  // -->
  </script>
  ';
 $footers = '
<div class=contentFoot>

<a href="http://assp.sourceforge.net/fom/cache/1.html" rel="external">docs</a> | 
 <a href="http://sourceforge.net/mail/?group_id=69172" rel="external">email lists</a> | 
 <a href="http://sourceforge.net/forum/?group_id=69172" rel="external">forums</a> | 
 <a href="http://sourceforge.net/news/?group_id=69172" rel="external">news</a> | 
 <a href="http://sourceforge.net/export/rss2_projnews.php?group_id=69172&rss_fulltext=1&go" rel="external">rss</a> | 
 <a href="http://assp.sourceforge.net/cgi-bin/total.pl" rel="external">stats</a> | 
 <a href="http://www.pointdee.co.uk/assp-wiki/" rel="external">wiki</a>
</div>';
$kudos = '
<div class="kudos">
 <a href="http://www.magicvillage.de/~Fritz_Borgstedt/assp/" rel="external">
 <img src="get?file=images/village.gif" alt="Fritz Borgstedt&#39s beta site" height="31" width="31" /></a>&nbsp;
 <a href="http://sourceforge.net" rel="external">
 <img src="get?file=images/sourceforge-logo.gif" alt="SourceForge" height="31" width="88" /></a>
</div>
';
}

$EmailAdrRe="[^()<>@,;:\\\"\\[\\]\000-\040]+";
$EmailDomainRe='(?:\w[\w\.\-]*\.\w+|\[[\d\.]*\.\d+\])';
$HeaderNameRe='\S[^\r\n]*';
$HeaderValueRe='[ \t]*[^\r\n]*(?:\r?\n[ \t]+\S[^\r\n]*)*(?:\r?\n)?';
$HeaderRe='(?:'.$HeaderNameRe.':'.$HeaderValueRe.')';


# Notes on general operation & program structure
# I'm using IO::Select, so don't make any changes that block for long
# as new connections come we create a pair of entries in a hash %Con
# based on the hash of the filehandle, so $Con{$fh} has data for this
# connection. $Con{$fh}->{friend} is the partner socket for the smtp proxy.
# ->{ip} is the ip address of the connecting client
# ->{relayok} tells if we can relay mail for this client
# ->{getline} is a pointer to a function that should be called whan a line of input is received for this filehandle
# ->{mailfrom} is the envelope sender (MAIL FROM: <address>)
# ->{outgoing} is a buffer for outgoing socket traffic (see $writable & &sendque)
# ->{rcpt} are the addresses from RCPT TO: <address> (space separated)
# ->{header} is where the header (and eventually the first 10000 bytes) are stored
# ->{myheader} is where we store our header, we merge it with client's header later
# ->{maillog} if present stream logging is enabled
# ->{maillogbuf} buffer for storing unwritten stream log while waiting for isspam decision
# ->{maillogfh} is the filehandle for logging lines to the maillog
# ->{mailloglength} is the length logged so far (we stop after 10000 bytes)
# ->{spamfound} is a flag used to signal if an email is determined to be spam.
# ->{maillength} is the same as mailloglength but is not reset.
#
# After connection the {getline} field functions like a state machine
# redirecting input to subsequent handlers
#
# whitebody -> getline
#   getbody ->
#     error -> (disconnects)
#     getline -> getheader ->
#       whitebody -> getline
#         error -> (disconnects)
#
# getline looks for MAIL FROM, RCPT TO, RSET
# getheader looks for a blank line then tests for whitelist / spamaddresses
# getbody looks for the . and calls isspam, the Bayesian spam test
# whitebody waits for . and redirects client to server
# error waits for . ignoring data from client (and finishes the maillog)
#
# the server has states like this:
#
# skipok -> reply
#
# skipok traps the 250 ok response from the NOOP Connection from
# reply echos server messages to the client
# reply also looks for a 235 AUTH OK and sets {relayok}=1

use IO::Select;
use IO::Socket;
use Time::Local;
use Sys::Hostname;


sub serviceCheck {}
sub d {}

eval(q[sub d {
 my $time=gmtime(); $time=~s/... (...) +(\d+) (........) ..(..)/$2 $1 $4 $3/;
 print DEBUG "$time <$_[0]>\n";
 }]) if $DEBUG;

if($AsADaemon) {
 fork() && exit;
 close STDOUT;
 close STDERR;
 $silent=1;
}

if($pidfile) {open(F,">$base/$pidfile"); print F $$; close F;}

sub RemovePid {
 if ($pidfile) {
  d('RemovePid');
  unlink("$base/$pidfile");
 }
}

if($DEBUG) {open(DEBUG, ">$base/".time.".dbg"); binmode(DEBUG); my $oldfh = select(DEBUG); $| = 1; select($oldfh);}
 my $logdir = $1 if $logfile=~/(.*)\/.*/;
 mkdir "$base/$logdir",0777 if $logdir;
if($logfile && open(LOG,">>$base/$logfile")) {my $oldfh = select(LOG); $| = 1; select($oldfh);}

if($AsAService) {
 eval(<<'EOT');
 use Win32::Daemon;
 mlog(0,"starting as a service");
 Win32::Daemon::StartService();

 # Wait until the service manager is ready for us to continue...
 while( SERVICE_START_PENDING != Win32::Daemon::State() ) { sleep( 1 ); }
 Win32::Daemon::State( SERVICE_RUNNING );

sub serviceCheck {
 d(50);
 if(Win32::Daemon::State() == SERVICE_STOP_PENDING ) {
  d(51);
  mlog(0,"service stopping");
  &saveWhitelist;
  Win32::Daemon::State( SERVICE_STOPPED );
  Win32::Daemon::StopService();
  exit;
 }
}

EOT
 print STDERR "error: $@\n" if $@;
 print LOG "error: $@\n" if $@;
}

init();
$lastTimeoutCheck = time();
while(1) {
 &MainLoop;
}

sub init {
 my $ver;

 
  mlog(0,"ASSP version $version$modversion (Perl $]) initializing ");
 if ($CanUseHostname) {
 mlog(0,"ASSP running on server: $localhostname ");
  } else {
  mlog(0,"ASSP running on server: Hostname not available");
 }
 if ($CanUseLDAP) {
  $ver=eval('Net::LDAP->VERSION'); $VerNetLDAP=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Net::LDAP module$ver installed and available");
 } else {
  mlog(0,"Net::LDAP module not installed");
 }
 if ($CanUseDNS) {
  $ver=eval('Net::DNS->VERSION'); $VerNetDNS=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Net::DNS module$ver installed and available");
 } else {
  mlog(0,"Net::DNS module not installed");
 }
 if ($CanUseAddress) {
  $ver=eval('Email::Valid->VERSION'); $VerEmailValid=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Email::Valid module$ver installed and available");
 } else {
  mlog(0,"Email::Valid module not installed");
 }
 if ($CanUseSPF) {
  $ver=eval('Mail::SPF::Query->VERSION'); $VerMailSPFQuery=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Mail::SPF::Query module$ver installed and available");
 } elsif ($AvailSPF) {
  $ver=eval('Mail::SPF::Query->VERSION'); $ver=" version $ver" if $ver;
  mlog(0,"Mail::SPF::Query module$ver installed but Net::DNS required");
 } else {
  mlog(0,"Mail::SPF::Query module not installed");
 }
 if ($CanUseSRS) {
  $ver=eval('Mail::SRS->VERSION'); $VerMailSRS=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Mail::SRS module$ver installed - Sender Rewriting Scheme available");
 } elsif (!$AvailSRS) {
  mlog(0,"Mail::SRS module not installed - Sender Rewriting Scheme disabled");
 }
 if ($CanUseHTTPCompression) {
  $ver=eval('Compress::Zlib->VERSION'); $VerCompressZlib=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Compress::Zlib module$ver installed - HTTP compression available");
 } elsif (!$AvailZlib) {
  mlog(0,"Compress::Zlib module not installed - HTTP compression disabled");
 }
 if ($CanUseMD5Keys) {
  $ver=eval('Digest::MD5->VERSION'); $VerDigestMD5=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Digest::MD5 module$ver installed - delaying will use MD5 keys for hashes");
 } elsif (!$AvailMD5) {
  mlog(0,"Digest::MD5 module not installed - delaying will use plain text keys for hashes");
 }
 if ($CanSearchLogs) {
  $ver=eval('File::ReadBackwards->VERSION'); $VerFileReadBackwards=$ver; $ver=" version $ver" if $ver;
  mlog(0,"File::ReadBackwards module$ver installed - searching of log files enabled");
 } elsif (!$AvailReadBackwards) {
  mlog(0,"File::ReadBackwards module not installed - searching of log files disabled");
 }
 if ($CanStatCPU) {
  $ver=eval('Time::HiRes->VERSION'); $VerTimeHiRes=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Time::HiRes module$ver installed - CPU usage statistics available");
 } elsif (!$AvailHiRes) {
  mlog(0,"Time::HiRes module not installed - CPU usage statistics disabled");
 }
 if ($CanChroot) {
  $ver=eval('PerlIO::scalar->VERSION'); $VerPerlIOscalar=$ver; $ver=" version $ver" if $ver;
  mlog(0,"PerlIO::scalar module$ver installed - chroot savy") ;
 } 
 if ($CanUseSyslog){
  $ver=eval('Sys::Syslog->VERSION'); $VerSysSyslog=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Sys::Syslog module$ver installed - centralized logging enabled");
 } elsif (!$AvailSyslog) {
   mlog(0,"Sys::Syslog module not installed.");
 }
 
 if ($CanUseWin32Daemon){
  $ver=eval('Win32::Daemon->VERSION'); $VerWin32Daemon=$ver; $ver=" version $ver" if $ver;
  mlog(0,"Win32::Daemon module$ver installed - can run as Win32 service");
 }


 $readable = new IO::Select( );
 $writable = new IO::Select( );

 $lsn = newListen($listenPort,\&NewSMTPConnection);
 $WebSocket = newListen($webAdminPort,\&NewWebConnection);
 mlog(0,"listening for mail connections at $listenPort and admin connections at $webAdminPort");
 if($listenPort2) {
  $lsn2 = newListen($listenPort2,\&NewSMTPConnection);
  mlog(0,"listening for additional mail connections at $listenPort2");
 }
 # handle the possible relayhost / smarthost option
 if($relayHost && $relayPort) {
  $Relay=newListen($relayPort,\&NewSMTPConnection);
  mlog(0,"listening for relay connections at $relayPort");
 }

 $nextNoop=time;
 $endtime=$nextNoop+$RestartEvery;
 $saveWhite=$nextNoop+$UpdateWhitelist;
 $nextCleanDelayDB=$nextNoop+$CleanDelayDBInterval;

 $SIG{INT}=sub {mlog(0,"sig INT"); &SaveWhitelist; kill 6,$$ if $ENV{windir}; RemovePid(); exit;};
 $SIG{TERM}=sub {mlog(0,"sig TERM"); &SaveWhitelist; RemovePid(); exit;};

 my ($uid,$gid)=getUidGid($runAsUser,$runAsGroup) if ($runAsUser || $runAsGroup);
 if($ChangeRoot) {
  my $chroot;
  eval('$chroot=chroot($ChangeRoot)');
  if($@) {
   my $msg="request to change root to '$ChangeRoot' failed: $@";
   mlog('',$msg);
   die ucfirst($msg);
  } elsif(! $chroot) {
   my $msg="request to change root to '$ChangeRoot' did not succeed: $!";
   mlog('',$msg);
   die ucfirst($msg);
  } else {
   $chroot=$ChangeRoot; $chroot=~s/(\W)/\\$1/g;
   $base=~s/^$chroot//i;
   chdir("/");
   mlog('',"successfully changed root to '$ChangeRoot' -- new base is '$base'");
  }
 }
 switchUsers($uid,$gid) if ($runAsUser || $runAsGroup);

 # create folders if they're missing
 mkdir "$base/$spamlog",0700; mkdir "$base/$notspamlog",0700;
 my $dir=$correctedspam;
 $dir=~s/\/.*?$//;
 mkdir "$base/$dir",0700;
 mkdir "$base/$correctedspam",0700; mkdir "$base/$correctednotspam",0700;
 my $pbdir = $1 if $pbdb=~/(.*)\/.*/;
 mkdir "$base/$pbdir",0777 if $pbdir;
 mkdir "$base/notes",0777;


 # put this after chroot so the paths don't change
 $SpamdbObject=tie %Spamdb,orderedtie,"$base/$spamdb" if $spamdb;
 mlog(0,"warning: Bayesian spam database is small or empty: '$base/$spamdb'") if $spamdb && -s "$base/$spamdb" < 10000;
 $HeloBlackObject=tie %HeloBlack,orderedtie,"$base/$spamdb.helo" if $spamdb;
 $DnsblObject=tie %Dnsbl,orderedtie,"$base/$dnsbl" if $dnsbl;
 mlog(0,"warning: DNS blacklist database is small or empty: '$base/$dnsbl'") if $dnsbl && -s "$base/$dnsbl" < 10000;
 $WhitelistObject=tie %Whitelist,orderedtie,"$base/$whitelistdb";
 mlog(0,"warning: whitelist is small or empty: '$base/$whitelistdb' (ignore if this is a new install)") if $whitelistdb && -s "$base/$whitelistdb" < 1000;

 $RedlistObject=tie %Redlist,orderedtie,"$base/$redlistdb";
 $GreylistObject=tie %Greylist,orderedtie,"$base/$greylist" if $greylist;

 $PBWhiteObject=tie %PBWhite,orderedtie,"$base/$pbdb.white.db";
 $PBBlackObject=tie %PBBlack,orderedtie,"$base/$pbdb.black.db";
 $RBLCacheObject=tie %RBLCache,orderedtie,"$base/$pbdb.rbl.db";
 $DelayObject=tie %Delay,orderedtie,"$base/$delaydb";
 $DelayWhiteObject=tie %DelayWhite,orderedtie,"$base/$delaydb.white";


 if($AvDbs) {
  mlog(0,"loading virus definitions ...");
  Av->init( {path => ($AvPath || $base), databases => $AvDbs} );
  mlog(0,"virus definitions loaded; count=".Av->count);
 }
 

 $shuttingDown=$doShutdown=0;
 $smtpConcurrentSessions=0;
 $Stats{starttime}=time;
 $Stats{version}="$version$modversion";
 &ResetStats;
 mlog(0,"starting");
}

sub newListen {
 my($port,$handler)=@_;
 my ($interface,$p)=$port=~/(.*):(.*)/;
 my $s;
 if($interface) {
  $s = new IO::Socket::INET(Listen => 10, LocalPort => $p, Reuse=>1, LocalAddr => $interface);
 } else {
  $s = new IO::Socket::INET(Listen => 10, LocalPort => $port, Reuse=>1);
 }
 if(! $s) {
  mlog('',"couldn't create server socket on port '$port' -- maybe another service is running or I'm not root (uid=$>)?");
  return undef;
 }
 $SocketCalls{$s}=$handler;
 $readable->add($s); # add to select list
 $s;
}

sub getUidGid { my ($uname,$gname)=@_;
 return if $AsAService;
 eval('getgrnam(root);getpwnam(root);');
 if($@) {
  # windows pukes "unimplemented" for these -- just skip it
  mlog('',"warning: uname and/or gname are set ($uname,$gname) but getgrnam / getpwnam give errors: $@");
  return;
 }
 my $gid;
 if($gname) {
  $gid = getgrnam($gname);
  if(defined $gid) {
  } else {
   my $msg="could not find gid for group '$gname' -- not switching effective gid -- quitting";
   mlog('',$msg);
   die ucfirst($msg);
  }
 }
 my $uid;
 if($uname) {
  $uid = getpwnam($uname);
  if(defined $uid) {
  } else {
   my $msg="could not find uid for user '$uname' -- not switching effective uid -- quitting";
   mlog('',$msg);
   die ucfirst($msg);
  }
 }
 ($uid,$gid);
}

sub switchUsers { my ($uid,$gid)=@_;
 return if $AsAService;
 my($uname,$gname)=($runAsUser,$runAsGroup);
 $>=0;
 if($> != 0) {
  my $msg="requested to switch to user/group '$uname/$gname' but cannot set effective uid to 0 -- quitting; uid is $>";
  mlog('',$msg);
  die ucfirst($msg);
 }
 $<=0;
 if($gid) {
  $)=$gid;
  if($)+0==$gid) {
   mlog('',"switched effective gid to $gid ($gname)");
  } else {
   my $msg="failed to switch effective gid to $gid ($gname) -- effective gid=$) -- quitting";
   mlog('',$msg);
   die ucfirst($msg);
  }
  $(=$gid;
  if($(+0==$gid) {
   mlog('',"switched real gid to $gid ($gname)");
  } else {
   mlog('',"failed to switch real gid to $gid ($gname) -- real uid=$(");
  }
 }
 if($uid) {
  # do it both ways so linux and bsd are happy
  $<=$uid; $>=$uid; $<=$uid; $>=$uid;
  if($>==$uid) {
  mlog('',"switched effective uid to $uid ($uname)");
  } else {
   my $msg="failed to switch effective uid to $uid ($uname) -- real uid=$< -- quitting";
   mlog('',$msg);
   die ucfirst($msg);
  }
  if($<==$uid) {
   mlog('',"switched real uid to $uid ($uname)");
  } else {
   mlog('',"failed to switch real uid to $uid ($uname) -- real uid=$<");
  }
 }
}

sub MainLoop {
 my $wait=5; # keep it short enough for servicecheck to be called regularly
 my $stime=$CanStatCPU ? (Time::HiRes::time()) : time; # loop cycle start time
 my ($canread,$canwrite)=IO::Select->select($readable,$writable,undef,$wait);
 my $itime=$CanStatCPU ? (Time::HiRes::time()) : time; # loop cycle idle end time
 $webTime=0; # loop cycle web time interval, global var
 $nextLoop2=$itime+1; # global var
 foreach $fh (@$canwrite) {
  my $l=length($Con{$fh}->{outgoing});
  print DEBUG "$fh $Con{$fh} l=$l\n" if $DEBUG;
  if(length($Con{$fh}->{outgoing})) {
   my $written=syswrite($fh,$Con{$fh}->{outgoing},$OutgoingBufSize);
   if($DEBUG) {
    if($written < 200) {
     print DEBUG "wrote: ($written)<",substr($Con{$fh}->{outgoing},0,$written),">\n";
    } else {
     print DEBUG "wrote: ($written)<long text>\n";
    }
   }
   $Con{$fh}->{outgoing}=substr($Con{$fh}->{outgoing},$written);
   $l=length($Con{$fh}->{outgoing});
   # test for highwater mark
   if($written>0 && $l < $OutgoingBufSize && $Con{$fh}->{paused}) {
    $Con{$fh}->{paused}=0;
    $readable->add($Con{$fh}->{friend});
   }
  }
  if(length($Con{$fh}->{outgoing})==0) {
   $writable->remove($fh);
  }
 }
 foreach $fh (@$canread) {
  if ($fh && $SocketCalls{$fh}) {
   if ($CanStatCPU && ($SocketCalls{$fh}==\&WebTraffic || $SocketCalls{$fh}==\&NewWebConnection)) {
    # calculate time spent serving web request
    $webTime-=Time::HiRes::time();
    $SocketCalls{$fh}->($fh);
    $webTime+=Time::HiRes::time();
   } else {
    $SocketCalls{$fh}->($fh);
   }
  }
 }
 if ($smtpIdleTimeout > 0){
   if (%Con > 0){
     $tmpNow = time();
     # Check timeouts only every 3 seconds at least
     if ($tmpNow > ($lastTimeoutCheck + 3)){
      foreach $tmpfh (keys %Con){
       if ($Con{$tmpfh}->{type} eq 'C' && $Con{$tmpfh}->{timelast} > 0 && (($tmpNow - $Con{$tmpfh}->{timelast}) > $smtpIdleTimeout)){
         mlog($tmpfh,'Connection Timeout');
         $Stats{smtpConnIdleTimeout}++;
         seterror($Con{$tmpfh}->{client},"451 Connection timeout, try later\r\n",1);
       }
      }
      $lastTimeoutCheck = $tmpNow;
     }
   }
 }
 d(6);
 serviceCheck(); # for win32 services
 # timer related issues
 if(abs(($itime - $stime) - $wait) <= 0.5) {
  # noactive connections -- check for maintenance
  d(8);
  if($itime >= $saveWhite) {
   d(9);
   &SaveWhitelist;
   $saveWhite=int($itime)+$UpdateWhitelist;
  }
  if($itime >= $nextCleanDelayDB) {
   &DoCleanDelayDB;
   $nextCleanDelayDB=int($itime)+$CleanDelayDBInterval;
  }

  if($RestartEvery && $itime >= $endtime) {
   # time to quit -- after endtime and we're bored.
   $opencon=(keys %Con);
   if($opencon == 0) {
    &SaveWhitelist;
    mlog(0,"restarting");
    if($AsAService) {
     exec('cmd.exe /C net stop ASSPSMTP & net start ASSPSMTP');
    } else {
     exit 1;
    }
   }
  }
  uploadStats() if($totalizeSpamStats && $itime >= $Stats{nextUpload});
  downloadGrey() if(!$nogreydownload && $greylist && $itime >= $NextGreylistDownload);
  if($AvDbs && Av->checkReload()) {
   mlog(0,"reloading virus database ...");
   Av->loadAll();
   mlog(0,"virus signature database reloaded; count=".Av->count);
  }
 }
 if ($CanStatCPU) {
  #
  # cycleTime = cpuTime + webTime
  # cpuTime = cpuIdleTime + cpuBusyTime
  #
  my $ctime=Time::HiRes::time(); # loop cycle end time
  my $cycleTime=$ctime-$stime;
  my $cpuTime=$cycleTime-$webTime;
  my $cpuIdleTime=$itime-$stime;
  my $cpuBusyTime=$cpuTime-$cpuIdleTime;
  $Stats{cpuTime}+=$cpuTime;
  $Stats{cpuBusyTime}+=$cpuBusyTime;
  # envelope following filter with instant rise and decay time of 1 second
  my $lusage=$cpuUsage*exp(-(0.693/1)*$cycleTime);
  my $usage=($cpuTime==0 ? 0 : $cpuBusyTime/$cpuTime);
  $cpuUsage=$usage>$lusage ? $usage : $lusage;
 }
 if ($doShutdown && $itime >= $doShutdown) {
  &SaveWhitelist;
  mlog(0,"restarting");
  if($AsAService) {
   exec('cmd.exe /C net stop ASSPSMTP & net start ASSPSMTP');
  } else {
   exit 1;
  }
 }
}
d(11);
# Never reached...(we hope)

# called during long operations to keep processing priority data
# alternates (1s/1s) beetween SMTP connections handling and the calling task
sub MainLoop2 {
 my $time=$AvailHiRes ? (Time::HiRes::time()) : time;
 if ($time >= $nextLoop2) {
  $webTime+=$time if $CanStatCPU;
  $nextLoop2=$time+1; # 1s for SMTP stuff
  serviceCheck(); # for win32 services
  my ($canread,$canwrite);
  do {
   ($canread,$canwrite)=IO::Select->select($readable,$writable,undef,0);
   foreach $fh (@$canwrite) {
    my $l=length($Con{$fh}->{outgoing});
    print DEBUG "$fh $Con{$fh} l=$l\n" if $DEBUG;
    if(length($Con{$fh}->{outgoing})) {
     my $written=syswrite($fh,$Con{$fh}->{outgoing},$OutgoingBufSize);
     if($DEBUG) {
      if($written < 200) {
       print DEBUG "wrote: ($written)<",substr($Con{$fh}->{outgoing},0,$written),">\n";
      } else {
       print DEBUG "wrote: ($written)<long text>\n";
      }
     }
     $Con{$fh}->{outgoing}=substr($Con{$fh}->{outgoing},$written);
     $l=length($Con{$fh}->{outgoing});
     # test for highwater mark
     if($written>0 && $l < $OutgoingBufSize && $Con{$fh}->{paused}) {
      $Con{$fh}->{paused}=0;
      $readable->add($Con{$fh}->{friend});
     }
    }
    if(length($Con{$fh}->{outgoing})==0) {
     $writable->remove($fh);
    }
   }
   foreach $fh (@$canread) {
     if ($fh && ($SocketCalls{$fh}==\&SMTPTraffic || $SocketCalls{$fh}==\&NewSMTPConnection || $SocketCalls{$fh}==\&WebTraffic || $SocketCalls{$fh}==\&NewWebConnection)) {
     $SocketCalls{$fh}->($fh);
    }
   }
   $time=$AvailHiRes ? (Time::HiRes::time()) : time;
  } until ((@$canread==0 && @$canwrite==0) || $time >= $nextLoop2);
  $nextLoop2=$time+1; # 1s for other tasks
  $webTime-=$time if $CanStatCPU;
 }
}

sub SaveWhitelist {
 d(35);
 mlog(0,"saving whitelist") if $MaintenanceLog;
 $WhitelistObject->flush() if $WhitelistObject;
 mlog(0,"saving redlist") if $MaintenanceLog;
 $RedlistObject->flush() if $RedlistObject;
 mlog(0,"saving delaying records") if $MaintenanceLog;
 $DelayObject->flush() if $DelayObject;
 $DelayWhiteObject->flush() if $DelayWhiteObject;
 SavePB();
 SaveStats();

}

sub SavePB {

 # save Penalty Box Databases
 mlog(0,"saving penalty records") if $MaintenanceLog;
 $PBBlackObject->flush() if $PBBlackObject;
 $PBWhiteObject->flush() if $PBWhiteObject;
 mlog(0,"saving cache records") if $MaintenanceLog;
 $RBLCacheObject->flush() if $RBLCacheObject;
}

sub CleanPB {

 # clean Penalty Box Databases
 &SavePB;
 mlog(0,"cleaning penalty records...") if $MaintenanceLog;
 &cleanBlackPB if $PBBlackObject;
 &cleanWhitePB if $PBWhiteObject;

 mlog(0,"cleaning cache records...") if $MaintenanceLog;
 &cleanCacheRBL if $DoRBLCache!=0;
 &exportExtremePB;

}

sub DoCleanDelayDB {
 mlog(0,"cleaning up delaying databases ...") if $MaintenanceLog;
 my $t=time;
 my $keys_before=$keys_deleted=0;
 while (($k,$v)=each(%Delay)) {
  $keys_before++;
  if ($t-$v>=$DelayEmbargoTime*60+$DelayWaitTime*3600) {
   delete $Delay{$k};
   $keys_deleted++;
  }
  MainLoop2();
 }
 mlog(0,"cleaning delaying database (triplets) finished; keys before=$keys_before, deleted=$keys_deleted") if $MaintenanceLog;
 $keys_before=$keys_deleted=0;
 while (($k,$v)=each(%DelayWhite)) {
  $keys_before++;
  if ($t-$v>=$DelayExpiryTime*24*3600) {
   delete $DelayWhite{$k};
   $keys_deleted++;
  }
  MainLoop2();
 }
 mlog(0,"cleaning delaying database (whitelisted tuplets) finished; keys before=$keys_before, deleted=$keys_deleted") if $MaintenanceLog;
CleanPB();
}

sub mlog{
 my $fh=shift;
 d(34);
 my $m=localtime();
 $m=~s/^... (...) +(\d+) (\S+) ..(..)/$1-$2-$4 $3/;
  my ($sec,$min,$hour,$mday,$mon,$year) = localtime(time);
 

 

 if($LogRollDays > 0) {
  my $t=int(time()/($LogRollDays*24*3600)); # roll log every 14 days

  if($logfile && $mlogLastT && $t != $mlogLastT && $logfile ne "maillog.log" && $asspLog) {
  	# roll the log

  	my ($sec,$min,$hour,$mday,$mon,$year) = localtime(time);
 
  	$mon++; $year-=100;
   	my $mm=sprintf("%02d-%02d-%02d-%02d",$year,$mon,$mday,$hour);
   	my ($logdir, $logdirfile) = ($1,$2) if $logfile=~/^(.*)[\/\\](.*?)$/;
  		if (!$logdir)  {
  			$archivelogfile = "$mm.$logfile";
  		} else {
  			mkdir "$base/$logdir",0777;
  			$archivelogfile = "$logdir/$mm.$logdirfile";
  		} 
   my $msg="$m: Rolling log file -- archive saved as '$archivelogfile'\n";
   print LOG $msg;
   print $msg unless $silent;
  
   close LOG;
   rename("$base/$logfile", "$base/$archivelogfile");
   if(open(LOG,">>$base/$logfile")) {my $oldfh = select(LOG); $| = 1; select($oldfh);}
   print LOG "$m new log file -- old log file renamed to '$archivelogfile'\n";
   SaveConfig();
	}
  $mlogLastT=$t;
 }
  if($fh && $Con{$fh}) {
  $m.= " $Con{$fh}->{ip} <$Con{$fh}->{mailfrom}>";
  my ($to) = $Con{$fh}->{rcpt}=~/(\S+)/;
  $m.= " to: $to" if $to;
  $m.= " $_[0]\n";
 } else {
  $m.= " ".ucfirst($_[0])."\n";
 }
 print DEBUG $m if $DEBUG;

 tosyslog('info', substr($m,18)) if $CanUseSyslog && $sysLog;
 return if ($fh && $Con{$fh}) && ($noLog && $Con{$fh}->{ip}=~$NLOGRE);

 print $m unless $silent;
 print LOG $m if $logfile && $asspLog;
}
sub tosyslog {
  my ($priority, $msg) = @_;
  return 0 unless ($priority =~ /info|err|debug/);
  $msg=~s/^\s+//;
  setlogsock('unix');
  openlog('assp', 'pid,cons', 'mail');
  syslog($priority, $msg);
  closelog();
  return 1;
  }
sub tzStr {
 # calculate the time difference in minutes
 my $minoffset = (Time::Local::timelocal(localtime()) - Time::Local::timelocal(gmtime()))/60;
 # translate it to "hour-format", so that 90 will be 130, and -90 will be -130
my $tzoffset = 0;
$tzoffset = int($minoffset/60)*100 + ($minoffset/abs($minoffset))*($minoffset%60) if $minoffset;
 # apply final formatting, including +/- sign and 4 digits
 return sprintf("%+05d", $tzoffset);
}

#####################################################################################
#                Socket handlers
sub NewSMTPConnection {
 my $fh=shift;
 my ($client, $server, $destination);
 if($fh==$Relay) {
  # a relay connection -- destination is the relayhost
  d(101);
  $destination=$relayHost;
  } elsif($fh==$lsn2 && $smtpAuthServer ne '') { 
	# connection on the Second Listen port 
	d(1001); 
	$destination=$smtpAuthServer; 
 } else {
  d(1);
  $destination=$smtpDestination;
 }
 if(!($client=$fh->accept)) {
  d("accept failed: $fh");
  return;
 }
 my $ip       = $client->peerhost();
 my $port     = $client->peerport();
 my $localip  = $client->sockhost();
 my $localport= $client->sockport();
 # shutting down ?
 if ($shuttingDown) {
  mlog(0,"connection from $ip:$port rejected -- shutdown/restart process is in progress");
  $Stats{smtpConnDenied}++;
  $client->write("421 <$myName> Service not available, closing transmission channel\r\n");
  $client->close();
  return;
 }
 # ip connection filtering

 if ($denySMTPConnectionsFrom && $ip=~$DSMTPCFRE && !($ispip && $ip=~$ISPRE) && !($acceptAllMail && $ip=~$AMRE) && !($contentOnlyRe && $ip=~('('.$contentOnlyReRE.')'))  && !($noDelay && $ip=~$NDRE)) {

 mlog(0,"connection from $ip:$port rejected by denySMTPConnectionsFrom") if !$denySMTPnoLog;
$Stats{smtpConnDenied}++;

 $client->close();
 return;
  }

 # ip connection limiting
 $maxSMTPipSessions=999 if (!$maxSMTPipSessions);
 if ($maxSMTPipSessions && !($ispip && $ip=~$ISPRE) && !($acceptAllMail && $ip=~$AMRE)) {
  $SMTPSession{$ip}++;
  if ($SMTPSession{$ip} > $maxSMTPipSessions) {
   $SMTPSession{$ip}--;
   d("limiting ip: $fh");
   mlog(0,"limiting $ip connections") if $SessionLog;
pbAdd($ip,$ilValencePB,"LimitingIp") if $ilValencePB>0 ;
   $Stats{smtpConnLimitIP}++;
   return;
  } else {
   $SMTPSession{$client}=$fh;
  }
 }
 if ($destination =~ /^(__INBOUND__:)?(\d+)$/){
   if ($localip eq '0.0.0.0'){
     mlog('',"Something really odd is going on with this incomming connection at $localip:$localport");
     $localip = '127.0.0.1';
   }
   $destination = $localip .':'.$2;
 }
 $server=new IO::Socket::INET(Proto=>'tcp',PeerAddr=>$destination,Timeout=>2);
 if(! $server) {
  mlog('',"couldn't create server socket to $destination -- aborting connection");
  if (exists $SMTPSession{$client}) {
   delete $SMTPSession{$client};
   $SMTPSession{$ip}--;
  }
  $client->close();
  return;
 }
 addfh($client,\&getline,$server);
 if($sendNoopInfo) {
  addfh($server,\&skipok,$client);
 } else {
  addfh($server,\&reply,$client);
 }
 $Con{$client}->{client}   = $client;
 $Con{$client}->{server}   = $server;
 $Con{$client}->{ip}       = $ip;
 $Con{$client}->{port}     = $port;
 $Con{$client}->{localip}  = $localip;
 $Con{$client}->{localport}= $localport;
 $Con{$client}->{type}     = 'C';
 $Con{$server}->{type}     = 'S';
 print DEBUG "Connected: $client -- $server\n" if $DEBUG;
 if(ok2Relay($ip) || $fh == $Relay ) {
  $Con{$client}->{relayok}=1;
  print DEBUG "$client relaying ok: $ip\n" if $DEBUG;
 }
 my $time=$UseLocalTime ? localtime() : gmtime();
 my $tz=$UseLocalTime ? tzStr() : '+0000';
 $time=~s/... (...) +(\d+) (........) (....)/$2 $1 $4 $3/;
 $Con{$client}->{rcvd}="Received: from $ip ([$ip] helo=) by $myName; $time $tz\r\n";
 print DEBUG  "\n* connect ip=$Con{$client}->{ip} relay=<$Con{$client}->{relayok}> *\n" if $DEBUG;
 mlog(0,"Connected: $ip:$port -> $localip:$localport -> $destination") unless (!$ConnectionLog || $noLog && $ip=~$NLOGRE);
 $Con{$server}->{noop}="NOOP Connection from: $ip, $time $tz relayed by $myName\r\n" if $sendNoopInfo;

 # overall session limiting
 $maxSMTPSessions=9999 if (!$maxSMTPSessions);
 if ($maxSMTPSessions) {
  $SMTPSession{Total}++;
  $SMTPSession{$client}=$fh;
  if ($SMTPSession{Total}>=$maxSMTPSessions) {
   d("limiting sessions: $fh");
   $readable->remove($lsn) if $lsn;
   $readable->remove($lsn2) if $lsn2;
   $readable->remove($Relay) if $Relay;
   if ($SessionLog) {
    mlog(0,"connected: $ip:$port") if (!$ConnectionLog || $noLog && $ip=~$NLOGRE); # log if not logged ealier
    mlog(0,"limiting total connections");
   }
   $Stats{smtpConnLimit}++;
  }
 }
 # increment Stats if connection not limited
 if (!$maxSMTPSessions || $SMTPSession{Total}<$maxSMTPSessions) {
  if ($noLog && $ip=~$NLOGRE) {
   $Stats{smtpConnNotLogged}++;
  } else {
   $Stats{smtpConn}++;
  }
 }
 $smtpConcurrentSessions++;
 $Stats{smtpMaxConcurrentSessions}=$smtpConcurrentSessions if $smtpConcurrentSessions>$Stats{smtpMaxConcurrentSessions};
 # check if options files have been updated and need to be re-read
 if(time-$lastOptionCheck > 60) { # check for updates each 60 seconds
  foreach $f (@PossibleOptionFiles) {
   ${$f}=optionList($Config{$f},$f) if $Config{$f}=~/^ *file: *(.+)/i && fileUpdated($1);
  }
  foreach $f (@PossibleOptionFiles2) {
   ConfigCompileRe($f,'',${$f},'Initializing') if $Config{$f}=~/^ *file: *(.+)/i && fileUpdated($1);
  }
  $lastOptionCheck=time;
 }
}

sub SMTPTraffic {
 my $fh=shift;
 my $buf;
 if($fh->sysread($buf,4096)>0) {
  d(2);
  $this=$Con{$fh};
  $buf=$this->{_}.$buf;
  if ($Con{$fh}->{type} eq 'C'){
    $Con{$fh}->{timelast} = time();
  }
  if((my $sb=$this->{skipbytes})>0) {
   # support for XEXCH50 thankyou Microsoft for making my life miserable
   my $l=length($buf);
   print DEBUG "skipbytes=$sb l=$l -> " if $DEBUG;
   if($l >= $sb) {
    sendque($this->{friend},substr($buf,0,$sb)); # send the binary chunk on to the server
    $buf=substr($buf,$sb);
    delete $this->{skipbytes};
   } else {
    sendque($this->{friend},$buf); # send the binary chunk on to the server
    $this->{skipbytes}=$sb-=length($buf);
    $buf='';
   }
   print DEBUG "skipbytes=$this->{skipbytes}\n" if $DEBUG;
  }
  $bn=$lbn=-1;
  while(($bn=index($buf,"\n",$bn+1)) >= 0) {
   $s=substr($buf,$lbn+1,$bn-$lbn);
   if(defined($this->{bdata})) { $this->{bdata}-=length($s); }
   print DEBUG  "doing <$s>\n" if $DEBUG;
	Maillog($fh,$s) if $Con{$fh}->{maillog};
   $Con{$fh}->{getline}->($fh,$s);
   last unless $Con{$fh};  # it's possible that the connection can be deleted while there's still something in the buffer
   $lbn=$bn;
  }
  d(3);
  if($Con{$fh}) {
   ($this->{_})=substr($buf,$lbn+1);
   if(length($this->{_}) > $MaxBytes) {
    d(4);
    if(defined($this->{bdata})) { $this->{bdata}-=length($this->{_}); }
    Maillog($fh,$this->{_}) if $Con{$fh}->{maillog};
    $Con{$fh}->{getline}->($fh,$this->{_});
    ($this->{_})='';
   }
  }
 } else {
  d(5);
  done($fh);
 }
}

sub check4update {
 # only check every 15 seconds
 my $fil=shift;
 return if $check4updateTime{$fil} + 15 > time;
 $check4updateTime{$fil}=time;
 my @s=stat(${$fil});
 my $mtime=$s[9];
 if ($mtime != $FileUpdate{$fil}) {
  # reload
  $FileUpdate{$fil}=$mtime;
  open(F,"<${$fil}");
  local $/="\n";
  my $l; my %h;
  while($l=<F>) {
   $l=~y/\r\n\t //d;
   next unless $l;
   $h{lc $l}=1;
  }
  close F;
  %{$fil}=%h;
 }
}

sub SetRE { my ($var,$r,$f,$log)=@_;
 eval("\$$var=qr/\$r/$f");
 if($@) {
  mlog(0,"regular expression error in '$r' for $log: $@");
 }
}

sub setAMRE {
 SetRE(AMRE,"^($_[0])",'i','Accept All Mail');
}

sub setISPRE {
 SetRE(ISPRE,"^($_[0])",'i','ISP & Secondary MX');
}

sub ok2Relay {
 my $ip=shift;
 return 1 if $acceptAllMail && $ip=~$AMRE;
 if($relayHostFile) {
  check4update(relayHostFile);
  return 1 if $relayHostFile{$ip};
 }
 return 1 if PopB4SMTP($ip);
 # failed all tests -- return 0
 0;
}

sub PopB4SMTP {
 return 0 unless $PopB4SMTPFile;
 unless ($TriedDBFileUse) {
  eval 'use DB_File';
  mlog(0,"could not load module DB_File: $@") if $@;
  $TriedDBFileUse=1;
 }
 my $ip=shift;
 my %hash;
 tie %hash,  'DB_File', $PopB4SMTPFile, O_READ, 0400, $DB_HASH;
 if($hash{$ip}) {
  return 1;
 } else {
  return 0;
 }
}

# Another possible PopB4SMTP implementation
# works with Merak and other text based popb4smtp files.
#  -- this could be implemented more effeciently...
#sub PopB4SMTP {
# return 0 unless $PopB4SMTPFile;
# my $ip=shift;
# my $ind; my $ipMatch; my $preByte; my $postByte;
# open(MKPOPSMTP,"<$PopB4SMTPFile") or return 0 ;
# while ($line = <MKPOPSMTP>) {
#  $ind = index($line,$ip);
#  if ($ind  > 0) {
#   #find the match, and get it and the char before and after
#   #if both of those aren't a number ord("0") & ord("9") 48 - 57 then I have the whole IP [ord is same as asc]
#   #if not, this is a subset of a larger IP address and thus no good
#   #ex: 66.35.250.203 I don't want to let 66.35.250.20 or 6.35.250.203 or 6.35.250.20 you get the idea
#   $preByte = ord(substr($line, ($ind - 1), 1));
#   $postByte = ord(substr($line, ($ind + length($ip)), 1)); #0 based, so no + 1
#   if ( (($preByte < 48) || ($preByte > 57)) & (($postByte < 48) || ($postByte > 57)) ) {
#    close(MKPOPSMTP);
#    mlog(0,"PopB4SMTP OK for $ip");
#    return 1;
#   }
#  }
# }
# close(MKPOPSMTP);
# mlog(0,"PopB4SMTP NOT OK for $ip");
# return 0;
#}

sub setACFRE {
 SetRE(ACFRE,"^($_[0])",'i',"Allow Admin Connections From");
}

sub NewWebConnection {
 my $s=$WebSocket->accept;
 return unless $s;
 my $ip=$s->peerhost();
 my $port=$s->peerport();
 if($allowAdminConnectionsFrom && $ip!~$ACFRE) {
  mlog('',"admin connection from $ip:$port rejected by allowAdminConnectionsFrom");
  $Stats{admConnDenied}++;
  $s->close();
  return;
 }
 # logging is done later (in webRequest()) due to /shutdown_frame page, which auto-refreshes
 $readable->add($s);
 $SocketCalls{$s}=\&WebTraffic;
}

sub WebTraffic {
 my $fh=shift;
 if($fh->sysread($buf,4096)>0) {
  local $_=$WebCon{$fh}.=$buf;
  if(length($_) > 1030000) {
   # throw away connections longer than 1M to prevent flooding
   WebDone($fh);
   return;
  }
  if(/Content-length: (\d+)/i) {
   # POST request
   my $l=$1;
   if (/(.*?\n)\r?\n\r?(.*)/s && length($2) >= $l) {
    my $reqh=$1;
    my $reqb=$2;
    my $resp;
    my $tempfh;
    open($tempfh,'>',\$resp);
    binmode $tempfh;
    webRequest($tempfh,$fh,$reqh,$reqb);
    close($tempfh);
    if ($resp=~/(.*?)\n\r?\n\r?(.*)/s) {
     my $resph=$1;
     my $respb=$2;
     my $time=gmtime();
     $time=~s/(...) (...) +(\d+) (........) (....)/$1, $3 $2 $5 $4 GMT/;
     $resph.="\nServer: ASSP/$version$modversion";
     $resph.="\nDate: $time";
     if ($EnableHTTPCompression && $CanUseHTTPCompression && /Accept-Encoding: (.*?)\n/i && $1=~/(gzip|deflate)/i) {
      my $enc=$1;
      if ($enc=~/gzip/i) {
       # encode with gzip
       $respb=Compress::Zlib::memGzip($respb);
      } else {
       # encode with deflate
       my $deflater=deflateInit();
       $respb=$deflater->deflate($respb);
       $respb.=$deflater->flush();
      }
      $resph.="\nContent-Encoding: $enc";
     }
     $resph.="\nContent-Length: ".length($respb);
     print $fh $resph;
     print $fh "\n\n";
     print $fh $respb;
    }
    # close connection
    WebDone($fh);
   }
  } elsif(/\n\r?\n/) {
   my $resp;
   my $tempfh;
   open($tempfh,'>',\$resp);
   binmode $tempfh;
   webRequest($tempfh,$fh,$_);
   close($tempfh);
   if ($resp=~/(.*?)\n\r?\n\r?(.*)/s) {
    my $resph=$1;
    my $respb=$2;
    my $time=gmtime();
    $time=~s/(...) (...) +(\d+) (........) (....)/$1, $3 $2 $5 $4 GMT/;
    $resph.="\nServer: ASSP/$version$modversion";
    $resph.="\nDate: $time";
    if ($EnableHTTPCompression && $CanUseHTTPCompression && /Accept-Encoding: (.*?)\n/i && $1=~/(gzip|deflate)/i) {
     my $enc=$1;
     if ($enc=~/gzip/i) {
      # encode with gzip
      $respb=Compress::Zlib::memGzip($respb);
     } else {
      # encode with deflate
      my $deflater=deflateInit();
      $respb=$deflater->deflate($respb);
      $respb.=$deflater->flush();
     }
     $resph.="\nContent-Encoding: $enc";
    }
    $resph.="\nContent-Length: ".length($respb);
    print $fh $resph;
    print $fh "\n\n";
    print $fh $respb;
   }
   # close connection
   WebDone($fh);
  }
 } else {
  # connection closed
  WebDone($fh);
 }
}

sub WebDone {
 my $fh=shift;
 delete $SocketCalls{$fh};
 delete $WebCon{$fh};
 $readable->remove($fh);
}

# done with a file handle -- close him and his friend(s)
sub done {
 my $fh=shift;
 d(12);
 done2($Con{$fh}->{friend});
 done2($Con{$fh}->{forwardSpam});
 done2($fh);
}

# close a file handle & clean up associated records
sub done2 {
 my $fh=shift;
 d(13);
 return unless $fh;
 my $this=$Con{$fh};
 my $ip=$this->{ip};
 return unless $this;
 mlog($fh, "is disconnected") if $Con{$fh}->{ip} && $ConnectionLog && !($noLog && $ip=~$NLOGRE);
 print DEBUG  "closing $fh\n" if $DEBUG;
 # close the maillog if it's still open
 my $f=$this->{maillogfh};
 close $f if $f;
 # remove from the select structure
 delete $SocketCalls{$fh};
 $readable->remove($fh);
 $writable->remove($fh);
 # close it
 $fh->close;
 # delete the Connection data
 delete $Con{$fh};
 # delete the Session data & re-add sockets.
 if (exists $SMTPSession{$fh}) {
  delete $SMTPSession{$fh};
  $smtpConcurrentSessions--;
  $smtpConcurrentSessions=0 if $smtpConcurrentSessions<0;
  $readable->add($lsn) if $lsn && (!$readable->exists($lsn));
  $readable->add($lsn2) if $lsn2 && (!$readable->exists($lsn2));
  $readable->add($Relay) if $Relay && (!$readable->exists($Relay));
  $SMTPSession{Total}-- if $maxSMTPSessions;
  $SMTPSession{$ip}-- if $maxSMTPipSessions;
 }
}

# adding a socket to the Select structure and Con hash
sub addfh {
 my ($fh,$getline,$friend) =@_;
 d(14);
 $SocketCalls{$fh}=\&SMTPTraffic;
 $readable->add($fh);
 binmode($fh);
 $Con{$fh} = {};
 my $this = $Con{$fh};
 $this->{getline}  = $getline;
 $this->{friend}   = $friend;
 $this->{timestart}= time();
 $this->{timelast} = time();
}

# sendque enques a string for a socket
sub sendque {
 my ($fh,$message)=@_;
 my $l=length($message);
 print DEBUG "sq: $fh l=$l\n" if $DEBUG;
 return unless $fh && $Con{$fh};
 $writable->add($fh);
 $Con{$fh}->{outgoing}.=$message;
 if(!$Con{$fh}->{paused} && length($Con{$fh}->{outgoing}) > $OutgoingBufSize) {
  $Con{$fh}->{paused}=1;
  print DEBUG "pausing\n" if $DEBUG;
  $readable->remove($Con{$fh}->{friend});
 }
}

#####################################################################################
#                SMTP stuff

# compile the regular expression (RE) for the local domains list (LDRE)
sub setLDRE {
 SetRE(LDRE,"^($_[0])\$","i","Local Domains");
}
# compile the regular expression (RE) for the local server names list (LSRE)
sub setLSRE {
 SetRE(LSRE,"^($_[0])\$","i","LocalHost");
}

# returns true if this address is local
sub localmail {
 my $h=shift;
 $h = $1 if $h=~/\@(.*)/;
 return 1 if $localDomains && $h=~$LDRE;
 if($localDomainsFile) {
  check4update(localDomainsFile);
  return 1 if $localDomainsFile{lc $h};
 }
 0;
}

sub localmailaddress {
 my $h=shift;
 my $retcode;
 my $retmsg;
 $h = $1 if $h=~/\@(.*)/;
 # do LDAP lookup
 $current_email = "$1$h";
 $ldapflt = $LDAPFilter;
 $ldapflt =~ s/EMAILADDRESS/$current_email/g;
 print DEBUG  "doing LDAP lookup with $ldapflt in $LDAPRoot\n" if $DEBUG;


@ldaplist = split(/\|/,$LDAPHost);
$ldaplist = \@ldaplist;


 $ldap = Net::LDAP->new( $ldaplist ); 
 if(! $ldap) {
  mlog($fh,"Couldn't contact LDAP server at $LDAPHost -- check ignored");
 # seterror($fh,"451 Could not check recipient, try later\r\n",1);
  return 1;
 }
 # bind to a directory anonymous or with dn and password
 if ($LDAPLogin) {
  $mesg = $ldap->bind($LDAPLogin,
                      password => $LDAPPassword
                      );
 } else {
  # mlog($fh,"LDAP anonymous bind");
  $mesg = $ldap->bind;
 }
 $retcode = $mesg->code;
 if ($retcode) {
  # $retmsg=$mesg->error_text();
  # mlog($fh,"LDAP bind error: $retcode - Login Problem?");
  mlog($fh,"LDAP bind error: $retcode -- check ignored");
  # seterror($fh,"451 Could not check recipient, try later\r\n",1);
  return 1;
 }
 # perform a search
 $mesg = $ldap->search( base   => $LDAPRoot,
                        filter => $ldapflt,
                        attrs => ['cn']
                       );
 $retcode = $mesg->code;
 # mlog($fh,"LDAP search: $retcode");
 if($retcode > 0) {
  mlog($fh,"LDAP search error: $retcode -- check ignored");
 #seterror($fh,"451 Could not check recipient, try later\r\n",1);
  return 1;
 }
 $entry_count = $mesg->count;
 $retmsg = $mesg->entry(1);
 # mlog($fh,"LDAP Results: $entry_count : $retmsg");
 print DEBUG  "got $entry_count result(s) from LDAP lookup\n" if $DEBUG;
 $mesg = $ldap->unbind;  # take down session
 return $entry_count
}

sub serverIsSmtpDestination {
 my $server=shift;
 my $peeraddr=$server->peerhost().':'.$server->peerport();
 my $destination;
 if ($smtpDestination =~ /^(__INBOUND__:)?(\d+)$/){
   $destination = $Con{$Con{$server}->{friend}}->{localip} .':'.$2;
 }
 else{
   $destination = $smtpDestination;
 }
 return ($peeraddr eq $destination || $peeraddr eq $destination.':25');
}

sub serverIsRelayHost {
 my $server=shift;
 my $peeraddr=$server->peerhost().':'.$server->peerport();
 my $destination;
 if ($relayHost =~ /^(__INBOUND__:)?(\d+)$/){
   $destination = $Con{$Con{$server}->{friend}}->{localip} .':'.$2;
 }
 else{
   $destination = $relayHost;
 }
 return ($peeraddr eq $destination || $peeraddr eq $destination.':25');
}

# wrap long headers
sub headerWrap {
 my $header=shift;
 $header=~s/(?:([^\r\n]{60,75}?;)|([^\r\n]{60,75}) ) {0,5}(?=[^\r\n]{10,})/$1$2\r\n\t/g;

 return $header;
}

# compile the regular expression for the spam collect addresses
sub setSARE {
  my (@uad, @u, @d);
  foreach $a (split(/\|/,$_[0])) {
   if($a=~/\S\@\S/) {
    push(@uad,$a);
   } elsif( $a=~/^\@/ ) {
    push(@d,$a);
   } else {
    push(@u,$a);
   }
  }
  my @s;
  push(@s,'^('.join('|',@uad).')$') if @uad;
  push(@s,'^('.join('|',@u).')@') if @u;
  push(@s,'('.join('|',@d).')$') if @d;
  my $s=join("|",@s);
  $s='<not a valid list>' unless $s;
  SetRE(SARE,$s,'i',"Spam Addresses");
}
# compile the regular expression for the spam trap addresses
sub setSTRE {
  my (@uad, @u, @d);
  foreach $a (split(/\|/,$_[0])) {
   if($a=~/\S\@\S/) {
    push(@uad,$a);
   } elsif( $a=~/^\@/ ) {
    push(@d,$a);
   } else {
    push(@u,$a);
   }
  }
  my @s;
  push(@s,'^('.join('|',@uad).')$') if @uad;
  push(@s,'^('.join('|',@u).')@') if @u;
  push(@s,'('.join('|',@d).')$') if @d;
  my $s=join("|",@s);
  $s='<not a valid list>' unless $s;
  SetRE(STRE,$s,'i',"Spam Trap Addresses");
}
# compile the no-processing regular expression
sub setNPREL {
  my (@uad, @u, @d);
  foreach $a (split(/\|/,$_[0])) {
   if($a=~/\S\@\S/) {
    push(@uad,$a);
   } elsif( $a=~/^\@/ ) {
    push(@d,$a);
   } else {
    push(@u,$a);
   }
  }
  my @s;
  push(@s,'^('.join('|',@uad).')$') if @uad;
  push(@s,'^('.join('|',@u).')@') if @u;
  push(@s,'('.join('|',@d).')$') if @d;
  my $s=join("|",@s);
  $s='<not a valid list>' unless $s;
  SetRE(NPREL,$s,'i',"No Processing");
}
# compile the ccAddresses regular expression
sub setCCRE {
  my (@uad, @u, @d);
  for $a (split(/\|/,$_[0])) {
   if($a=~/\S\@\S/) {
    push(@uad,$a);
   } elsif( $a=~/^\@/ ) {
    push(@d,$a);
   } else {
    push(@u,$a);
   }
  }
  my @s;
  push(@s,'^('.join('|',@uad).')$') if @uad;
  push(@s,'^('.join('|',@u).')@') if @u;
  push(@s,'('.join('|',@d).')$') if @d;
  my $s=join("|",@s);
  $s='<not a valid list>' unless $s;
  SetRE(CCRE,$s,'i',"CC Adresses");
}
# compile the ccArchivAddressesRec regular expression
sub setCCARRE {
  my (@uad, @u, @d);
  for $a (split(/\|/,$_[0])) {
   if($a=~/\S\@\S/) {
    push(@uad,$a);
   } elsif( $a=~/^\@/ ) {
    push(@d,$a);
   } else {
    push(@u,$a);
   }
  }
  my @s;
  push(@s,'^('.join('|',@uad).')$') if @uad;
  push(@s,'^('.join('|',@u).')@') if @u;
  push(@s,'('.join('|',@d).')$') if @d;
  my $s=join("|",@s);
  $s='<not a valid list>' unless $s;
  SetRE(CCARRE,$s,'i',"CCArchiv Adresses Receiver");
}
# compile the regular expression for the bounce senders addresses
sub setBSRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^\s*$'); # null sender address
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(BSRE,$s,'i',"Bounce Senders");
}

# compile the regular expression for no-logged addresses
sub setNLOGRE {
 SetRE(NLOGRE,"^($_[0])",'i','Don\'t log IP\'s');
}

# compile the regular expression for no-delayed addresses
sub setNDRE {
 SetRE(NDRE,"^($_[0])",'i','Don\'t delay IP\'s');
}

# compile the regular expression for no-validated bounces addresses
sub setNSRSRE {
 SetRE(NSRSRE,"^($_[0])",'i','Don\'t validate bounces IP\'s');
}

# compile the regular expression for denied IP addresses
sub setDSMTPCFRE {
 SetRE(DSMTPCFRE,"^($_[0])",'i','Deny connections from IP\'s');
}

# compile the regular expression for exported extreme blocked
sub setEXEXRE {
 SetRE(EXEXRE,"^($_[0])",'i','Deny connections from exported IP\'s');
}
sub stateReset {
 my $fh=shift;
 my $this=$Con{$fh};
$this->{mailfrom}=$this->{rcpt}=$this->{header}=$this->{myheader}=$this->{mypbreason}=$this->{messagereason}='';
 $this->{noprocessing}=$this->{isbounce}=$this->{invalidSRSBounce}=$this->{delayed}=$this->{ispip}=$this->{nodelay}=$this->{spamfound}=$this->{acceptall}=$this->{testmode}=$this->{messagescore}=$this->{contentonly}=$this->{whitelisted}=0;
$this->{def_fh}=$this->{def_reason}=$this->{def_log}=$this->{def_error}=$this->{def_testmode}=$this->{def_slok}=$this->{def_done}=$this->{def_status}=0;
 $this->{allLoveSpam}=$this->{allLoveBaysSpam}=$this->{allLoveBlSpam}=$this->{allLovePBSpam}=$this->{allLoveISSpam}=$this->{allLoveHlSpam}=0;
 $this->{allLoveSPFSpam}=$this->{allLoveRBLSpam}=$this->{allLoveSRSSpam}=0;
 $this->{reporttype}=-1;
}

# a line of input has been received from the smtp client
sub getline {
 my($fh,$l)=@_;
 d(15);
 my $this=$Con{$fh};
 my $server=$this->{friend};
 my $reply;
 print DEBUG  "gl: <$l>\n" if $DEBUG;

 if($l=~/^ *(helo|ehlo) .*?([^<>,;\"\'\(\)\s]+)/i) {
  my $helo = $2;
  my $helo2 = $helo;
  $helo=~s/(\W)/\\\$1/g;
  $this->{helo}=$helo2;
  $this->{rcvd}=~s/=\)/=$helo2\)/;
  $this->{rcvd}=headerWrap($this->{rcvd}); # wrap long lines
 } elsif($l=~/mail from:\s*<?($EmailAdrRe\@$EmailDomainRe|\s*)>?/io) {
  my $fr=$1;

 stateReset($fh); # reset everything
 $this->{mailfrom}=$fr;
 
 my $mf =lc $this->{mailfrom};
 
 if($contentOnlyRe && $mf=~('('.$contentOnlyReRE.')')){
 $this->{contentonly}=1;

 }
 if($contentOnlyRe && $this->{ip}=~('('.$contentOnlyReRE.')')){
 $this->{contentonly}=1;
 pbWhiteAdd($this->{ip},"ContentOnly:ip=$1");
 }
 if($contentOnlyRe && $this->{helo}=~('('.$contentOnlyReRE.')')){
 $this->{contentonly}=1;
 pbWhiteAdd($this->{ip},"ContentOnly:helo=$1");
 }
 if ($whiteListedDomains && $this->{mailfrom}=~$WLDRE) {
 $this->{whitelisted}=1;
 pbBlackDelete($this->{ip});
 pbWhiteAdd($this->{ip},"WhiteDomain:$this->{mailfrom}");
 }
 $this->{ispip}=1 if ($ispip && $this->{ip}=~$ISPRE);
 $this->{nodelay}=1 if ($noDelay && $ip=~$NDRE);
 $this->{acceptall}=1 if ($acceptAllMail && $ip=~$AMRE);
 
 if ($Whitelist{$mf}) {
 $this->{whitelisted}=1;
 pbWhiteAdd($this->{ip},"Whitelist:$this->{mailfrom}");
 }
  if ($noProcessing && $mf=~$NPREL) {
 $this->{noprocessing}=1;
}
  if ($npRe && $mf=~('('.$npReRE.')')) {
 $this->{noprocessing}=1;
}

 	if (!PBExtremeOK($fh,$this->{ip})) {
 	my $reply=$PenaltyError ? "$PenaltyError" : "550 5.7.7 Access denied" ;
	seterror($fh,$reply,1);
 	done($fh);
	return;
	}
 if (!$fhTestMode) {
  if (!$this->{relayok}) {
	if (!ForgedHeloOK($fh)) {

	seterror($fh,"554 5.7.7 Helo invalid(forged)",1);

  	done($fh);
  return;}
  }
  }
    
 my $ip=$this->{ip};
if ( !$this->{whitelisted} || ($this->{whitelisted} && $RBLWL)) {	
if ($ForceRBLCache || ($RBLFailLog>=6 && (!$rblTestMode) && (!$rblSpamLovers))) {
	if (!RBLCacheOK($fh,$this->{ip}))  {
	return;}
	}}
  



  if (serverIsSmtpDestination($server)) {
   $this->{isbounce}=($this->{mailfrom}=~$BSRE ? 1 : 0);
  } elsif ($EnableSRS && $CanUseSRS) {
   # rewrite sender addresses when relaying through Relay Host
   my $tmpfrom;
   my $srs=new Mail::SRS(
    Secret=>$SRSSecretKey,
    MaxAge=>$SRSTimestampMaxAge,
    HashLength=>$SRSHashLength,
    AlwaysRewrite=>1
   );
   if (!eval{$tmpfrom=$srs->reverse($this->{mailfrom})} &&
        eval{$tmpfrom=$srs->forward($this->{mailfrom},$SRSAliasDomain)}) {
    $l =~ s/\Q$this->{mailfrom}\E/$tmpfrom/;
   }
  }
 } elsif($l=~/rcpt to: *(.*)/i) {
  my $e=$1;
  my ($u,$h);
  #enforce valid email address pattern
  if ($CanUseAddress && $DoRFC822) {
   if ($l=~/rcpt to:\s*<*([^\r\n>]*).*/i) {
    my $RO_e=$1;
    if (!Email::Valid->address($RO_e)) {
     # couldn't understand recipient
     sendque($fh, "553 Malformed address: $RO_e\r\n");
     mlog($fh,"malformed address: '$RO_e'");
     $Stats{rcptRelayRejected}++;
     delayWhiteExpire($fh);
     return;
    }
   }
  }
  if ($EnableSRS && $CanUseSRS) {
   if ($this->{isbounce}) {
    # validate incoming bounces
    my $tmpto;
    my $srs=new Mail::SRS(
     Secret=>$SRSSecretKey,
     MaxAge=>$SRSTimestampMaxAge,
     HashLength=>$SRSHashLength,
     AlwaysRewrite=>1
    );
    if ($e=~/^<?(SRS0[=+-][^\r\n>]*).*/i) {
     if (eval{$tmpto=$srs->reverse($1)}) {
      $l=~s/\Q$1\E/$tmpto/;
      $e=<$tmpto>;
     } else {
      $this->{invalidSRSBounce}=1;
     }
    } elsif ($e=~/^<?(SRS1[=+-][^\r\n>]*).*/i) {
     if (eval{$tmpto=$srs->reverse($1)}) {
      if (eval{$_=$srs->reverse($tmpto)}) {
       $l=~s/\Q$1\E/$_/;
       $e=<$_>;
      } else {
       sendque($fh,"551 5.7.1 User not local; please try <$tmpto> directly\r\n");
       mlog($fh,"user not local; please try <$tmpto> directly");
       $Stats{rcptRelayRejected}++;
       pbAdd($this->{ip},$rlValencePB,"RelayAttempt") if $rlValencePB>0;
       return;
      }
     } else {
      $this->{invalidSRSBounce}=1;
     }
    } else {
     $this->{invalidSRSBounce}=1;
    }
   } elsif (serverIsSmtpDestination($server) && $e=~/^<?(SRS[01][=+-][^\r\n>]*).*/i) {
    sendque($fh,"550 5.7.6 SRS only supported in DSN\r\n");
    mlog($fh,"SRS only supported in DSN: $e");
    $Stats{rcptRelayRejected}++;
    pbAdd($this->{ip},$rlValencePB,"RelayAttempt") if $rlValencePB>0;
    return;
   }
  }
  if($e=~/[\!\%\@]\S*\@/) {
   # blatent attempt at relaying
   sendque($fh, $NoRelaying."\r\n");
   mlog($fh,"relay attempt blocked for (evil): $e");
	pbAdd($this->{ip},$rlValencePB,"RelayAttempt") if $rlValencePB>0;
   $Stats{rcptRelayRejected}++;
   delayWhiteExpire($fh);
   return;
  } elsif($e=~/([a-z\-_\.]+)!([a-z\-_\.]+)$/i) {
   # someone give me one good reason why I should support bang paths! grumble...
   $u="$2@";
   $h=$1;
  } elsif($l=~/rcpt to:.*?($EmailAdrRe\@)($EmailDomainRe)/io) {
   ($u,$h)=($1,$2);
  } elsif($defaultLocalHost && $l=~/rcpt to:.*?<($EmailAdrRe)>/io) {
   ($u,$h)=($1,$defaultLocalHost);
   $u.='@';
  } else {
   # couldn't understand recipient
   sendque($fh, $NoRelaying."\r\n");
   mlog($fh,"relay attempt blocked for (parsing): $e");
   pbAdd($this->{ip},$rlValencePB,"RelayAttempt") if $rlValencePB>0;

   $Stats{rcptRelayRejected}++;
   delayWhiteExpire($fh);
   return;
  }
  my $rcptislocal=localmail($h);
  
  # skip check when RELAYOK
  if (!$this->{relayok}) {
  
 
   # Need Check?
   if($LocalAddresses_Flat || $DoLDAP) {
    $this->{islocalmailaddress}=0;
   }
   # check recipient against flat list?
   if($LocalAddresses_Flat && "$u$h"=~$LAFRE) {
    $this->{islocalmailaddress}=1;
    print DEBUG  "$u$h validated by flat LocalAddresses list\n" if $DEBUG;
   }
   # Need another check?
   if (!$this->{islocalmailaddress}) {
    # check recipient against LDAP ?
    if ($DoLDAP) {
     if ($CanUseLDAP) {
      $this->{islocalmailaddress}=localmailaddress($h);
     } else {
      $this->{islocalmailaddress}=localmail($h);
      mlog($fh,"Net::LDAP not installed, cannot check: $u$h");
     }
    }
   }
  } else {
   $this->{islocalmailaddress}=localmail($h);
  }
  if(!($this->{relayok}) && (!$rcptislocal || ($u.$h)=~/\%/) || $u =~/\@\w+/) {
   sendque($fh, $NoRelaying."\r\n");
   mlog($fh,"relay attempt blocked for: $u$h");
   pbAdd($this->{ip},$rlValencePB,"RelayAttempt") if $rlValencePB>0;
   $Stats{rcptRelayRejected}++;
   delayWhiteExpire($fh);
   return;
  }
  if ($noProcessing) {
   if("$u$h"=~$NPREL) { $this->{noprocessing}|=1 } else { $this->{noprocessing}|=2 }
  }
  if ($rcptislocal && $spamaddresses && "$u$h"=~$SARE) {
   $this->{addressedToSpamBucket}=1;
  }
  if ($rcptislocal && $spamtrapaddresses && "$u$h"=~$STRE) {
   $this->{addressedToSpamTrap}=1;

   pbAdd($this->{ip},$stValencePB,"SpamTrap:$u$h") ;
   $Stats{spamtrap}++;
   delayWhiteExpire($fh);
   done($fh);
   return;
  }
  
  my $mSLRE=$spamLovers && "$u$h"=~$SLRE;
  my $mBSLRE=$baysSpamLovers && "$u$h"=~$BSLRE;
  my $mBLSLRE=$blSpamLovers && "$u$h"=~$BLSLRE;
  my $mHLSLRE=$hlSpamLovers && "$u$h"=~$HLSLRE;
  my $mSPFSLRE=$spfSpamLovers && "$u$h"=~$SPFSLRE;
  my $mRBLSLRE=$rblSpamLovers && "$u$h"=~$RBLSLRE;
  my $mSRSSLRE=$srsSpamLovers && "$u$h"=~$SRSSLRE;
  my $mDLSLRE=$delaySpamLovers && "$u$h"=~$DLSLRE;
  my $mPBSLRE=$pbSpamLovers && "$u$h"=~$PBSLRE;
  my $mISSLRE=$isSpamLovers && "$u$h"=~$ISSLRE;
  if ($rcptislocal && ($mSLRE || $mBSLRE || $mBLSLRE || $mHLSLRE || $mSPFSLRE || $mRBLSLRE || $mSRSSLRE || $mDLSLRE || $mPBSLRE || $mISSLRE)) {
   $this->{allLoveSpam}|=1;
  } else {
   $this->{allLoveSpam}=2;
  }
  if ($rcptislocal && ($mBSLRE || $mSLRE)) { $this->{allLoveBaysSpam}|=1 } else { $this->{allLoveBaysSpam}=2 }
  if ($rcptislocal && ($mBLSLRE || $mSLRE)) { $this->{allLoveBlSpam}|=1 } else { $this->{allLoveBlSpam}=2 }
  if ($rcptislocal && ($mHLSLRE || $mSLRE)) { $this->{allLoveHlSpam}|=1 } else { $this->{allLoveHlSpam}=2 }
  if ($rcptislocal && ($mSPFSLRE || $mSLRE)) { $this->{allLoveSPFSpam}|=1 } else { $this->{allLoveSPFSpam}=2 }
  if ($rcptislocal && ($mRBLSLRE || $mSLRE)) { $this->{allLoveRBLSpam}|=1 } else { $this->{allLoveRBLSpam}=2 }
  if ($rcptislocal && ($mSRSSLRE || $mSLRE)) { $this->{allLoveSRSSpam}|=1 } else { $this->{allLoveSRSSpam}=2 }
  if ($rcptislocal && ($mPBSLRE || $mSLRE)) { $this->{allLovePBSpam}|=1 } else { $this->{allLoveISSpam}=2 }
  if ($rcptislocal && ($mIFSLRE || $mSLRE)) { $this->{allLoveISSpam}|=1 } else { $this->{allLovePBSpam}=2 }
  if($EmailInterfaceOk && $this->{relayok} && $rcptislocal) {
   if(lc $u eq lc "$EmailSpam\@") {
    $this->{reporttype}=0;
    $this->{getline}=\&NewListReport if $EmailErrorsModifyWhite;
    $this->{getline}=\&SpamReport if !$EmailErrorsModifyWhite;
    mlog($fh,"email spamreport");
    $Stats{rcptReportSpam}++;
    sendque($fh,"250 OK\r\n");
    return;
   } elsif(lc $u eq lc "$EmailHam\@") {
    $this->{reporttype}=1;
    $this->{getline}=\&NewListReport if $EmailErrorsModifyWhite;
    $this->{getline}=\&SpamReport if !$EmailErrorsModifyWhite;
    mlog($fh,"email hamreport");
    $Stats{rcptReportHam}++;
    sendque($fh,"250 OK\r\n");
    return;
   } elsif(lc $u eq lc "$EmailWhitelistAdd\@") {
    $this->{reporttype}=2;
    $this->{getline}=\&ListReport;
    mlog($fh,"email whitelist addition");
    $Stats{rcptReportWhitelistAdd}++;
    foreach $a (split(/ /,$this->{rcpt})) {ListReportExec($a,$this)};
    sendque($fh,"250 OK\r\n");
    return;
   } elsif(lc $u eq lc "$EmailWhitelistRemove\@") {
    $this->{reporttype}=3;
    $this->{getline}=\&ListReport;
    mlog($fh,"email whitelist deletion");
    $Stats{rcptReportWhitelistRemove}++;
    foreach $a (split(/ /,$this->{rcpt})) {ListReportExec($a,$this)};
    sendque($fh,"250 OK\r\n");
    return;
   } elsif(lc $u eq lc "$EmailRedlistAdd\@") {
    $this->{reporttype}=4;
    $this->{getline}=\&ListReport;
    mlog($fh,"email redlist addition");
    $Stats{rcptReportRedlistAdd}++;
    foreach $a (split(/ /,$this->{rcpt})) {ListReportExec($a,$this)};
    sendque($fh,"250 OK\r\n");
    return;
   } elsif(lc $u eq lc "$EmailRedlistRemove\@") {
    $this->{reporttype}=5;
    $this->{getline}=\&ListReport;
    mlog($fh,"email redlist deletion");
    $Stats{rcptReportRedlistRemove}++;
    foreach $a (split(/ /,$this->{rcpt})) {ListReportExec($a,$this)};
    sendque($fh,"250 OK\r\n");
    return;
   }
  }

 
  $this->{rcptValidated}=$this->{rcptNonexistent}=0;
  if ($this->{addressedToSpamBucket}) {
   # accept SpamBucket addresses in every case
   $this->{rcpt}.="$u$h ";
  } elsif ($LocalAddresses_Flat || $DoLDAP) {
   if (($this->{islocalmailaddress}) || ($this->{relayok}) && ! $rcptislocal) {
    if (serverIsSmtpDestination($server) && !Delayok($fh,"$u$h")) {
     $this->{delayed}=1;
     if (!$this->{isbounce}) {
      if ($DelayError) {
       $reply = $DelayError."\r\n";
      } else {
       $reply = "451 4.7.1 Please try again later\r\n";
      }
      sendque($fh, $reply);
      mlog($fh,"recipient delayed: $u$h") if $DelayLog;
      return;
     }
    }
    $this->{rcpt}.="$u$h ";
    mlog($fh,"recipient accepted: $u$h") if $ValidateLog;
    $this->{rcptValidated}=1;
    
 } else {
    sleep ($NoValidRecipientSleepTime) if ($this->{ispip}!=1);

    if ($NoValidRecipient) {
     $reply = $NoValidRecipient."\r\n";
    } else {
     $reply = "550 5.1.1 User unknown\r\n";
    }
    $reply =~ s/EMAILADDRESS/$u$h/g;
    sendque($fh, $reply);
    mlog($fh,"invalid address rejected: $u$h") if $ValidateLog;
    pbAdd($this->{ip},$irValencePB,"InvalidAddress") if $irValencePB>0;
    $Stats{rcptNonexistent}++;
    $this->{rcptNonexistent}=1;
    # increment error and drop line if necessary
    if($this->{serverErrors}++ > $MaxErrors) {
     mlog($fh,"max errors ($MaxErrors) exceeded -- dropping connection");
     pbAdd($this->{ip},$meValencePB,"MaxErrors") if $meValencePB>0;
     $Stats{msgMaxErrors}++;
     
     delayWhiteExpire($fh);
     done($fh);
    }
    return;
   }
  } elsif (serverIsSmtpDestination($server) && !Delayok($fh,"$u$h")) {
   $this->{delayed}=1;
   if (!$this->{isbounce}) {
    if ($DelayError) {
     $reply = $DelayError."\r\n";
    } else {
     $reply = "451 4.7.1 Please try again later\r\n";
    }
    sendque($fh, $reply);
    mlog($fh,"recipient delayed: $u$h") if $DelayLog;
    return;
   }
  } else {
   $this->{rcpt}.="$u$h ";
   mlog($fh,"recipient accepted unchecked: $u$h") if $ValidateLog;
  }
  # update Stats
  if ($this->{noprocessing}==1) {

   $Stats{rcptUnprocessed}++;
  } elsif ($this->{addressedToSpamBucket}) {
   $Stats{rcptSpamBucket}++;
  } elsif ($this->{allLoveSpam} & 1) {
   $Stats{rcptSpamLover}++;
  } elsif ($this->{rcptValidated}) {
    $Stats{rcptValidated}++;
  } elsif ($this->{rcptNonexistent}) {
  
    $Stats{rcptNonexistent}++;
  } elsif ($rcptislocal) {
   $Stats{rcptUnchecked}++;
  } elsif ($Whitelist{lc "$u$h"})
   {pbWhiteAdd($this->{ip},"whitelisted");
   $Stats{rcptWhitelisted}++;
  } else {
   $Stats{rcptNotWhitelisted}++;
  }
 } elsif( $l=~/^ *XEXCH50 +(\d+)/i ) {
  $this->{skipbytes}=$1;
  print DEBUG "XEXCH50 b=$1\n" if $DEBUG;
 } elsif( $l=~/^ *DATA/i || $l=~/^ *BDAT (\d+)/i ) {
  if($1) {
   $this->{bdata}=$1;
  } else {
   delete $this->{bdata};
  }
  $this->{rcpt}=~s/\s$//;
  # drop line if no recipients left
  if ($this->{rcpt}!~/@/) {
   # possible workaround for GroupWise bug
   if ($this->{delayed}) {
    if ($DelayError) {
     $reply = $DelayError."\r\n";
    } else {
     $reply = "451 4.7.1 Please try again later\r\n";
    }
    sendque($fh, $reply);
    mlog($fh,"DATA phase delayed") if $DelayLog;
    $Stats{msgDelayed}++;
    return;
   }
   mlog($fh,"no recipients left -- dropping connection");
   $Stats{msgNoRcpt}++;

   delayWhiteExpire($fh);
   pbAdd($this->{ip},$erValencePB,"NeedRecipient") if $erValencePB>0;
   seterror($fh,"503 5.5.2 Need Recipient\r\n",1);
   return;
  }
  if($this->{noprocessing}==1 || ($noProcessing && $this->{mailfrom}=~$NPREL) ) {
   # all addresses are on no-processing list
   $this->{noprocessing}=1;
   $this->{myheader}=''; # reset myheader
   if($BlockNPExes) {
    $this->{getline}=\&whitebodyNoExe;
   } else {
    $this->{getline}=\&whitebody;
    mlog($fh,"message proxied without processing - (attachments unchecked)");
    $Stats{noprocessing}++;
    

  $Stats{nopsize}=$Stats{nopsize} + $this->{maillength};
   if ($Stats{noprocessing}>0) {
   $Stats{nopavsize}=int($Stats{nopsize} / $Stats{noprocessing});
   }
   }
  } elsif ($this->{isbounce} && $this->{delayed}) {
   if ($DelayError) {
    $reply = $DelayError."\r\n";
   } else {
    $reply = "451 4.7.1 Please try again later\r\n";
   }
   sendque($fh, $reply);
   mlog($fh,"bounce delayed");
   $Stats{msgDelayed}++;
   return;
  } else {
   MaillogStart($fh); # notify the stream logging to start logging
   $this->{getline}=\&getheader;
  }
 } elsif( $l=~/^ *RSET/i ) {
  stateReset($fh); # reset everything
 }
 sendque($server, $l);
}

# compile the blacklisted domains regular expression
sub setBLDRE {
 SetRE(BLDRE1,"($_[0])\$","i","Blacklisted Domains");
 SetRE(BLDRE2,"($_[0]) ",'i',"Blacklisted Domains");
}

# compile the helo-blacklist ignore regular expression
sub setHBIRE {
 SetRE(HBIRE,"^($_[0])\$","i","HELO Blacklisted Ignore");
}

# get the header part of the DATA.
sub getheader {
 my($fh,$l)=@_;
 d(18);
 my $this=$Con{$fh};
 if($this->{inerror}) {
  my $server=$this->{friend};
  $this->{getline}=\&getline;
  sendque($server, $l);
  return;
 }
 $this->{header}.=$l;
 if($l=~/^\.?[\r\n]*$/) {
  $this->{maillength}=length($this->{header});
  my $slok;
  # header is done

  if($contentOnlyRe && $this->{header}=~('('.$contentOnlyReRE.')')) {
  $subre=substr($1,0,$RegExLength);
  $this->{contentonly}=1;}
  if($npRe && $this->{header}=~('('.$npReRE.')')) {
  $subre=substr($1,0,$RegExLength);
  pbBlackClear($fh,$myip);
  pbWhiteAdd($this->{ip},"NPRE:$subre");
  mlog($fh,"Noprocessing RE: '$subre'");

  $this->{noprocessing}=1;
  
   $this->{myheader}=''; # reset myheader
  
   if ($SPFNP) { SPFok($fh);}
   if($BlockNPExes) {
    $this->{getline}=\&whitebodyNoExe;
   } else {
    mlog($fh,"message proxied without processing - (attachments unchecked)") if ($AttachmentLog);
    $Stats{noprocessing}++;
    isnotspam($fh);
   }
} elsif(onwhitelist($fh,$this->{header})) {

 if ((!$SPFWL || ($SPFWL && SPFok($fh))) && (!$RBLWL || ($RBLWL && RBLok($fh)))) {
    if($BlockWLExes) {
     $this->{getline}=\&whitebodyNoExe;
    } else {
    my $fn=Maillog($fh,'',2); # tell maillog this isn't spam
    $fn=' -> '.$fn if !$fn=="";
    $fn="" if !$fileLogging;
    $SpamProb=0; addSpamProb($fh,1);
    isnotspam($fh);
    mlog($fh,"local or whitelisted - (attachments unchecked)$fn") ;
    }
   }
} elsif($blackListedDomains && ($this->{mailfrom}=~$BLDRE1 || $this->{senders}=~$BLDRE2)) {
   $slok=$this->{allLoveBlSpam}==1;
   $Stats{blacklisted}++ unless $slok;
   pbAdd($this->{ip},$blValencePB,"BlacklistedDomain") if $blValencePB>0;
   thisIsSpam($fh,'has blacklisted domain',$blDomainLog,$SpamError,$blTestMode,$slok,0);
   } elsif($this->{addressedToSpamBucket}) {
   $slok=$this->{allLoveSpam}==1;

   $Stats{spambucket}++ unless $slok;
   $SpamProb=1;
   pbAdd($this->{ip},$saValencePB,"SpamAddress") if $saValencePB>0;
   thisIsSpam($fh,'has spam address',$spamBucketLog,$SpamError,$sbTestMode,$slok,0);
   } elsif($fhTestMode!=0 && (!ForgedHeloOK($fh))) {
   $slok=$this->{allLoveHlSpam}==1;
   $SpamProb=1;
   thisIsSpam($fh," Helo invalid(forged):'$this->{helo}'",7,$SpamError,1,0,0);
   } elsif (!LocalSenderOK($fh,$this->{ip})) {
    $slok=$this->{allLoveISSpam}==1;
	$Stats{senderInvalidLocals}++ unless $slok;
	$reply=$SenderInvalidError;
	$SpamProb=1;
    $reply =~ s/REASON/Unknown User In Local Domain(Sender)/g;  
    
    thisIsSpam($fh,"Validate Sender: Unknown User in Local Domain",$spamISLog,$reply,$flsTestMode,$slok,0);
    } elsif (!validHeloOK($fh,$this->{helo})) {
    $slok=$this->{allLoveISSpam}==1;
	$Stats{invalidHelo}++ unless $slok;
	$reply=$SenderInvalidError;
	$SpamProb=1;
    $reply =~ s/REASON/Invalid HELO Format/g; 
    thisIsSpam($fh,"Validate Sender: Invalid HELO Format '$this->{helo}'",$spamHeloLog,$reply,$ihTestMode,$slok,0);
} elsif (!invalidHeloOK($fh,$this->{helo})) {
    $slok=$this->{allLoveISSpam}==1;
	$Stats{invalidHelo}++ unless $slok;
	$reply=$SenderInvalidError;
	$SpamProb=1;
    $reply =~ s/REASON/Invalid HELO Format/g; 
    thisIsSpam($fh,"Validate Sender: Invalid HELO Format '$this->{helo}'",$spamHeloLog,$reply,$ihTestMode,$slok,0);
    } elsif (!MXAOK($fh)) {
    $slok=$this->{allLoveISSpam}==1;
    $Stats{mxaMissing}++ unless $slok;
    $reply=$SenderInvalidError;
    $SpamProb=1;
    $reply =~ s/REASON/Missing MX and A record/g;
    thisIsSpam($fh,"Validate Sender: missing MX/A record",$spamISLog,$reply,$mxaTestMode,$slok,0);
    } elsif (!PTROK($fh)) {
    $slok=$this->{allLoveISSpam}==1;
    $reply=$SenderInvalidError;
    $SpamProb=1;
    $reply =~ s/REASON/Missing PTR Record/g;
    $Stats{ptrMissing}++ unless $slok;
    thisIsSpam($fh,"Validate Sender: Missing PTR record",$spamISLog,$reply,$ptrTestMode,$slok,0);

    } elsif(!BlackHeloOK($fh,$this->{helo})) {
   $slok=$this->{allLoveHlSpam}==1;
    $this->{testmode} = ($hlTestMode!=0 || $useHeloBlacklist==4);
    $Stats{helolisted}++ unless $slok;
   thisIsSpam($fh,"Validate Sender: '$this->{helo}' in HELO-Blacklist",$spamHeloLog,$SpamError,$hlTestMode,$slok,0);
  
  } elsif($this->{invalidSRSBounce} && $SRSValidateBounce && !($ispip && $this->{ip}=~$ISPRE) && !($noSRS && $this->{ip}=~$NSRSRE)) {
   $slok=$this->{allLoveSRSSpam}==1;
   $Stats{msgNoSRSBounce}++ unless $slok;
   thisIsSpam($fh,'bounce address not SRS signed',$SRSFailLog,'550 5.7.5 Bounce address not SRS signed',$srsTestMode,$slok,0);



  } elsif(SPFok($fh) && RBLok($fh)) { 
   # cleared all the above rules - off to Bayesian testing if SPF and RBL is OK.
   # and no testcheck was successful.
  
   $this->{getline}=\&getbody;
  }
 }
}

# do SPF (sender policy framework) checks
sub SPFok {
 my($fh)=@_;
 my $this=$Con{$fh};
 d('SPFok');
return 1 if $this->{contentonly};
return 1 unless (!$this->{relayok} && $CanUseSPF && $ValidateSPF && !($ispip && $this->{ip}=~$ISPRE));

my $query = eval {new Mail::SPF::Query (ipv4       => $this->{ip},
                                   sender     => $this->{mailfrom},
                                   helo       => $this->{helo},
                                   trusted    => 1,
                                   guess      => $LocalPolicySPF,
                                   myhostname => $myName,
                                   sanitize   => 1,
                                   debug      => $DebugSPF,
                                   debuglog   => sub { mlog($fh,"debug: @_")
} );};

# add exception check and log
if ($@) {

	return 1;
}
 my ($per_result, $smtp_comment, $header_comment);
 foreach my $recip (split(' ', $this->{rcpt})) {
  ($per_result, $smtp_comment, $header_comment) = $query->result2($recip);
  # Keep processing SPF records until all recipients are checked otherwise breakout if fail
  if ($per_result eq 'fail') {last;}
 }
 my $received_spf;
 $received_spf = "Received-SPF: $per_result ($header_comment) client-ip=$this->{ip};";
 $received_spf .= " envelope-from=$this->{mailfrom};" if ( defined( $this->{mailfrom} ) );
 $received_spf .= " helo=$this->{helo};" if ( defined( $this->{helo}) );
 mlog($fh,$received_spf) if $SPFLog;
 # add to our header; merge later, when client sent own headers
 $this->{myheader}.="X-Assp-$received_spf\r\n" if $AddSPFHeader;
 if ($per_result eq 'fail') {
  # This email fails SPF rules for the sending domain.  Apply SPF Failure Rules
  $SpamProb=1;
  my $slok=$this->{allLoveSPFSpam}==1;
  $Stats{spffails}++ unless $slok;
  thisIsSpam($fh,'failed SPF checks',$SPFFailLog,"550 5.7.1 $smtp_comment",$spfTestMode,$slok,0);
  return 0;
 } else {
  return 1;
 }
}

# do RBL checks

sub RBLok {
 my($fh)=@_;
 my $this=$Con{$fh};
 d('RBLok');

 return 1 unless (!$this->{relayok} && $CanUseRBL && $ValidateRBL && !($ispip && $this->{ip}=~$ISPRE));
return 1 if $this->{contentonly};
return 1 if $this->{nodelay};
my $ip=ipNetwork($this->{ip},($RBLUseNetblocks ? 24 : 32));
return  1 if (exists $PBWhite{$ip});
 my $rbl = eval {RBL->new (lists       => [@rbllist],
                     server      => $nameservers[0],
                     max_hits    => $RBLmaxhits,
                     max_replies => $RBLmaxreplies,
                     query_txt   => 1,
                     max_time    => $RBLmaxtime,
                     timeout     => $RBLsocktime);};
 # add exception check 
if ($@) {return 1;}                    
 my ($received_rbl,$rbl_result,$lookup_return);
 $lookup_return = $rbl->lookup($this->{ip});
 my @listed_by  = $rbl->listed_by();
 $rbls_returned = $#listed_by + 1;
 if ($rbls_returned >= $RBLmaxhits ) {
  $received_rbl = "Received-RBL: fail ($myName: local policy) rbl=@listed_by; client-ip=$this->{ip};";
  if ($RBLLog) {
#  mlog(0,"lookup returned:  $lookup_return");
    mlog($fh,$received_rbl);
  }
  # add to our header; merge later, when client sent own headers
  $this->{myheader}.="X-Assp-$received_rbl\r\n" if $AddRBLHeader;
  $SpamProb=1;
  my $slok=$this->{allLoveRBLSpam}==1;
  $Stats{rblfails}++;
  pbWhiteDelete($this->{ip});
  if ($DoRBLCache>0) {
  RBLCacheAdd($this->{ip},"@listed_by") ;
  } else {
  
  pbAdd($this->{ip},$rblValencePB,"RBL-Failed:@listed_by") if $rblValencePB>0;
  }

  my $reply=$RBLError;
  $SpamProb=1;
  $reply =~ s/RBLLISTED/@listed_by/g;
  thisIsSpam($fh,'failed RBL checks',$RBLFailLog,"$reply",$rblTestMode,$slok,0);
 return 0;
 } elsif ($rbls_returned > 0) {
  $received_rbl = "Received-RBL: neutral ($myName: local policy) rbl=@listed_by; client-ip=$this->{ip};";
 } else {
  $received_rbl = "Received-RBL: pass ($myName: local policy) rbl=none; client-ip=$this->{ip};";
 }
 if ($RBLLog) {
# mlog(0,"lookup returned: $lookup_return"); 
   mlog($fh,$received_rbl);
 }
 # add to our header; merge later, when client sent own headers
 $this->{myheader}.="X-Assp-$received_rbl\r\n" if $AddRBLHeader;
 return 1;
}

sub ipNetwork {
 my ($ip,$cidr)=@_;
 my $u32 = unpack "N", pack "CCCC", split /\./, $ip;
 my $mask = unpack "N", pack "B*", "1" x $cidr . "0" x (32 - $cidr );
 return join ".", unpack "CCCC", pack "N", $u32 & $mask;
}

sub ipBroadcast {
 my ($ip,$cidr)=@_;
 my $u32 = unpack "N", pack "CCCC", split /\./, $ip;
 my $mask = unpack "N", pack "B*", "1" x $cidr . "0" x (32 - $cidr );
 return join ".", unpack "CCCC", pack "N", $u32 | ~$mask;
}

sub formatTimeInterval {
 my $interval=shift;
 my $res;
 $res.=$_."d " if local $_=int($interval/(24*3600)); $interval%=(24*3600);
 $res.=$_."h " if $_=int($interval/3600); $interval%=3600;
 $res.=$_."m " if $_=int($interval/60); $interval%=60;
 $res.=$interval."s " if ($interval || !defined $res);
 $res=~s/\s$//;
 return $res;
}




# do forged local sender 
sub ForgedHeloOK {
  my($fh,$rcpt)=@_;
 my $this=$Con{$fh};
 d('ForgedHeloOK');


return 1 if ($this->{relayok});
return 1 if ($this->{ispip}==1);
return 1 if ($heloBlacklistIgnore && $heloBlacklistIgnore && $this->{helo} =~ $HBIRE);  
return 1 if ($DoFakedLocalHelo==0);
return 1 if ($Whitelist{$this->{mailfrom}} && $DoFakedWL);
return 1 if ($noProcessing && $this->{mailfrom}=~$NPREL && $DoFakedNP);

$tlit="";
$tlit="Sender Validation:blocked:" if $DoFakedLocalHelo==1;
$tlit="Sender Validation:logging:" if $DoFakedLocalHelo==2;
$tlit="Sender Validation:scoring + $fhValencePB:" if $DoFakedLocalHelo==3;
 
		
		if (($localDomains && $this->{helo} =~$LDRE) || $this->{helo} eq 'localhost' || $this->{helo} eq 'friend'|| ($localhostname && $this->{helo} eq $localhostname ) || ($localhostname && $this->{helo} eq $localhostaddr)  || ($myServerRe && $this->{helo} =~$myServerRe)) {

			if ($Whitelist{$this->{mailfrom}}) {
			mlog($fh,"$tlit  whitelisted/forged HELO: '$this->{helo}'") if $ValidateSenderLog; 
			AdminReportMail($this->{ip},"$this->{ip} blocked, $this->{mailfrom} is whitelisted and has forged HELO: '$this->{helo}'.");


			 
			} elsif ($noProcessing && $this->{mailfrom}=~$NPREL) {
			mlog($fh,"$tlit NP-listed/forged HELO: '$this->{helo}'") if $ValidateSenderLog; 
			AdminReportMail($this->{ip},"$this->{ip} blocked, '$this->{mailfrom}' is NP-listed and has forged HELO: '$this->{helo}'.");
			
			}
		mlog($fh,"$tlit Forged HELO: '$this->{helo}'") if $ValidateSenderLog;
		delayWhiteExpire($fh);
		return 1 if  $DoFakedLocalHelo==2;	
		pbWhiteDelete($this->{ip});
		pbAdd($this->{ip},$fhValencePB,"ForgedHELO") if $fhValencePB>0;
		return 1 if  $DoFakedLocalHelo==3;
		$Stats{forgedHelo}++;
		
		return;  
}
return 1;
}

# do forged local sender 
sub LocalSenderOK {
my($fh,$ip)=@_;
my $this=$Con{$fh};
d('LocalSenderOK');

return 1 if ($this->{relayok});
return 1 if ($this->{ispip}==1);
return 1 if $this->{acceptall}==1;
return 1 if ($DoNoValidLocalSender==0);
return 1 if (!localmail($this->{mailfrom}));
return 0 if (localmail($this->{mailfrom}) && $DoNoSpoofing);

#enforce valid local mailfrom

 my $mf=$this->{mailfrom};

$tlit="";
$tlit="Sender Validation:blocked:" if $DoNoValidLocalSender==1;
$tlit="Sender Validation:logging:" if $DoNoValidLocalSender==2;
$tlit="Sender Validation:scoring + $flValencePB:" if $DoNoValidLocalSender==3;
 
$this->{islocalmailaddress}=0;

if($LocalAddresses_Flat && $this->{mailfrom}=~$LAFRE) {
    $this->{islocalmailaddress}=1;
   } else {
# Need another check?

    # check sender against LDAP ?
    if ($DoLDAP) {
     if ($CanUseLDAP) {
      $h = $2 if ($mf =~ /^(.*@)(.*)$/);
      $this->{islocalmailaddress}=localmailaddress($h);
     } 
    }
   }
if (!$this->{islocalmailaddress}) { 
mlog($fh,"$tlit Invalid Local Sender:$this->{mailfrom}") if $ValidateSenderLog && ($DoNoValidLocalSender==3 || $DoNoValidLocalSender==2);
return 1 if ($DoNoValidLocalSender==2);
delayWhiteExpire($fh);
pbWhiteDelete($this->{ip});
pbAdd($this->{ip},$flValencePB,"InvalidLocalSender:$this->{mailfrom}")if $flValencePB>0;
return 1 if  $DoNoValidLocalSender==3;
return;
}
return 1;
}

#enforce valid A/MX record for sender address
sub MXAOK {
my($fh)=@_;
my $this=$Con{$fh};
d('MXAOK');
return 1 if $this->{mailfrom}=~$BSRE;
return 1 if $DoDomainCheck==0;
return 1 if (localmail($this->{mailfrom}));
return 1 if !$CanUseAddress;
return 1 if ($this->{relayok});

$tlit="";
$tlit="Sender Validation:blocked:" if $DoDomainCheck==1;
$tlit="Sender Validation:logging:" if $DoDomainCheck==2;
$tlit="Sender Validation:scoring + $mxValencePB:" if $DoDomainCheck==3;

	$EmailMX = eval{$mfmx = Email::Valid->mx($this->{mailfrom});};
	
    	if (!$mfmx) {
     	# couldn't find valid record for sender

     	mlog($fh,"$tlit missing MX/A record") if $ValidateSenderLog && ($DoDomainCheck==3 || $DoDomainCheck==2);
     	
		pbWhiteDelete($this->{ip});
		return 1 if $DoDomainCheck==2;
		pbAdd($this->{ip},$mxValencePB,"missingMX/A:$this->{mailfrom}",1) if $mxValencePB>0;
     	delayWhiteExpire($fh);
		return 1 if  $DoDomainCheck==3;
		return;
     	}
return 1;
}

sub BombOK {
my($fh,$b)=@_;
my $this=$Con{$fh};
d('BombOK');
my $subre;
if($testRe && $b=~('('.$testReRE.')') ) {
$subre=substr($1,0,40);
$subre=~ s/\r/ /g;
$subre=~ s/\n/ /g;
mlog($fh,"Bomb:Test: TestRegEx: '$subre'") ;

}
return 1 if $DoBombRe==0;
return 1 if $this->{acceptall}==1;
return 1 if $this->{whitelisted}  && !$bombReWL;
return 1 if $this->{noprocessing}==1 && !$bombReNP;
return 1 if ($this->{relayok} && !$bombReRelay);
$tlit="";
$tlit="Bomb:blocking:" if $DoBombRe==1;
$tlit="Bomb:logging:" if $DoBombRe==2;
$tlit="Bomb:scoring + $bombValencePB" if $DoBombRe==3;


if($bombRe && $b=~('('.$bombReRE.')') ) {
$subre=substr($1,0,$RegExLength);
$subre=~ s/\r/ /g;
$subre=~ s/\n/ /g;
$this->{messagereason}=$subre; 
mlog($fh,"$tlit BombRegEx: '$subre'")  if ($DoBombRe==2 || $DoBombRe==3);
return 1 if $DoBombRe==2;
pbWhiteDelete($this->{ip});
pbAdd($this->{ip},$bombValencePB,"BombRe") if ($bombValencePB>0);


return 1 if $DoBombRe==3;
return;
}
return 1;
 }
# 

sub ScriptOK {
my($fh,$b)=@_;
my $this=$Con{$fh};
d('ScriptOK');

return 1 if $DoScripRe==0;
return 1 if $this->{acceptall}==1;
return 1 if $this->{whitelisted};
return 1 if $this->{noprocessing}==1;
return 1 if ($this->{relayok});
$tlit="";
$tlit="Script:blocking:" if $DoScriptRe==1;
$tlit="Script:logging:" if $DoScriptRe==2;
$tlit="Script:scoring + $bombValencePB" if $DoScriptRe==3;


if($scriptRe && $b=~('('.$scriptReRE.')') ) {
		$subre=substr($1,0,$RegExLength);
		
$this->{mypbreason}=$subre; 
mlog($fh,"$tlit ScriptRegEx: '$subre'") if ($DoScriptRe==2 || $DoScriptRe==3);
return 1 if $DoScriptRe==2;
return 1 if $DoScriptRe==3;
return;
}
return 1;
 }
#  
 # do valid HELO check
sub validHeloOK {
my($fh,$helo)=@_;
my $this=$Con{$fh};
d('validHeloOK');

return 1 if $DoInvalidFormatHelo==0 || $ValidLogic==0;
return 1 if ($this->{relayok});
return 1 if ($heloBlacklistIgnore && $helo =~ $HBIRE); 
return 1 if $this->{ispip}==1;
return 1 if $this->{nodelay}==1;
return 1 if $this->{acceptall}==1;
return 1 if $this->{contentonly};
return 1 if $this->{whitelisted};
return 1 if $this->{noprocessing}==1;
return 1 if (pbWhiteFind($this->{ip}));
 

if ($DoValidFormatHelo && $validFormatHeloRe && !($helo =~('('.$validFormatHeloReRE.')')))
 {
$tlit="";
$tlit="Sender Validation:blocked:" if $DoValidFormatHelo==1;
$tlit="Sender Validation:logging:" if $DoValidFormatHelo==2;
$tlit="Sender Validation:scoring + $ihValencePB:" if $DoValidFormatHelo==3; 
mlog($fh,"$tlit Invalid HELO: '$helo'") if $ValidateSenderLog && ($DoValidFormatHelo==3 || $DoValidFormatHelo==2);

return 1 if $DoValidFormatHelo==2;
pbAdd($this->{ip},$ihValencePB,"InvalidHelo") if $ihValencePB>0 ;
return 1 if $DoValidFormatHelo==3;
return 0;
}

return 1;
}

 # do invalid HELO check
sub invalidHeloOK {
my($fh,$helo)=@_;
my $this=$Con{$fh};
d('invalidHeloOK');

return 1 if $DoInvalidFormatHelo==0 || $ValidLogic==0;
return 1 if ($this->{relayok});
return 1 if ($heloBlacklistIgnore && $helo =~ $HBIRE); 
return 1 if $this->{ispip}==1;
return 1 if $this->{nodelay}==1;
return 1 if $this->{acceptall}==1;
return 1 if $this->{contentonly};
return 1 if $this->{whitelisted};
return 1 if $this->{noprocessing}==1;
return 1 if (pbWhiteFind($this->{ip}));
 


if ($DoInvalidFormatHelo && $invalidFormatHeloRe && $helo =~$invalidFormatHeloReRE)
 {
 $tlit="";
$tlit="Sender Validation:blocked:" if $DoInvalidFormatHelo==1;
$tlit="Sender Validation:logging:" if $DoInvalidFormatHelo==2;
$tlit="Sender Validation:scoring + $ihValencePB:" if $DoInvalidFormatHelo==3;
mlog($fh,"$tlit Invalid HELO: '$helo'") if $ValidateSenderLog && ($DoInvalidFormatHelo==3 || $DoInvalidFormatHelo==2);
return 1 if $DoInvalidFormatHelo==2;
pbAdd($this->{ip},$ihValencePB,"InvalidHelo") if $ihValencePB>0 ;
return 1 if $DoInvalidFormatHelo==3;
return 0;
}

return 1;
}

# do blacklisted HELO check
sub BlackHeloOK {
my($fh,$helo)=@_;
my $this=$Con{$fh};
d('BlackHeloOK');
return 1 if $useHeloBlacklist==0;
return 1 if ($this->{relayok});
return 1 if ($heloBlacklistIgnore && $this->{helo} =~ $HBIRE);
$tlit="";
$tlit="Sender Validation:blocked:" if $useHeloBlacklist==1;
$tlit="Sender Validation:logging" if $useHeloBlacklist==2;
$tlit="Sender Validation:scoring + $hlValencePB:" if $useHeloBlacklist==3;


if ($HeloBlackObject && $HeloBlack{$this->{helo}}) { 
mlog($fh,"$tlit blacklisted HELO: '$helo'") if $ValidateSenderLog && ($useHeloBlacklist==3 || $useHeloBlacklist==2);

return 1 if $useHeloBlacklist==2;
pbAdd($this->{ip},$hlValencePB,"BlacklistedHelo:$this->{helo}") if $ihValencePB>0 ;
return 1 if $useHeloBlacklist==3;
 
return 0;
}
return 1;
}

sub PTROK {

my($fh)=@_;
my $this=$Con{$fh};
d('PTROK');

return 1 if $DoReversed==0;
return 1 if !$CanUseDNS;
return 1 if ($this->{ispip}==1);
return 1 if ($this->{nodelay}==1);
return 1 if  $this->{acceptall}==1;
return 1 if ( $this->{contentonly});
return 1 if ( $this->{whitelisted});
return 1 if ($this->{noprocessing}==1);
return 1 if (pbWhiteFind($this->{ip}));
return 1 if ($this->{relayok});
$tlit="";
$tlit="Sender Validation:blocked:" if $DoReversed==1;
$tlit="Sender Validation:logging:" if $DoReversed==2;
$tlit="Sender Validation:scoring + $ptValencePB:" if $DoReversed==3;

my $res = Net::DNS::Resolver->new;
my $ip_address = $this->{ip};
	if ($ip_address) {
    my $query = $res->search("$ip_address");
    if ($query) {
           foreach my $rr ($query->answer) {
             next unless $rr->type eq "PTR";
             return 1;
           }
       } else {
       mlog($fh,"$tlit PTR missing for $ip_address ") if $ValidateSenderLog && ($DoReversed==3 || $DoReversed==2);

       return 1 if $DoReversed==2;
       pbAdd($this->{ip},$ptValencePB,"PTRmissing",1) if $ptValencePB>0;
       return 1 if $DoReversed==3;
      
       return 0;
       }
}
return 1;
} 
sub PBOK {
my($fh,$myip,$lvl)=@_;
my $this=$Con{$fh};
d('PBOK');
my $t=time;

my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));

return 1 if ( $this->{contentonly});
return 1 if ($this->{relayok});
return 1 if ( $this->{whitelisted});
return 1 if ($this->{ispip}==1);
return 1 if ($this->{nodelay}==1);
return 1 if ($this->{noprocessing}==1);
return 1 if(pbWhiteFind($this->{ip}));
return 1 if (!exists $PBBlack{$ip});
return 1 if $DoPenalty==0 ;
my($ct,$ut,$level,$totalscore,$sip,$reason)=split(" ",$PBBlack{$ip});
$this->{mypbreason}="$totalscore ($reason)";
return 1 if $totalscore<$PenaltyLimit;
return 1 if $DoPenalty==2 || $DoPenalty==3;
return 0;
}

sub PBExtremeOK {
my($fh,$myip)=@_;
my $this=$Con{$fh};
d('PBExtremeOK');
my $newscore;
my $data;
my $t=time;
my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));
return 1 if $PenaltyExtreme==0;
return 1 if $pbTestMode==1;
return 1 if ($DoPenalty==0);
return 1 if ( $this->{contentonly});
return 1 if ( $this->{whitelisted} && !$DoExtremeWL);
return 1 if ($this->{noprocessing}==1 && !$DoExtremeNP);
return 1 if (exists $PBWhite{$ip});
return 1 if ($this->{ispip}==1);
return 1 if ($this->{nodelay}==1);
return 1 if  $this->{acceptall}==1;  
return 1 if ($this->{relayok});
return 1 if (!exists $PBBlack{$ip});


$tlit="";
$tlit="PB:extreme:blocked:" if $DoPenalty==1;
$tlit="PB:extreme:logging:" if $DoPenalty==2;
$tlit="PB:extreme:scoring:" if $DoPenalty==3;

my($ct,$ut,$level,$totalscore,$sip,$reason)=split(" ",$PBBlack{$ip});

if ($totalscore>=$PenaltyExtreme) {
mlog($fh,"$tlit $ip score:$totalscore $reason ") if $PenaltyLog;
return 1 if $DoPenalty==2 || $DoPenalty==3;
$Stats{pbdenied}++ ;
return 0;
}
return 1;
}
sub RBLCacheOK {
my($fh,$myip)=@_;
my $this=$Con{$fh};
d('RBLCacheOK');
my $ip=ipNetwork($myip,($RBLUseNetblocks ? 24 : 32));
return 1 if ( $this->{contentonly});
return 1 if ( $this->{whitelisted} && !$RBLWL);
return 1 if ($this->{noprocessing}==1);
return 1 if !(exists $RBLCache{$ip});
return 1 if ($DoRBLCache==0);
return 1 if ($rblSpamLovers);
return 1 if ($rblTestMode==1);
return 1 if (exists $PBWhite{$ip});
return 1 if ($this->{ispip}==1);
return 1 if ($this->{nodelay}==1);
return 1 if  $this->{acceptall}==1;  
return 1 if ($this->{relayok});
my $t=time; 
my($ct,$mm,$rbllists,$ut,$freq)=split(" ",$RBLCache{$ip});
$freq++;
my $tdif=$t-$ut;
$data="$ct $mm $rbllists $t $freq";
$RBLCache{$ip}=$data;
$RBLCache{$myip}=$data;
mlog($fh,"RBLCache($freq): - $ip blocked by $rbllists ($mm)") if (($RBLLog || $PenaltyLog));
$Stats{rblcachehits}++;
my $reply=$RBLNonFatal ? "451 4.7.1" : "550 5.7.1";
seterror($fh,"$reply Blacklisted by $rbllists ",1);
done($fh);
return 0;
}
sub Delayok {
 my($fh,$rcpt)=@_;
 my $this=$Con{$fh};
 d('Delayok');
 return 1 unless (!$this->{relayok} && $EnableDelaying && !($ispip && $this->{ip}=~$ISPRE));
 return 1 unless ($this->{noprocessing}!=1 && !($noProcessing && $this->{mailfrom}=~$NPREL));
 my $a=lc $this->{mailfrom};
 my $time=$UseLocalTime ? localtime() : gmtime();
 my $tz=$UseLocalTime ? tzStr() : '+0000';
 $time=~s/... (...) +(\d+) (........) (....)/$2 $1 $4 $3/;
 if (($whiteListedDomains && $a=~$WLDRE) || (!$DelayWL && $Whitelist{$a})) {
  # add to our header; merge later, when client sent own headers
  $this->{myheader}.="X-Assp-Delay: not delayed (whitelisted); $time $tz\r\n" if $DelayAddHeader;
  return 1;
 }
 if ($noDelay && $this->{ip}=~$NDRE) {
  # add to our header; merge later, when client sent own headers
  $this->{myheader}.="X-Assp-Delay: not delayed (noDelay IP); $time $tz\r\n" if $DelayAddHeader;
  return 1;
 }
 if (!$DelaySL && ($this->{allLoveSpam} & 1)) {
  # add to our header; merge later, when client sent own headers
  $this->{myheader}.="X-Assp-Delay: not delayed (spamlover); $time $tz\r\n" if $DelayAddHeader;
  return 1;
 }
 if ($DelayNormalizeVERPs) {
  # strip extension
  $a=~s/\+.*(?=@)//;
  # replace numbers with '#'
  $a=~s/\b\d+\b(?=.*@)/#/g;
 }
 my $ip=ipNetwork($this->{ip},($DelayUseNetblocks ? 24 : 32));
 my $hash="$ip $a ". lc $rcpt;
 # get sender domain
 my $awhite=$a;
 $awhite=~s/.*@//;
 my $hashwhite="$ip $awhite";
 if ($CanUseMD5Keys) {
  $hash=Digest::MD5::md5_hex($hash);
  $hashwhite=Digest::MD5::md5_hex($hashwhite);
 }
 my $t=time;
 my $delay_result;
 if (!exists $DelayWhite{$hashwhite}) {
  if (!exists $Delay{$hash}) {
   mlog($fh,"adding new triplet: ($ip,$a,". lc $rcpt .")") if $DelayLog;
   $Stats{rcptDelayed}++;
   $Delay{$hash}=$t;
   $delay_result=0;
  } else {
   my $interval=$t-$Delay{$hash};
   my $intervalFormatted=formatTimeInterval($interval);
   if ($interval<$DelayEmbargoTime*60) {
    mlog($fh,"embargoing triplet: ($ip,$a,". lc $rcpt .") waited: $intervalFormatted") if $DelayLog;
    $Stats{rcptEmbargoed}++;
    $delay_result=0;
   } elsif ($interval<$DelayEmbargoTime*60+$DelayWaitTime*3600) {
    mlog($fh,"whitelisting triplet: ($ip,$a,". lc $rcpt .") waited: $intervalFormatted") if $DelayLog;
    delete $Delay{$hash};
    $DelayWhite{$hashwhite}=$t;
    $delay_result=1;
    # add to our header; merge later, when client sent own headers
    $this->{myheader}.="X-Assp-Delay: delayed for $intervalFormatted; $time $tz\r\n" if $DelayAddHeader;
   } else {
    mlog($fh,"late triplet encountered, deleting: ($ip,$a,". lc $rcpt .") waited: $intervalFormatted") if $DelayLog;
    $Stats{rcptDelayedLate}++;

    $Delay{$hash}=$t;
    $delay_result=0;
   }
  }
 } else {
  my $interval=$t-$DelayWhite{$hashwhite};
  my $intervalFormatted=formatTimeInterval($interval);
  if ($interval<$DelayExpiryTime*24*3600) {
   mlog($fh,"renewing whitelisted tuplet: ($ip,$awhite) age: ". $intervalFormatted) if $DelayLog;
   $DelayWhite{$hashwhite}=$t;
   # multiple rcpt's
   delete $Delay{$hash};
   $delay_result=1;
   # add to our header; merge later, when client sent own headers
   $this->{myheader}.="X-Assp-Delay: not delayed (auto whitelisted); $time $tz\r\n" if $DelayAddHeader;
  } else {
   mlog($fh,"deleting expired tuplet: ($ip,$awhite) age: ". $intervalFormatted) if $DelayLog;
   $Stats{rcptDelayedExpired}++;
   
   delete $DelayWhite{$hashwhite};
   $Delay{$hash}=$t;
   $delay_result=0;
  }
 }
 return $delay_result;
}

# compile the spam-lovers regular expression
sub setSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(SLRE,$s,'i',"Spam Lovers");
}

# compile the Bayesian spam-lovers regular expression
sub setBSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(BSLRE,$s,'i',"Bayesian Spam Lovers");
}

# compile the blacklisted spam-lovers regular expression
sub setBLSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(BLSLRE,$s,'i',"Blacklisted Spam Lovers");
}

# compile the HELO listed spam-lovers regular expression
sub setHLSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(HLSLRE,$s,'i',"HELO listed Spam Lovers");
}

# compile the SPF failures spam-lovers regular expression
sub setSPFSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(SPFSLRE,$s,'i',"SPF failures Spam Lovers");
}

# compile the RBL failures spam-lovers regular expression
sub setRBLSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(RBLSLRE,$s,'i',"RBL failures Spam Lovers");
}
# compile the Invalid Senders  failures spam-lovers regular expression
sub setISSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(ISSLRE,$s,'i',"Invalid Senders failures Spam Lovers");
}
sub setPBSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(PBSLRE,$s,'i',"Penalty Box failures Spam Lovers");
}
# compile not SRS signed bounces spam-lovers regular expression
sub setSRSSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(SRSSLRE,$s,'i',"not SRS signed bounces Spam Lovers");
}
sub setDLSLRE {
 my (@uad, @u, @d);
 foreach $a (split(/\|/,$_[0])) {
  if($a=~/\S\@\S/) {
   push(@uad,$a);
  } elsif( $a=~/^\@/ ) {
   push(@d,$a);
  } else {
   push(@u,$a);
  }
 }
 my @s;
 push(@s,'^('.join('|',@uad).')$') if @uad;
 push(@s,'^('.join('|',@u).')@') if @u;
 push(@s,'('.join('|',@d).')$') if @d;
 my $s=join("|",@s);
 $s='<not a valid list>' unless $s;
 SetRE(DLSLRE,$s,'i',"not Delay Spam Lovers");
}
# returns true if all of the addresses in the space separated list are CC adresses
sub allccAddresses {
 my $rcpt=shift;
 my $c=0;
 for (split(' ',$rcpt)) {
  return 0 unless $_=~$CCRE;
  $c++;
 }
 $c;
}
# returns true if all of the addresses in the space separated list are CCArchiv adresses
sub allccArchivAddressesRec {
 my $rcpt=shift;
 my $c=0;
 for (split(' ',$rcpt)) {
  return 0 unless $_=~$CCARRE;
  $c++;
 }
 $c;
}
# the message is not spam -- route it to the server
sub isnotspam {
 my ($fh,$done)=@_;
 d(23);
 my $this=$Con{$fh};
 my $server=$this->{friend};
 # it's time to merge our header with client's one
 $this->{myheader}=headerWrap($this->{myheader}); # wrap long lines
 $this->{header}=~s/^($HeaderRe*)/$1\r\n\n\n\r$this->{myheader}/o;
 $this->{header}=~s/\r?\n?\r\n\n\n\r/\r\n/;


 my $m=$this->{header};
 sendque($server, $m);
 $this->{header}='';
 if($done) {
  $this->{getline}=\&getline;
 } else {
  $this->{getline}=\&whitebody;
 }
}

# the message is non spam -- just relay it to the server
sub whitebody { my($fh,$l)=@_;
 my $this=$Con{$fh};
 d(25);
 my $server=$this->{friend};
 $this->{maillength}+=length($l);
 my $done=$l=~/^\.[\r\n]*$/ || defined($this->{bdata}) && $this->{bdata}<=0;
 if($done) {
  $this->{getline}=\&getline;
 } else {
  if($this->{maillength}>=$AVBytes) {
   if (!$AVBytes) {
    checkInfection($fh,$l); # Full Scan
   }
  } else {
   checkInfection($fh,$l); # Scan up to AV Bytes.
  }
 }

 sendque($server, $l);
}

# the message is non spam -- check if it is executable
sub whitebodyNoExe { my($fh,$l)=@_;
 my $this=$Con{$fh};
 d(255);
 my $b=$this->{header}.=$l;
 my $done=$l=~/^\.[\r\n]*$/ || defined($this->{bdata}) && $this->{bdata}<=0;
 checkInfection($fh,$l);
 if( $done || length($b) >=$MaxBytes) {
  $this->{maillength}=length($b);

  if ($this->{noprocessing}==1) {
   if($b=~$badattachRE[$BlockNPExes]) {
    Maillog($fh,'',$npAttachLog);
    mlog($fh,"bad attachment (noprocessing)");
    $Stats{viri}++;
    delayWhiteExpire($fh);
    pbAdd($this->{ip},$baValencePB,"BadAttachment") if $baValencePB>0;
  
    seterror($fh,$AttachmentError,$done);
   } else {
    mlog($fh,"message proxied without processing - (no bad attachments)");
    $Stats{noprocessing}++;
  
    $Stats{nopsize}=$Stats{nopsize} + $this->{maillength};
   if ($Stats{noprocessing}>0) {
   $Stats{nopavsize}=int($Stats{nopsize} / $Stats{noprocessing});
   }
    isnotspam($fh,$done);
   }
  } elsif ($b=~$badattachRE[$BlockWLExes]) {
   Maillog($fh,'',$wlAttachLog);
   mlog($fh,"bad attachment (local/white)");
   $Stats{viri}++;
   delayWhiteExpire($fh);
 
   seterror($fh,$AttachmentError,$done);
  } else {
   $SpamProb=0; addSpamProb($fh,1);
    my $fn=Maillog($fh,'',2); # tell maillog this isn't spam
    $fn=' -> '.$fn if !$fn=="";
    $fn="" if !$fileLogging;
   mlog($fh,"local or whitelisted - (no bad attachments)$fn");
   isnotspam($fh,$done);
  }
 }
}

# the message may or may not be spam -- get the body and test it.
sub getbody { my($fh,$l)=@_;
 d(27);
 my $this=$Con{$fh};
 my $b=$this->{header}.=$l;
 my $subre;
 my $done=$l=~/^\.[\r\n]*$/ || defined($this->{bdata}) && $this->{bdata}<=0;
 print DEBUG "bd='$this->{bdata}'\n" if $DEBUG;
 checkInfection($fh,$l);
 if( $done || length($b) >=$MaxBytes) {
  $this->{maillength}=length($b);

  if(!BombOK($fh,$b)) {
 
  $bomblt = $bombError;
  $bomblt .= " ( reason: '$this->{messagereason}' ) " if $bombErrorReason;
$Stats{bombs}++;
  delayWhiteExpire($fh);
  $slok=$this->{allLoveISSpam}==1;
  thisIsSpam($fh,"BombRe: '$this->{messagereason}'",$spamBombLog,$bomblt,$bombTestMode,$slok,1);
  } elsif(!ScriptOK($fh,$b)) {
  $slok=$this->{allLoveISSpam}==1;
  $Stats{scripts}++;
  delayWhiteExpire($fh);

thisIsSpam($fh,"ScriptRe: '$this->{messagereason}'",$scriptLog,$scriptError,$bombTestMode,$slok,1);
} elsif (!PBOK($fh,$this->{ip})){
    $slok=$this->{allLovePBSpam}==1;
    $Stats{pbdenied}++ unless $slok;
    $SpamError=$PenaltyError if $PenaltyError;
    $this->{myheader}.="X-Assp-PB-Score: $this->{mypbreason}\r\n";
    thisIsSpam($fh,"PB:LV1 blocked - score:$this->{mypbreason} ",$spamPBLog,$SpamError,$pbTestMode,$slok,1);
  } elsif($BlockExes && $b=~$badattachRE[$BlockExes]) {
    my $fn=Maillog($fh,'bad attachment',$extAttachLog);
    $fn=' -> '.$fn if !$fn=="";
    $fn="" if !$fileLogging;	  
   mlog($fh,"bad attachment (external) $fn");
   $Stats{viri}++;
   delayWhiteExpire($fh);
   pbAdd($this->{ip},$baValencePB,"BadAttachment" ) if $baValencePB>0;
   seterror($fh,$AttachmentError,$done);
  } elsif($this->{spamfound}) {
   # Spam is found to be safe, lets pass it on.

    my $fn=Maillog($fh,'',$baysSpamLog);
    $fn=' -> '.$fn if !$fn=="";
    $fn="" if !$fileLogging;
   mlog($fh,"spam determined to be safe, passing on to recipient $fn");
   delayWhiteExpire($fh);
   isnotspam($fh,$done);

} elsif(isspam($b,$this->{ip})) {

my $slok=$this->{allLoveBaysSpam}==1; 
$this->{testmode} = ($baysTestMode!=0 || ($baysConfidence>0 && $SpamProbConfidence<$baysConfidence));
if (!$slok) {
$Stats{bspams}++;
}
pbAdd($this->{ip},$baysValencePB,"Bayesian") if $baysValencePB>0;
$this->{myheader}.=sprintf("X-Assp-Bayes-Confidence: %.5f\r\n",$SpamProbConfidence) if $AddSpamProbHeader && $AddConfidenceHeader; 
thisIsSpam($fh,'Bayesian spam',$baysSpamLog,$SpamError,$this->{testmode},$slok,$done); 

} else {

  	my $fn=Maillog($fh,'',$baysNonSpamLog);
  	$fn=' -> '.$fn if !$fn=="";
  	$fn="" if !$fileLogging;
$this->{myheader}.=sprintf("X-Assp-Bayes-Confidence: %.5f\r\n",$SpamProbConfidence) if $AddSpamProbHeader && $AddConfidenceHeader; 
  	addSpamProb($fh,0);
  	mlog($fh,"message ok$fn");
   $Stats{bhams}++;
   isnotspam($fh,$done);
  }
 }
}

sub checkInfection {
 my ($fh,$l)=@_;
 my $this=$Con{$fh};
 return unless $AvDbs && (!(localmail($this->{mailfrom})) || $Avlocal);
 my $av;
 unless($av=$Con{$fh}->{av}) {
  $av=$Con{$fh}->{av}=Av->new();
 }
 $l=~s/([a-zA-Z0-9+\/=]{40,}\s*)/base64decode($1)/e;
 my $r;
 my $n=0;
 for(;$n<length($l); $n++) {
  if($r=$av->addchar(substr($l,$n,1))) {
   # this mail is infected
   my $er=$AvError;
   $er=~s/\$infection/$r->[1]/gi;
   mlog($fh,"virus detected '$r->[1]'");
   $Stats{viridetected}++;
   delayWhiteExpire($fh);
   pbAdd($this->{ip},$vdValencePB,"Virus") if $vdValencePB>0;
   seterror($fh,$er,0);
  }
 }
}

# This is spam, lets see if its test mode or spamlover.
sub thisIsSpam {
 my ($fh,$reason,$log,$error,$testmode,$slok,$done)=@_;
 my $this=$Con{$fh};
 d('thisIsSpam');
 addSpamProb($fh,0);
 $this->{spamfound}=1; # Set spamfound flag.
 # add to our header; merge later, when client sent own headers
 $this->{myheader}.="X-Assp-Spam: YES\r\n" if $AddSpamHeader;
 $this->{myheader}.="X-Assp-Spam-Reason: ".ucfirst($reason)."\r\n" if $AddSpamReasonHeader;
 if($slok || $testmode) {
  if($slok) {
   mlog($fh,"passing is safe because spamlover(s): $this->{rcpt}, otherwise $reason");
   $Stats{spamlover}++;
  } else {
   mlog($fh,"passing is safe because testmode, otherwise $reason");
  }
  # pretend it's not spam
  $this->{header}=~s/^($HeaderRe*)/$1From: sender not supplied\r\n/o unless $this->{header}=~/^$HeaderRe*From:/io; # add From: if missing
  $this->{header}=~s/^($HeaderRe*)/$1Subject:\r\n/o unless $this->{header}=~/^$HeaderRe*Subject:/io; # add Subject: if missing
if ($slok && $spamSubjectSL) {
} else {
    $this->{header}=~s/^Subject:/Subject: $spamSubject/gim if $spamSubject ;
  }
  #Lets check if its safe to pass if not already done so.
  if ($done) {

   my $fn=Maillog($fh,'',$log); # tell maillog what this is.
   $fn=' -> '.$fn if !$fn=="";
   $fn="" if !$fileLogging;
   mlog($fh,"spam determined to be safe, passing on to recipient$fn");
   delayWhiteExpire($fh) unless $slok; # maybe change to always expire ?

   isnotspam($fh,$done);
  } else {
   $this->{getline}=\&getbody;
  }
 } else {
  my $fn=Maillog($fh,'',$log); # tell maillog what this is.
  $fn=' -> '.$fn if !$fn=="";
  $fn="" if !$fileLogging;	
  mlog($fh,$reason.$fn);
  delayWhiteExpire($fh);
  seterror($fh,$error,$done);
 }
}

# delete whitelisted tuplet
sub delayWhiteExpire {
 return unless ($EnableDelaying && $DelayExpireOnSpam);
 my $fh=shift;
 my $this=$Con{$fh};
 my $a=lc $this->{mailfrom};
 
 # get sender domain
 $a=~s/.*@//;
 my $ip=ipNetwork($this->{ip},($DelayUseNetblocks ? 24 : 32));
 my $hash="$ip $a";
 $hash=Digest::MD5::md5_hex($hash) if $CanUseMD5Keys;
 if ($DelayWhite{$hash}) {
  # delete whitelisted (IP+sender domain) tuplet
  mlog($fh,"deleting spamming whitelisted tuplet: ($ip,$a) age: ". formatTimeInterval(time-$DelayWhite{$hash})) if $DelayLog;
  delete $DelayWhite{$hash};
 }
}

# add to penalty box
sub pbAdd {
my($myip,$score,$reason,$enforce)=@_;
return	if ( $this->{whitelisted});
return	if ($this->{noprocessing}==1);
return	if ($this->{ispip}==1);
return	if ($this->{nodelay}==1);
return	if ($DoPenalty==0);
$this->{messagescore}+=$score;

my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));
return if (exists $PBWhite{$ip});
$this->{myheader}.="X-Assp-PB-Score: $score ($reason)\r\n" if $AddScoringHeader;
pbBlackAdd($myip,$score,$reason);

}
# find in penalty White list
sub pbWhiteFind {
return if ($DoPenalty==0);
my($myip)=@_;
return unless ($PBWhiteObject);
my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));

return 1 if (exists $PBWhite{$ip}) ;
}

sub pbBlackAdd {
return if ($DoPenalty==0);
my($myip,$score,$reason,$nolog)=@_;
my $t=time;
my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));
if (exists $PBBlack{$ip}) {
my($ct,$ut,$freq,$oldscore,$sip,$sreason)=split(" ",$PBBlack{$ip});
$freq++;
my $tdif=$t-$ut;
my $newscore=$oldscore+$score;
my $data="$ct $t $freq $newscore $myip $reason ";
 mlog(0,"PB: $ip score: $oldscore+$score => $newscore reason:$myip:$reason") if $PenaltyLog==2;
$PBBlack{$ip}=$data;
$PBBlack{$myip}=$data;
$this->{mypbreason}="$reason";
return;
} else {
my $freq=1;
$this->{mypbreason}="$reason";
my $data="$t $t $freq $score $myip $reason $score";
$PBBlack{$ip}=$data;
$PBBlack{$myip}=$data;
mlog(0,"PB: $ip score: 0+$score => $score reason:$myip:$reason$mfrom") if $PenaltyLog==2;
} 
}

sub pbBlackDelete {
return if ($DoPenalty==0);

 my($myip,$score,$reason)=@_;
 return unless ($PBBlackObject);
 my $t=time;
 my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));
 if (exists $PBBlack{$ip}) {
  delete $PBBlack{$ip};
  delete $PBBlack{$myip};

  mlog(0,"PB: deleting(black) $myip - $reason") if $PenaltyLog==2;
  }
  
}

sub pbBlackClear {
my($fh,$myip)=@_;
my $this=$Con{$fh};

$ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));

delete $PBBlack{$myip};
delete $PBBlack{$ip};
return 1;
}

sub pbWhiteAdd {

 my($myip,$reason)=@_;
 my $t=time;
 my $status=2;
 my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));


return if ($this->{isbounce} );
return if ($DoPenalty==0);
return 1 if ($this->{ispip}==1);
return 1 if ($this->{nodelay}==1);


if (exists $PBWhite{$ip}) {
my($ct,$ut,$pbstatus)=split(" ",$PBWhite{$ip});

 my $data="$ct $t $status $myip $reason from:$this->{mailfrom}";
 $PBWhite{$ip}=$data;
 $PBWhite{$myip}=$data;

 } else {
  mlog(0,"PB: adding(white) $myip - $reason") if $PenaltyLog==2;
 my $data="$t $t $status $myip $reason from:$this->{mailfrom}";
$PBWhite{$ip}=$data;
$PBWhite{$myip}=$data;
}

}
 
sub pbWhiteDelete {
return if ($DoPenalty==0);
 my($myip,$score,$reason)=@_;
 my $t=time;
 my $ip=ipNetwork($myip,($PenaltyUseNetblocks ? 24 : 32));

if (exists $PBWhite{$ip}) {
delete $PBWhite{$ip};
delete $PBWhite{$myip};
mlog(0,"PB: deleting(white) $myip - $reason") if $PenaltyLog==2;

 } 
 
}


#
sub RBLCacheAdd {

my($myip,$rbllists)=@_;
my $t=time;
my ($sec,$min,$hour,$mday,$mon,$year) = localtime(time);
$mon++; $year-=100;
my $mm=sprintf("%02d-%02d-%02d/%02d:%02d",$year,$mon,$mday,$hour,$min);
my $ip=ipNetwork($myip,($RBLUseNetblocks ? 24 : 32));
my $data="$t $mm $rbllists";
$RBLCache{$ip}=$data;
$RBLCache{$myip}=$data;
 mlog(0,"RBLCache: adding $myip:$rbllists") if $PenaltyLog==2;
} 

sub RBLCacheDelete {
return if ($DoRBLCache==0);
my($myip)=@_;
return unless ($RBLCacheObject);
my $ip=ipNetwork($myip,($RBLUseNetblocks ? 24 : 32));
 	if (exists $RBLCache{$ip}) {
 	my($ct,$mm,$rbllists)=split(" ",$RBLCache{$ip});
 	delete $RBLCache{$ip};
 	delete $RBLCache{$myip};
 	mlog(0,"RBLCache: deleting $myip:$rbllists") if $PenaltyLog==2;
  	}
}
sub RBLCacheFind {
return if ($DoRBLCache==0);
my($myip)=@_;
return unless ($RBLCacheObject);
 my $ip=ipNetwork($myip,($RBLUseNetblocks ? 24 : 32));
 	if (exists $RBLCache{$ip}) {
 	return 1;
 	}
}

# reject the email
sub seterror {
 my($fh,$e,$done)=@_;
 d(28);
 my $this=$Con{$fh};
 $this->{error}=$e;
 if($done) {
  error($fh,".\r\n");
 } else {
  $this->{getline}=\&error;
  $this->{header}=''; # free up some memory
 }
 # detatch the friend -- closing connection to server & disregarding message
 done2($this->{friend});
 $this->{friend}=undef;
}

# ignore what's sent & give reason at the end.
sub error { my($fh,$l)=@_;
 d(29);
 my $this=$Con{$fh};
 if( $l=~/^\.[\r\n]*$/ || defined($this->{bdata}) && $this->{bdata}<=0) {
  print $fh $this->{error}."\r\n";
  done2($fh);
 }
}

# filter off the 250 OK noop response and go to reply
sub skipok {
 d(291);
 my ($fh,$l)=@_;
 if($l=~/^250/) {
  $Con{$fh}->{getline}=\&reply;
 } else {
  reply(@_);
 }
}

# messages from the server get relayed to the client
sub reply {
 my($fh,$l)=@_;
 d(30);
 my $this=$Con{$fh};
 return unless $this;
 my $cli=$this->{friend};
 return unless $cli;
 $Con{$cli}->{inerror}=$l=~/^5[05][0-9]/;
 if($l=~/250-(CHUNKING|PIPELINING)/i) {
  # we'll filter off the chunking directive to avoid BDAT problems.
  d('CHUNKING');
  return;
 } elsif($l=~/250-XEXCH50/i) {
  # we'll filter off the XEXCH50 service, as it only causes troubles
  d('XEXCH50');
  return;
 } elsif($l=~/250-.*STARTTLS/i) {
  # we'll filter off the STARTTLS directive to avoid TLS problems.
  d('STARTTLS');
  return;
 } elsif($l=~/^220/) {
  sendque($fh,$this->{noop}) if $this->{noop};
  delete $this->{noop};
 } elsif($l=~/^235/) {
  # check for authentication response
  $Con{$cli}->{relayok}=1;
  print DEBUG  "$Con{$cli}->{ip}: authenticated\n" if $DEBUG;
  mlog($cli,"authenticated") if $ValidateLog;
 } elsif($l=~/^354/) {
  d(301);
 } elsif($l=~/^50[0-9]/) {
  if($Con{$cli}->{skipbytes}) {
   d("Resetting skipbytes");
   $Con{$cli}->{skipbytes}=0; # if we got a negative response from XEXCH50 then don't skip anything
  }
  if($this->{serverErrors}++ > $MaxErrors) {
   mlog($fh,"max errors ($MaxErrors) exceeded -- dropping connection");
   $Stats{msgMaxErrors}++;
   done($fh);
  }
 }
 # email report/list interface sends messages itself
 return if (defined($Con{$cli}->{reporttype}) && $Con{$cli}->{reporttype}>=0);
 sendque($cli, $l);
}
#####################################################################################
#                Email Interface

# this mail isn't really a mail -- it's a spam/ham report
sub SpamReport {
 my($fh,$l)=@_;
 my $this=$Con{$fh};
 if( $l=~/^ *DATA/i || $l=~/^ *BDAT (\d+)/i ) {
  if($1) {
   $this->{bdata}=$1;
  } else {
   delete $this->{bdata};
  }
  $this->{getline}=\&SpamReportBody;
  my $report=($this->{reporttype}==0) ? "spam" : "ham";
  sendque($fh,"354 OK Send $report body\r\n");
  return;
 } elsif( $l=~/^ *RSET/i ) {
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"RSET\r\n");
  return;
 } elsif( $l=~/^ *QUIT/i ) {
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"QUIT\r\n");
  return;
 } elsif( $l=~/^ *XEXCH50 +(\d+)/i ) {
  print DEBUG "XEXCH50 b=$1\n" if $DEBUG;
  sendque($fh,"504 Need to authenticate first\r\n");
  return;
 }
 sendque($fh,"250 OK\r\n");
}

# we're getting the body of a spam/ham report
sub SpamReportBody {
 my ($fh, $l)=@_;
 $Con{$fh}->{header}.=$l if length($Con{$fh}->{header}) < $MaxBytes;
 if($l=~/^\.[\r\n]/ || defined($this->{bdata}) && $this->{bdata}<=0) {
  # we're done -- write the file & clean up
  my $this=$Con{$fh};
  my $sub=SpamReportExec($this->{header},($this->{reporttype}==0) ? $correctedspam : $correctednotspam);
  $this->{header}='';
  my $file=($this->{reporttype}==0) ? "spamreport.txt" : "notspamreport.txt";
  
 

  ReturnMail($this->{mailfrom},"$base/$file",$sub,"$this->{rcpt}\n\n$this->{report}\n") if ($EmailErrorsReply==1 || $EmailErrorsReply==3);
  ReturnMail($EmailErrorsTo,"$base/$file",$sub,"$this->{rcpt}\n\n$this->{report}\n",$this->{mailfrom}) if ($EmailErrorsTo && ($EmailErrorsReply==2 || $EmailErrorsReply==3));

  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"RSET\r\n");
 }
}

sub SpamReportExec {
 my ($bod,$path)=@_;
 my ($sub)=$bod=~/Subject: (.*)/i;
 $sub=~s/\r//;
 $bod=~s/^.*?\n\r?\n\s*//s;
 # remove the spam subject header addition if present
 my $spamsub=$spamSubject;
 if($spamsub) {
  $spamsub=~s/(\W)/\\$1/g;
  $bod=~s/Subject: $spamsub */Subject: /gi;
 }
 $bod=~s/X-Assp-Spam-Prob: .*\n//gi;
 if($bod=~/\nReceived: /) {
  $bod=~s/^.*?\nReceived: /Received: /s;
 } else {
  $bod=~s/^.*?\n((\w[^\n]*\n)*Subject:)/$1/si;
  $bod=~s/\n> /\n/g;
 }
 my $f;
 do {
  $f=int(rand()*100000000);
 } while(-e "$base/$path/$f.rpt");
 open(F,">$base/$path/$f.rpt"); binmode F;
 print F $bod;
 close F;
 $sub;
}

# we're receiving an email to manipulate addresses in the whitelist/redlist
sub ListReport {
 my($fh,$l)=@_;
 my $this=$Con{$fh};
 if( $l=~/^ *DATA/i || $l=~/^ *BDAT (\d+)/i ) {
  if($1) {
   $this->{bdata}=$1;
  } else {
   delete $this->{bdata};
  }
  sendque($this->{friend},"RSET\r\n"); # make sure to reset the pending email
  $this->{getline}=\&ListReportBody;
  my $list=(($this->{reporttype} & 4)==0) ? "whitelist" : "redlist";
  sendque($fh,"354 OK Send $list body\r\n");
  return;
 } elsif( $l=~/^ *RSET/i ) {
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"RSET\r\n");
  return;
 } elsif( $l=~/^ *QUIT/i ) {
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"QUIT\r\n");
  return;
 } elsif( $l=~/^ *XEXCH50 +(\d+)/i ) {
  print DEBUG "XEXCH50 b=$1\n" if $DEBUG;
  sendque($fh,"504 Need to authenticate first\r\n");
  return;
 } else {
  # more recipients ?
  while ($l=~/($EmailAdrRe\@$EmailDomainRe)/og) {
   ListReportExec($1,$this);
   $this->{rcpt}.="$1 ";
  }
   while ($l=~/(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/go) {
   IPListReportExec($1,$this);
 }
 }
 sendque($fh,"250 OK\r\n");
}

# we're getting the body of a whitelist/redlist report
sub ListReportBody {
 my($fh,$l)=@_;
 my $this=$Con{$fh};
 if($l=~/^\.[\r\n]/ || defined($this->{bdata}) && $this->{bdata}<=0) {
  my $file=($this->{reporttype}==2) ? "whitereport.txt" :
           ($this->{reporttype}==3) ? "whiteremovereport.txt" :
           ($this->{reporttype}==4) ? "redreport.txt" :
                                      "redremovereport.txt";
  # mail summary report

  if (($this->{reporttype}==2) || ($this->{reporttype}==3)) {
  
ReturnMail($this->{mailfrom},"$base/$file",'',"$this->{rcpt}\n\n$this->{report}\n") if ($EmailWhitelistReply==1 || $EmailWhitelistReply==3);
 
ReturnMail($EmailWhitelistTo,"$base/$file",'',"$this->{rcpt}\n\n$this->{report}\n",$this->{mailfrom}) if ( $EmailWhitelistTo && ($EmailWhitelistReply==2 || $EmailWhitelistReply==3));
  } else {
 ReturnMail($this->{mailfrom},"$base/$file",'',"$this->{rcpt}\n\n$this->{report}\n") if ($EmailRedlistReply==1 || $EmailRedlistReply==3);
 
ReturnMail($EmailRedlistTo,"$base/$file",'',"$this->{rcpt}\n\n$this->{report}\n",$this->{mailfrom}) if ( $EmailRedlistTo && ($EmailRedlistReply==2 || $EmailRedlistReply==3));
  } 
  delete $this->{report};
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"RSET\r\n");
 } elsif($l=~/message-id:/i || $l=~/from:.*?$this->{mailfrom}/i) {
  # ignore
 } else {
  while ($l=~/($EmailAdrRe\@$EmailDomainRe)/go) {
   ListReportExec($1,$this);
  }
    while ($l=~/(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/go) {
   IPListReportExec($1,$this);
 }
 }
}

sub ListReportExec {
 my ($a,$this)=@_;
 my $ea=($this->{reporttype}==0) ? "$EmailSpam\@" :
 		($this->{reporttype}==1) ? "$EmailHam\@" :
		($this->{reporttype}==2) ? "$EmailWhitelistAdd\@" :
        ($this->{reporttype}==3) ? "$EmailWhitelistRemove\@" :
        ($this->{reporttype}==4) ? "$EmailRedlistAdd\@" :
                                   "$EmailRedlistRemove\@";
 return unless $a=~/($EmailAdrRe\@)$EmailDomainRe/;
 return if lc $1 eq lc $ea && localmail($a);
 my $t=time;
 my $redlist="Redlist";
 my $list=(($this->{reporttype} & 4)==0) ? "Whitelist" : "Redlist";
 if ($this->{reporttype} & 1) {
  # deletion
  if($list->{lc $a}) {
   delete $list->{lc $a};
   $this->{report}.="$a: deleted from ".lc $list."\n";
   mlog(0,"email ".lc $list." deletion: $a");
   
   # we're adding to redlist
  if ($this->{reporttype}==3 && !localmail($a) && !$EmailNoWhiteToRed) {
if ($redlist->{lc $a}) {
   $redlist->{lc $a}=$t;
   $this->{report}.="$a: already on ".lc $redlist."\n";
   } else {
   $redlist->{lc $a}=$t;
   $this->{report}.="$a: added to ".lc $redlist."\n";
   mlog(0,"email ".lc $redlist." addition: $a");
   } } 
 # ###################
   
  } else {if (($this->{reporttype}==3) && localmail($a)) {} else {
   $this->{report}.="$a: not on ".lc $list."\n";
  # mlog(0,"email ".lc $list." miss on deletion: $a");
  }}
  

   my $mf=$a;
   my $mfd = $1 if $mf=~/\@(.*)/;
   my $mfdd = $1 if $mf=~/(\@.*)/;

   if ($noProcessing) {
   if($mf=~$NPREL) { $this->{report}.="\n$mf is on No-Processing-list\n\n";deleteNP($mf,"email from $this->{mailfrom}"); } 
   if($mfdd=~$NPREL) { $this->{report}.="\n$mfdd is on No-Processing-list\n\n"; deleteNP($mfdd,"email from $this->{mailfrom}");}
    }
    if ($npRe) {
   if($mf=~$npReRE) { $this->{report}.="\n$mf is in No-Processing-Regex\n\n"; } 
 
    }

	if($whiteListedDomains && $mfdd=~$WLDRE) {$this->{report}.="\n$mfdd is on whitedomain-list\n\n";}
 } else {
  # addidtion
  if($list->{lc $a}) {
   $list->{lc $a}=$t;
   $this->{report}.="$a: already on ".lc $list."\n";
  # mlog(0,"email ".lc $list." renewal: $a");
  } elsif(localmail($a)) {} elsif($list eq 'Whitelist' && $Redlist{lc $a}) {
   $this->{report}.="$a: cannot add redlisted users to whitelist\n";
  mlog(0,"email whitelist addition denied: $a on redlist");
  
  } else {
   $list->{lc $a}=$t;
   $this->{report}.="$a: added to ".lc $list."\n";
   mlog(0,"email ".lc $list." addition: $a");
  }
 }
}

# we're receiving a spam/ham report with option to manipulate addresses in the whitelist/redlist
sub NewListReport {
 my($fh,$l)=@_;
 my $this=$Con{$fh};
 if( $l=~/^ *DATA/i || $l=~/^ *BDAT (\d+)/i ) {
  if($1) {
   $this->{bdata}=$1;
  } else {
   delete $this->{bdata};
  }
  sendque($this->{friend},"RSET\r\n"); # make sure to reset the pending email
  $this->{getline}=\&NewListReportBody;
my $report=($this->{reporttype}==0) ? "spam" : "ham";  
my $list=($this->{reporttype}==0) ? "spam" : "ham";  

  sendque($fh,"354 OK Send $list body\r\n");
  return;
 } elsif( $l=~/^ *RSET/i ) {
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"RSET\r\n");
  return;
 } elsif( $l=~/^ *QUIT/i ) {
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"QUIT\r\n");
  return;
 } elsif( $l=~/^ *XEXCH50 +(\d+)/i ) {
  print DEBUG "XEXCH50 b=$1\n" if $DEBUG;
  sendque($fh,"504 Need to authenticate first\r\n");
  return;
 } else {
  # more recipients ?
  while ($l=~/($EmailAdrRe\@$EmailDomainRe)/og) {
   NewListReportExec($1,$this);
   $this->{rcpt}.="$1 ";
  }
 }
 sendque($fh,"250 OK\r\n");
}

# we're getting the body of a new combined report
sub NewListReportBody {

 my ($fh, $l)=@_;
 $Con{$fh}->{header}.=$l if length($Con{$fh}->{header}) < $MaxBytes;
 if($l=~/^\.[\r\n]/ || defined($this->{bdata}) && $this->{bdata}<=0) {
  # we're done -- write the file & clean up
  my $this=$Con{$fh};
  my $sub=NewSpamReportExec($this->{header},($this->{reporttype}==0) ? $correctedspam : $correctednotspam);
                                   
  # mail summary report
 
 my $file=($this->{reporttype}==0) ? "spamreport.txt" : "notspamreport.txt";


  ReturnMail($this->{mailfrom},"$base/$file",$sub,"$this->{rcpt}\n\n$this->{report}\n") if ($EmailErrorsReply==1 || $EmailErrorsReply==3);
  ReturnMail($EmailErrorsTo,"$base/$file",$sub,"$this->{rcpt}\n\n$this->{report}\n",$this->{mailfrom}) if ($EmailErrorsTo && ($EmailErrorsReply==2 || $EmailErrorsReply==3));

  delete $this->{report};
  stateReset($fh);
  $this->{getline}=\&getline;
  sendque($this->{friend},"RSET\r\n");
 } elsif($l=~/message-id:/i || $l=~/from:.*?$this->{mailfrom}/i) {
  # ignore
 } else {
  while ($l=~/($EmailAdrRe\@$EmailDomainRe)/go) {
   NewListReportExec($1,$this);
  }
   while ($l=~/(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/go) {
   IPListReportExec($1,$this);
 }
}

sub NewListReportExec {
 my ($a,$this)=@_;
 my $ea=($this->{reporttype}==0) ? "$EmailSpam\@" : "$EmailHam\@";
  return unless $a=~/($EmailAdrRe\@)$EmailDomainRe/ ;
 return if lc $1 eq lc $ea && localmail($a);
 my $t=time;
 my $redlist="Redlist";
 my $list="Whitelist";
 if ($this->{reporttype} ==0) {
  # deletion
  if($list->{lc $a}) {
   delete $list->{lc $a};
   $this->{report}.="$a: deleted from ".lc $list."\n";
   mlog(0,"email ".lc $list." deletion: $a");
   
 # we're adding to redlist
  if (!localmail($a) && !$EmailNoWhiteToRed) {
if ($redlist->{lc $a}) {
   $redlist->{lc $a}=$t;
   $this->{report}.="$a: already on ".lc $redlist."\n";
   } else {
   $redlist->{lc $a}=$t;
   $this->{report}.="$a: added to ".lc $redlist."\n";
   mlog(0,"email ".lc $redlist." addition: $a");
   } } 
 # ###################

   
  } else {if (($this->{reporttype}==1) && localmail($a)) {} else {
   $this->{report}.="$a: not on ".lc $list."\n";
  # mlog(0,"email ".lc $list." miss on deletion: $a");
  }}
  

   my $mf=$a;
   my $mfd = $1 if $mf=~/\@(.*)/;
   my $mfdd = $1 if $mf=~/(\@.*)/;

   if ($noProcessing) {
   if($mf=~$NPREL) { $this->{report}.="\n$mf is on No-Processing-List\n\n";deleteNP($mf,"email from $this->{mailfrom}"); } 
   if($mfdd=~$NPREL) { $this->{report}.="\n$mfdd is on No-Processing-List\n\n";
	deleteNP($mfdd,"email from $this->{mailfrom}"); }
    }
    if ($npRe) {
   if($mf=~$npReRE) { $this->{report}.="\n$mf is in No-Processing-Regex\n\n"; } 
 
    }
    

	if($whiteListedDomains && $mfdd=~$WLDRE) {$this->{report}.="\n$mfdd is on whitedomain-list\n\n";}
 } else {
  # addidtion
  if($list->{lc $a}) {
   $list->{lc $a}=$t;
   $this->{report}.="$a: already on ".lc $list."\n";
  # mlog(0,"email ".lc $list." renewal: $a");
  } elsif(localmail($a)) {} elsif($list eq 'Whitelist' && $Redlist{lc $a}) {
   $this->{report}.="$a: cannot add redlisted users to whitelist\n";
  mlog(0,"email whitelist addition denied: $a on redlist");

  } else {
   $list->{lc $a}=$t;
   $this->{report}.="$a: added to ".lc $list."\n";
   mlog(0,"email ".lc $list." addition: $a");
  }
 }
}

sub IPListReportExec {
 my ($a,$this)=@_;
 my $ea=($this->{reporttype}==0) ? "$EmailSpam\@" : "$EmailHam\@";
  
  return unless $a=~/(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/ ;
  my $myip=$1;
  my $ip3=$1;
 $ip3=~s/(\d+\.\d+\.\d+).*/$1/;
 $localhostaddr3=~s/(\d+\.\d+\.\d+).*/$1/ if $localhostname;
 return if ($localhostname && $ip3 eq $localhostaddr3)  || ($myServerRe && $myip =~$myServerRe || $ip3=="127.0.0");
 my $t=time;
 
 my $list="Whitelist";
 if ($this->{reporttype} ==0 || $this->{reporttype} ==3) {
  # deletion
  if (exists $PBWhite{$myip}) {
  pbWhiteDelete($myip);
 
 
  }

 } else {
  # deletion black
  delete $PBBlack{$myip};
  delete $PBBlack{$ip};



 
  }

}}
# we're getting the body of a spam/ham report


sub NewSpamReportExec {
 my ($bod,$path)=@_;
 my ($sub)=$bod=~/Subject: (.*)/i;
 $sub=~s/\r//;
 $bod=~s/^.*?\n\r?\n\s*//s;
 # remove the spam subject header addition if present
 my $spamsub=$spamSubject;
 if($spamsub) {
  $spamsub=~s/(\W)/\\$1/g;
  $bod=~s/Subject: $spamsub */Subject: /gi;
 }
 $bod=~s/X-Assp-Spam-Prob: .*\n//gi;
 if($bod=~/\nReceived: /) {
  $bod=~s/^.*?\nReceived: /Received: /s;
 } else {
  $bod=~s/^.*?\n((\w[^\n]*\n)*Subject:)/$1/si;
  $bod=~s/\n> /\n/g;
 }
 my $f;
 do {
  $f=int(rand()*100000000);
 } while(-e "$base/$path/$f.rpt");
 open(F,">$base/$path/$f.rpt"); binmode F;
 print F $bod;
 close F;
 $sub;
}

sub ReturnMail {
return if $NoHaiku;
 my($from,$file,$sub,$bod,$user)=@_;
 my $destination;
 if ($smtpDestination =~ /^(__INBOUND__:)?(\d+)$/){
   $destination = '127.0.0.1:'.$2;
 }
 else{
   $destination = $smtpDestination;
 }
 my $s=new IO::Socket::INET(Proto=>'tcp',PeerAddr=>$destination,Timeout=>2);
 if(! $s) {
  mlog('',"couldn't create server socket to $destination -- aborting ReturnMail connection");
  return;
 }
 addfh($s,\&RMhelo);
 my $this=$Con{$s};
 $this->{to}=$from;
 $this->{from}=$EmailFrom;
 open(F,"<$file") || mlog(0,"couldn't open '$file' for mail report");
 local $/="\n";
 my $subject=<F>;
 $subject=~s/\s*(.*)\s*/$1 $sub/;
 $this->{subject}=$subject;
 undef $/;
 $this->{body}="Report from: $user\n".$bod if $user;
$this->{body}=<F>.$bod if !$user;
 close F;
 $this->{body}=~s/\r?\n/\r\n/g;
 $this->{subject}=~s/\r?\n?//g;
my $spamsub=$spamSubject;
 if($spamsub) {
  $spamsub=~s/(\W)/\\$1/g;
  $this->{subject}=~s/$spamsub *//gi;
 }

}

sub AdminReportMail {
return if !$EmailAdminReportsTo;
 my($sub,$bod)=@_;
 my $destination;
 if ($smtpDestination =~ /^(__INBOUND__:)?(\d+)$/){
   $destination = '127.0.0.1:'.$2;
 }
 else{
   $destination = $smtpDestination;
 }
 my $s=new IO::Socket::INET(Proto=>'tcp',PeerAddr=>$destination,Timeout=>2);
 if(! $s) {
  mlog('',"couldn't create server socket to $destination -- aborting  connection");
  return;
 }
 addfh($s,\&RMhelo);
 my $this=$Con{$s};
 $this->{to}=$EmailAdminReportsTo;
 $this->{from}=$EmailFrom;

 local $/="\n";
 
 $this->{subject}=$sub;
 $this->{subject}=~s/\r?\n?//g;
 undef $/;
 
 $this->{body}=$bod;
 
}

sub RMhelo { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  RMabort($fh,"helo Expected 220, got: $l (from:$Con{$fh}->{from} to:$Con{$fh}->{to})");
 } elsif($l=~/^ *220 /) {
  sendque($fh,"HELO $myName\r\n");
  $Con{$fh}->{getline}=\&RMfrom;
 }
}
sub RMfrom { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  RMabort($fh,"from Expected 250, got: $l (from:$Con{$fh}->{from} to:$Con{$fh}->{to})");
 } elsif($l=~/^ *250 /) {
  sendque($fh,"MAIL FROM: ".($Con{$fh}->{from}=~/(<[^<>]+>)/?$1:$Con{$fh}->{from})."\r\n");
  $Con{$fh}->{getline}=\&RMrcpt;
 }
}
sub RMrcpt { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  RMabort($fh,"rcpt Expected 250, got: $l (from:$Con{$fh}->{from} to:$Con{$fh}->{to})");
 } elsif($l=~/^ *250 /) {
  sendque($fh,"RCPT TO: <$Con{$fh}->{to}>\r\n");
  $Con{$fh}->{getline}=\&RMdata;
 }
}
sub RMdata { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  RMabort($fh,"data Expected 250, got: $l (from:$Con{$fh}->{from} to:$Con{$fh}->{to})");
 } elsif($l=~/^ *250 /) {
  sendque($fh,"DATA\r\n");
  $Con{$fh}->{getline}=\&RMdata2;
 }
}
sub RMdata2 { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  RMabort($fh,"data2 Expected 354, got: $l");
 } elsif($l=~/^ *354 /) {
  my $date=$UseLocalTime ? localtime() : gmtime();
  my $tz=$UseLocalTime ? tzStr() : '+0000';
  $date=~s/(\w+) +(\w+) +(\d+) +(\S+) +(\d+)/$1, $3 $2 $5 $4/;
  my $this=$Con{$fh};
  sendque($fh,<<EOT);
From: $this->{from}\r
To: $this->{to}\r
Subject: $this->{subject}\r
X-Assp-Report: YES\r
Date: $date $tz\r
\r
$this->{body}\r
.\r
EOT
  $Con{$fh}->{getline}=\&RMdone;
 }
}
sub RMdone { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  RMabort($fh,"done Expected 250, got: $l");
 } elsif($l=~/^ *250 /) {
  done2($fh); # close and delete
 }
}
sub RMabort {mlog(0,"RMabort: $_[1]"); done2($_[0]);}

#####################################################################################
#                SPAM Detection

# check if the message is spam, based on Bayesian factors in $Spamdb
sub isspam {
my $msg=$_[0];
$SpamProbConfidence=1;
return $SpamProb=0 if $DoBayesian==0;
 if ($whiteRe && $msg=~('('.$whiteReRE.')')) {
  $subre=substr($1,0,$RegExLength);
  $subre=~ s/\r/ /g;
  $subre=~ s/\n/ /g;
  my $myip=$_[1];
  mlog($fh,"White RE: '$subre'");
  $this->{myheader}.="X-Assp-WhiteRe: $subre\r\n" if $AddRegexHeader; 

 $SpamProbConfidence=1;
 return $SpamProb=0;}
 if ($blackRe && $msg=~('('.$blackReRE.')')) {
 $subre=substr($1,0,$RegExLength);
 $subre=~ s/\r/ /g;
 $subre=~ s/\n/ /g;
 $this->{myheader}.="X-Assp-BlackRe: $subre\r\n" if $AddRegexHeader; 
 mlog($fh,"Black RE: '$subre'");
 $SpamProbConfidence=1;
 return $SpamProb=1;} 
 local $b=clean($_[0]);
 if ($whiteRe && $b=~('('.$whiteReRE.')')) {
 $subre=substr($1,0,$RegExLength);
 $subre=~ s/\r/ /g;
 $subre=~ s/\n/ /g;
 $this->{myheader}.="X-Assp-WhiteRe: $subre\r\n" if $AddRegexHeader; 

 mlog($fh,"White RE: '$subre'");
$SpamProbConfidence=1;
 return  $SpamProb=0;}
 if ($blackRe && $b=~('('.$blackReRE.')')) {
 $subre=substr($1,0,$RegExLength);
 $subre=~ s/\r/ /g;
 $subre=~ s/\n/ /g;
 $this->{myheader}.="X-Assp-BlackRe: $subre\r\n" if $AddRegexHeader; 
 mlog($fh,"Black RE: '$subre'");
 $SpamProbConfidence=1;
 return  $SpamProb=1;}

 return $SpamProb=1 if ($WhitelistOnly);
  
  
 my $ip=$_[1];
 d(31);
 my $ip3=$ip;
 $ip3=~s/(\d+\.\d+\.\d+).*/$1/;
 my ($v,$lt,$t,%seen);
 my @t;
 if(defined($Dnsbl{$ip}) || defined($Dnsbl{$ip3})) {
  mlog('',"$ip dnsbl hit");
  push(@t,0.97);
  push(@t,0.97);
 }
 $ip3=ipNetwork($ip,($PenaltyUseNetblocks ? 24 : 32));
  if(exists $PBBlack{$ip} || exists $PBBlack{$ip3}) {

  push(@t,0.97);
  push(@t,0.97);
 }
 if($greylist) {
  if ($ispip && $ip=~$ISPRE) {
   if ($ispgreyvalue) {
    $v=$ispgreyvalue;
   } else {
    $v=$Greylist{x};
   }
  } else {
   $v=$Greylist{$ip3} || $Greylist{x};
  }
  print DEBUG "gl=$v <$Greylist{$ip3}>\n" if $DEBUG;
  push(@t,$v,$v) if $v;
 }
 while($b=~/([-\$A-Za-z0-9\'\.!\240-\377]+)/g) {
  next if length($1) > 20;
 $lt=$t; $t=lc $1;
  $t=~s/[,.']+$//; $t=~s/!!!+/!!/g; $t=~s/--+/-/g;
  my $j="$lt $t";
  next if $seen{$j}++ >1; # first two occurances are significant
  push(@t,$v) if ($v=$Spamdb{$j});
 }
 @t=sort {abs($b-.5)<=>abs($a-.5)} @t;
 @t=@t[0..30];
 my $p1=1; my $p2=1; foreach $p (@t) {if($p) {$p1*=$p; $p2*=(1-$p);}}
 $SpamProb=$p1/($p1+$p2);
 #$SpamProbConfidence=(1+$p1-$p2)/2;
 $SpamProbConfidence=abs($p1-$p2);

 return $SpamProb<.6? 0: 1;
}

# attach a header line to the message if the config option is set
sub addSpamProb {
 return unless $AddSpamProbHeader;
 my ($fh,$wl)=@_;
 my $this=$Con{$fh};
 return if $NoExternalSpamProb && $this->{relayok};
 my $spamprobheader=sprintf("X-Assp-Spam-Prob: %.5f\r\n",$SpamProb);

 $this->{header}=~s/^X-Assp-Spam-Prob:$HeaderValueRe//gimo; # clear out existing X-Assp-Spam-Prob headers
 $this->{header}=~s/^X-Assp-Bayes-Confidence:$HeaderValueRe//gimo; # clear out existing X-Assp-Spam-Prob headers
 if ($wl) {
  $spamprobheader.="X-Assp-Whitelisted: Yes\r\n";
  $this->{header}=~s/^X-Assp-Whitelisted:$HeaderValueRe//gimo; # clear out existing X-Assp-Whitelisted headers
 }
 if (defined($this->{mailfrom})) {
  $spamprobheader.="X-Assp-Envelope-From: $this->{mailfrom}\r\n";
  $this->{header}=~s/^X-Assp-Envelope-From:$HeaderValueRe//gimo; # clear out existing X-Assp-Envelope-From headers
 }
 # add to our header; merge later, when client sent own headers
 $this->{myheader}.=$spamprobheader;
}

sub setWLDRE {
 SetRE(WLDRE,"($_[0])\$",'i',"Whitelisted Domains");
}

sub setLAFRE {
  my (@uad, @u, @d);
  foreach $a (split(/\|/,$_[0])) {
   if($a=~/\S\@\S/) {
    push(@uad,$a);
   } elsif( $a=~/^\@/ ) {
    push(@d,$a);
   } else {
    push(@u,$a);
   }
  }
  my @s;
  push(@s,'^('.join('|',@uad).')$') if @uad;
  push(@s,'^('.join('|',@u).')@') if @u;
  push(@s,'('.join('|',@d).')$') if @d;
  my $s=join("|",@s);
  $s='<not a valid list>' unless $s;
  SetRE(LAFRE,$s,'i',"LocalAddresses");
}

# see if the address in the mailfrom is on the whitelist meanwhile update the whitelist if that seems appropriate
sub onwhitelist {
 my($fh,$header,$a)=@_;
 d(32);
 my $this=$Con{$fh};
 $a=lc $this->{mailfrom};
 my $whitelisted=$this->{relayok};
  if ($whitelisted) {
  $Stats{locals}++;
 $Stats{localssize}=$Stats{localssize} + $this->{maillength};
   if ($Stats{locals}>0) {
   $Stats{localsavsize}=int($Stats{localssize} / $Stats{locals});
   }}
 return $whitelisted unless $a; # don't add to the whitelist unless there's a valid envelope -- prevent bounced mail from adding to the whitelist
 $this->{red}= ( $Redlist{$a} || ($redRe && $header=~$redReRE));
 my %senders;
 unless($whitelisted) {
  $senders{$a}=1;
  if(! $NotGreedyWhitelist) {
   while($header=~/\n(from|sender|reply-to|errors-to|list-\w+):.*?($EmailAdrRe\@$EmailDomainRe)/igo) {
    $senders{lc $2}=1;
   }
  }
  foreach $a (keys %senders) {
   return 0 if $a && $Redlist{$a};
   next if localmail($a) || $a eq '';
   if($whiteListedDomains && $a=~$WLDRE) {
    d("wld");
    $whitelisted=1;
     mlog($fh,"Whitelisted Domain");
    last;
   } elsif($Whitelist{$a}) {
    d("on whitelist");
    $whitelisted=1;
    last;
   }
  }
  $this->{senders}=join(' ',keys %senders)." "; # used for finding blacklisted domains
  if ($whitelisted) {
  $Stats{whites}++; 
  $Stats{whitessize}=$Stats{whitessize} + $this->{maillength};
   if ($Stats{whites}>0) {
   $Stats{whitesavsize}=int($Stats{whitessize} / $Stats{whites});
   }}
  
 }
 # don't add to whitelist if sender is redlisted
 return $whitelisted if $this->{red} || $WhitelistLocalOnly && !$this->{relayok} || $WhitelistLocalFromOnly && !localmail($this->{mailfrom});
 if($whitelisted) {
  # keep the whitelist up-to-date
  my %a=%senders;
  my $t=time;
  $a{$a}=1;
  $header=~s/\n\s+/ /g;
  while($header=~/\n(to|cc): (.*)/ig) {
   my $a=$2;
   while($a=~/($EmailAdrRe\@$EmailDomainRe)/go) {
    $a{lc $1}=1;
   }
  }
  foreach $a (split(' ',lc $this->{rcpt})) {
   $a{$a}=1;
  }
  foreach $a (keys %a) {
   next if localmail($a) || ! $a;
   next if $Redlist{$a}; # don't add to whitelist if rcpt is redlisted
   next if $whiteListedDomains && $a=~$WLDRE;
   mlog($fh,"whitelist addition: $a") unless $Whitelist{$a};
   $Whitelist{$a}=$t;
  }
  return 1;
 }
 0;
}

# clean up source email
sub clean {
 local $_="\n".shift;
 my ($helo)=/helo=([^)]+)\)/i;
 $helo=~s/(\w+)/ hlo $1 /g if length($helo) > 19; # if the helo string is long, break it up
 my $rcpt="rcpt ".join(" rcpt ",/($EmailAdrRe\@$EmailDomainRe)/g);
 # replace &#ddd encoding
 s/&#(\d{1,3});?/chr($1)/ge;
 # replace base64 encoding
 s/\n([a-zA-Z0-9+\/=]{40,}\r?\n[a-zA-Z0-9+\/=\r\n]+)/base64decode($1)/gse;
 # clean up quoted-printable references
 s/(Subject: .*)=\r?\n/$1\n/;
 s/=\r?\n//g;
 s/=([0-9a-fA-F]{2})/pack("C",hex($1))/gei;
 s/%([0-9a-fA-F][0-9a-fA-F])/pack('C',hex($1))/ge; # replace url encoding
 # strip out mime continuation
 s/.*---=_NextPart_.*\n//g;
 # mark the subject
 s/\nsubject: (.*)/fixsub($1)/ige;
 # remove received lines
 s/\n(received|Content-Type): .*(\n[\t ].*)*//ig;
 # remove other header lines
 s/(\n[a-zA-Z\-]{2,40}: .*(\n[\t ].*)*){2,}//g;
 # clean up &nbsp; and &amp;
 s/&nbsp;?/ /gi; s/&amp;?/and/gi;
 s/(\d),(\d)/$1$2/g;
 s/\r//g; s/ *\n/\n/g;
 s/\n\n\n\n\n+/\nblines blines\n/g;
 # clean up html stuff
 s/<script.*?>\s*(<!\S*)?/ jscripttag jscripttag /ig;
 while(s/(\w+)(<[^>]*>)((<[^>]*>)*\w+)/$2$1$3/g){} # move html out of words
 s/<([biu]|strong)>/ boldifytext boldifytext /gi;
 # remove some tags that are not informative
 s/<\/?(p|br|div|t[dr])[^>]*>/\n/gi; s/<\/([biu]|font|strong)>//gi;
 s/<\/?(html|meta|head|body|span|o)[^>]*>//ig;
 s/(<a\s[^>]*>)(.*?)(<\s*\/a\s*>)/$1.fixlinktext($2).$3/igse;
 s/<\s*\/a\s*>//gi;
 # treat titles like subjects
 s/<title[^>]*>(.*?)<\/title>/fixsub($1)/ige;
 # remove style sheets
 s/<style[^>]*>.*?<\/style>//igs;
 # remove html comments
 s/<!.*?-->//gs; s/<![^>]*>//g;
 # look for random words
 s/[ a-z0-9][ghjklmnpqrstvwxz_]{2}[bcdfghjklmnpqrstvwxz_0-9]{3}\S*/ randword randword /gi;
 # remove mime separators
 s/\n--.*randword.*//g;
 # look for linked images
 s/(<a[^>]*>[^<]*<img)/ linkedimage linkedimage $1/gis;
 s/<[^>]*href\s*=\s*("[^"]*"|\S*)/fixhref($1)/isge;
 s/http:\/\/(\S*)/fixhref($1)/isge;
 s/(\S+\@\S*\.\w{2,3})\b/fixhref($1)/ge;
 "helo: $helo\n$rcpt\n$_";
}

sub fixhref { my $t=shift; $t=~s/(\w+)/ href $1 /g; $t;}

sub fixlinktext { my $t=shift; $t=~s/(\w+)/atxt $1/g; $t;}

sub fixurl {
 my $a=shift;
 $a=~s/%([0-9a-fA-F][0-9a-fA-F])/pack('C',hex($1))/ge;
 $a;
}

sub fixsub {
 my $s=shift;
 $s=~s/ {3,}/ lotsaspaces /g;
 $s=~s/(\S+)/ssub $1/g;
 "\n$s ssub";
}

sub base64decode {
 my $str = shift;
 my $res;
 $str =~ tr|A-Za-z0-9+/||cd;
 $str =~ tr|A-Za-z0-9+/| -_|;
 while ($str =~ /(.{1,60})/gs) {
  my $len = chr(32 + length($1)*3/4);
  $res .= unpack("u", $len . $1 );
 }
 $res;
}

sub downloadGrey {
 # let's check if we really need to
 my @s=stat("$base/$greylist");
 my $mtime=$s[9];
 if(time - $mtime< 12*3600) {
  $NextGreylistDownload=$mtime + 12*3600;
  return;
 }
 my $peeraddress,$connect;
 if ($proxyserver) {
  mlog(0,"freshening greylist via proxy:$proxyserver") if $MaintenanceLog;
  $peeraddress = $proxyserver;
  $connect = "GET http://assp.sourceforge.net/greylist.txt HTTP/1.0

";
 } else {
  mlog(0,"freshening greylist via direct connection") if $MaintenanceLog;
  $peeraddress = "assp.sourceforge.net:80";
  $connect = "GET /greylist.txt HTTP/1.1
Host: assp.sourceforge.net

";
 }
 my $s=new IO::Socket::INET(Proto=>'tcp',PeerAddr=>$peeraddress,Timeout=>2);
 if($s) {
  print $s $connect;
  $SocketCalls{$s}=\&GreyTraffic;
  $readable->add($s);
  $NextGreylistDownload=time+3600*12;
  open(GREYTEMP,">$base/$greylist.tmp");
  binmode(GREYTEMP);
  $GreyListLen=0;
 } else {
  mlog(0,"unable to connect to greylist server");
  $NextGreylistDownload=time+3600;
 }
}

sub GreyTraffic {
 my $fh=shift;
 my $buf;
 if($fh->sysread($buf,4096)>0) {
  if(!$GreyListLen) {
   # look for http header
   if($buf=~/content-length: (\d+)/i) {
    $GreyListLen=$1;
   }
   if($buf=~/(.*?)\n\r?\n(.*)/s) {
    $buf=$2;
   }
  }
  if($GreyListLen > 0) {
   print GREYTEMP $buf;
   $GreyListLen-=length($buf);
   if(! $GreyListLen) {
    close GREYTEMP;
    unlink("$base/$greylist");
    rename("$base/$greylist.tmp","$base/$greylist");
    mlog(0,"greylist download complete") if $MaintenanceLog;
    if($GreylistObject) {
     $GreylistObject->resetCache();
    } else {
     $GreylistObject=tie %Greylist,orderedtie,"$base/$greylist" if $greylist;
    }
    $readable->remove($fh);
    $fh->close;
   }
  }
 } else {
  # greylist download interrupted
  $readable->remove($fh);
  $fh->close;
  close(GREYTEMP);
  mlog(0,"greylist download interrupted");
 }
}

sub uploadStats {
 my $peeraddress,$connect;
 if ($proxyserver) {
  mlog(0,"uploading stats via proxy:$proxyserver") if $MaintenanceLog;
  $peeraddress = $proxyserver;
  $connect = "POST http://assp.sourceforge.net/cgi-bin/upload.pl HTTP/1.0";
 } else {
  mlog(0,"uploading stats via direct connection") if $MaintenanceLog;
  $peeraddress = "assp.sourceforge.net:80";
  $connect = "POST /cgi-bin/upload.pl HTTP/1.1
Host: assp.sourceforge.net";
 }
 my $s=new IO::Socket::INET(Proto=>'tcp',PeerAddr=>$peeraddress,Timeout=>2);
 if($s) {
  my %UploadStats;
  my %tots=statsTotals();
  $UploadStats{starttime}=$Stats{starttime};
  $UploadStats{version}=$Stats{version};
  $UploadStats{pid}=$$;
  $UploadStats{timenow}=time;
  $UploadStats{testmode}=unpack "C", pack "B*", "0$baysTestMode$blTestMode$hlTestMode$sbTestMode$spfTestMode$rblTestMode$srsTestMode";
  $UploadStats{messages}=$tots{msgTotal}; # legacy
  $UploadStats{locals}=$Stats{locals};
  $UploadStats{whites}=$Stats{whites};
  $UploadStats{noprocessing}=$Stats{noprocessing};
  # for legacy support, $UploadStats{spams} are effectively non Bayesian spams.
  $UploadStats{spams}=$tots{msgRejectedTotal}-$Stats{bspams}; # legacy
  $UploadStats{blacklisted}=$Stats{blacklisted};
  $UploadStats{helolisted}=$Stats{helolisted};
  $UploadStats{spambucket}=$Stats{spambucket};
  $UploadStats{bhams}=$Stats{bhams};
  $UploadStats{bspams}=$Stats{bspams};
  $UploadStats{viri}=$Stats{viri}+$Stats{viridetected}; # legacy
  $UploadStats{viridetected}=$Stats{viridetected};
  $UploadStats{norelays}=$tots{rcptRelayRejected}; # legacy
  $UploadStats{connects}=$tots{smtpConnTotal}; # legacy
  $UploadStats{spamlover}=$Stats{spamlover};
  $UploadStats{bombs}=$Stats{bombs};
  $UploadStats{scripts}=$Stats{scripts};
  $UploadStats{spffails}=$Stats{spffails};
  $UploadStats{rblfails}=$Stats{rblfails}+$Stats{rblcachehit};
  $UploadStats{nextUpload}=$Stats{nextUpload};
  my $content=join("\001",%UploadStats);
  my $len=length($content);
  $connect.="
Content-Type: application/x-www-form-urlencoded
Content-Length: $len

$content";
  print $s $connect;
  $s->close;
 } else {
  mlog(0,"unable to connect to stats server");
 }
 $Stats{nextUpload}=time+3600*8;
}

sub ResetStats {
 $Stats{nextUpload}=time+3600*8;
 $Stats{cpuTime}=0;
 $Stats{cpuBusyTime}=0;
 $Stats{smtpConn}=0;
 $Stats{smtpConnNotLogged}=0;
 $Stats{smtpConnLimit}=0;
 $Stats{smtpConnLimitIP}=0;
 $Stats{smtpConnDenied}=0;
 $Stats{smtpConnIdleTimeout}=0;
 $Stats{smtpMaxConcurrentSessions}=0;
 $Stats{admConn}=0;
 $Stats{admConnDenied}=0;
 $Stats{rcptValidated}=0;
 $Stats{rcptUnchecked}=0;
 $Stats{rcptSpamLover}=0;
 $Stats{rcptWhitelisted}=0;
 $Stats{rcptNotWhitelisted}=0;
 $Stats{rcptUnprocessed}=0;
 $Stats{rcptReportSpam}=0;
 $Stats{rcptReportHam}=0;
 $Stats{rcptReportWhitelistAdd}=0;
 $Stats{rcptReportWhitelistRemove}=0;
 $Stats{rcptReportRedlistAdd}=0;
 $Stats{rcptReportRedlistRemove}=0;
 $Stats{rcptNonexistent}=0;
 $Stats{rcptDelayed}=0;
 $Stats{rcptDelayedLate}=0;
 $Stats{rcptDelayedExpired}=0;
 $Stats{rcptEmbargoed}=0;
 $Stats{rcptSpamBucket}=0;
 $Stats{rcptRelayRejected}=0;
 $Stats{senderInvalidLocals}=0;
 $Stats{senderBombs}=0;
 $Stats{pbdenied}=0;
 $Stats{msgMaxErrors}=0;
 $Stats{msgDelayed}=0;
 $Stats{msgNoRcpt}=0;
 $Stats{msgNoSRSBounce}=0;
 $Stats{bhams}=0;

 $Stats{whites}=0;

 $Stats{locals}=0;

 $Stats{noprocessing}=0;

 $Stats{spamlover}=0;
 
 $Stats{bspams}=0;

 $Stats{blacklisted}=0;
 $Stats{invalidHelo}=0;
 $Stats{forgedHelo}=0;
 $Stats{mxaMissing}=0;
 $Stats{ptrMissing}=0;
 $Stats{helolisted}=0;
 $Stats{spambucket}=0;
 $Stats{spamtrap}=0;
 $Stats{viri}=0;
 $Stats{viridetected}=0;
 $Stats{bombs}=0;

 $Stats{scripts}=0;
 $Stats{spffails}=0;
 $Stats{rblfails}=0;
 $Stats{rblcachehits}=0;
 open(F,"<$base/asspstats.sav");
 (%OldStats)=split(/\001/,<F>);
 close F;
 # conversion from previous versions
 if (exists $OldStats{messages}) {
  $OldStats{smtpConn}=$OldStats{connects};
  $OldStats{smtpConnLimit}=$OldStats{maxSMTP};
  $OldStats{smtpConnLimitIP}=$OldStats{maxSMTPip};
  $OldStats{viri}-=$OldStats{viridetected}; # fix double counting
  $OldStats{rcptRelayRejected}=$OldStats{norelays};
  # remove unused entries
  delete $OldStats{connects};
  delete $OldStats{maxSMTP};
  delete $OldStats{maxSMTPip};
  delete $OldStats{messages};
  delete $OldStats{spams};
  delete $OldStats{hams};
  delete $OldStats{norelays};
  delete $OldStats{testmode};
  SaveStats();
 }
}

sub SaveStats {
 %AllStats=%OldStats;
 foreach (keys %Stats) {
  if ($_ eq 'version') {
   # just copy
   $AllStats{$_}=$Stats{$_};
  } elsif ($_ eq 'smtpMaxConcurrentSessions') {
   # pick greater value
   $AllStats{$_}=$Stats{$_} if $Stats{$_}>$AllStats{$_};
  } else {
   $AllStats{$_}+=$Stats{$_};
  }
 }
 $AllStats{starttime}=$OldStats{starttime} || $Stats{starttime};
 open(F,">$base/asspstats.sav");
 print F join("\001",%AllStats);
 close F;
}

#####################################################################################
#                Maillog functions


# find an appropriate name for a maillog file
sub maillogFilename {my $isspam=shift;
 my @dirs=($notspamlog,$spamlog,$incomingOkMail,$viruslog);
 my $maillog=$dirs[$isspam];
 d(19);
 if($UseSubjectsAsMaillogNames || $isspam==2 || $isspam==3) {
  my($sub)=$_[0]=~/Subject: (.*)/;
  $sub=~y/a-zA-Z0-9/_/cs;
  $sub=substr($sub,0,50);
  $sub.="--".(++$Counter);
  return "$base/$maillog/$sub$maillogExt";
 } else {
  my $fn=(time + $Counter++ ) % $MaxFiles;
  "$base/$maillog/$fn$maillogExt";
 }
}

# integrated mail collection subroutine
sub MaillogStart {
 d(361);
 $Con{$_[0]}->{maillog}=1 unless $NoMaillog;
 $Con{$_[0]}->{maillogbuf}=$Con{$_[0]}->{header}=$Con{$_[0]}->{rcvd};
}
sub Maillog {
 my ($fh,$text,$parm)=@_;
 my $fln;
 # parm = 2 -- not spam, 3 -- is spam, 4 -- mail ok
 # 5 -- virii, 6 -- ignore, 7 -- ignore && cc to spamaccount (not working)
return unless $Con{$fh}->{maillog};
 my $skipLog=0;
 if ($parm == 2 || $parm == 3) {
  $logCount[$parm]++;
  $skipLog=1 if ($logFreq[$parm]>$logCount[$parm]);
 }
 if($parm == 4 && !$incomingOkMail || $parm == 5 && !$viruslog || $parm == 6 ||  $parm == 7 && $Con{$Con{$fh}->{forwardSpam}}->{ready} || $skipLog) {
  d(364);
  delete $Con{$fh}->{maillogbuf};
  delete $Con{$fh}->{maillog};
  close $Con{$fh}->{maillogfh} if $Con{$fh}->{maillogfh};
  delete $Con{$fh}->{maillogfh};
  delete $Con{$fh}->{mailloglength};
 } elsif($parm > 1 ) {
   
  d(362);
  $logCount[$parm]=0;
  # we now know if it is spam or not -- open the file
  $text=$Con{$fh}->{maillogbuf}.$text;
if($parm != 7 ) {
  delete $Con{$fh}->{maillogbuf};
  
  my $fn=maillogFilename($parm-2,$text);
  $fln=$fn;
  $FH='FHaaaaa' unless $FH;
  if(open(++$FH,">$fn")) {
   $Con{$fh}->{maillogfh}=$FH;
   $Con{$fh}->{mailloglength}=0;
   binmode $FH;
  } else {
   mlog($fh,"error opening maillog '$fn': $!");
  }} 
  # start sending the message to sendAllSpam if appropriate

if($ccAddressesMode) {
		$Con{$fh}->{forwardSpam}=forwardSpam($Con{$fh}->{mailfrom},$sendAllSpam,$fh) if (($parm==3 || $parm==7) && $sendAllSpam && allccAddresses($this->{rcpt}));
	} else {
		$Con{$fh}->{forwardSpam}=forwardSpam($Con{$fh}->{mailfrom},$sendAllSpam,$fh) if (($parm==3 || $parm==7) && $sendAllSpam);
	}
if($ccArchivModeRec) {
	if(($parm==2 || $parm==4) && $sendHamRec && allccArchivAddressesRec($this->{rcpt})) {

  	  	$Con{$fh}->{forwardSpam}=forwardSpam($Con{$fh}->{mailfrom},$sendHamRec,$fh);
}} 
}
if(my $h=$Con{$fh}->{maillogfh}) {
  print $h $text;
  if(($Con{$fh}->{mailloglength}+=length($text))>$MaxBytes || $text=~/(^|[\r\n])\.[\r\n]/) {
   d(366);
   close $h;
   delete $Con{$fh}->{maillog} unless $Con{$fh}->{forwardSpam};
   delete $Con{$fh}->{maillogfh};
   delete $Con{$fh}->{mailloglength};
  }
 } elsif(length($Con{$fh}->{maillogbuf})<$MaxBytes) {
  $Con{$fh}->{maillogbuf}.=$text;
 }
 if($Con{$fh}->{forwardSpam}) {
  my $t=$Con{$Con{$fh}->{forwardSpam}};
  if($t->{ready}) {
   sendque($Con{$fh}->{forwardSpam},$text);
  } else {
   $t->{body}.=$text;
  }
 }
return $fln;
}


sub forwardSpam {
 my ($from,$to,$oldfh)=@_;
 my $destination;
 if ($smtpDestination =~ /^(__INBOUND__:)?(\d+)$/){
   $destination = '127.0.0.1:'.$2;
 }
 else{
   $destination = $smtpDestination;
 }
 my $s=new IO::Socket::INET(Proto=>'tcp',PeerAddr=>$destination,Timeout=>2);
 if(! $s) {
  mlog('',"couldn't create server socket to $destination -- aborting sendAllSpam connection");
  return;
 }
 addfh($s,\&FShelo);
 my $this=$Con{$s};
 $this->{ready}=0;
 $this->{to}=$to;
 $this->{from}=$from;
 $this->{rcpt}=$Con{$fh}->{rcpt};
 $this->{myheader}=$Con{$fh}->{myheader};
 $s;
}
sub FShelo { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  FSabort($fh,"helo Expected 220, got: $l");
 } elsif($l=~/^ *220 /) {
  sendque($fh,"HELO $myName\r\n");
  $Con{$fh}->{getline}=\&FSfrom;
 }
}
sub FSfrom { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  FSabort($fh,"from Expected 250, got: $l");
 } elsif($l=~/^ *250 /) {
  sendque($fh,"MAIL FROM: <$Con{$fh}->{from}>\r\n");
  $Con{$fh}->{getline}=\&FSrcpt;
 }
}
sub FSrcpt { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  FSabort($fh,"rcpt Expected 250, got: $l");
 } elsif($l=~/^ *250 /) {
  sendque($fh,"RCPT TO: <$Con{$fh}->{to}>\r\n");
  $Con{$fh}->{getline}=\&FSdata;
 }
}
sub FSdata { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  FSabort($fh,"data Expected 250, got: $l");
 } elsif($l=~/^ *250 /) {
  sendque($fh,"DATA\r\n");
  $Con{$fh}->{getline}=\&FSdata2;
 }
}
sub FSdata2 { my ($fh,$l)=@_;
 if($l=~/^ *5/) {
  FSabort($fh,"data2 Expected 354, got: $l");
 } elsif($l=~/^ *354 /) {
  my $this=$Con{$fh};
  $this->{body}=~s/^($HeaderRe*)/$1From: sender not supplied\r\n/o unless $this->{body}=~/^$HeaderRe*From:/io; # add From: if missing
  $this->{body}=~s/^($HeaderRe*)/$1Subject:\r\n/o unless $this->{body}=~/^$HeaderRe*Subject:/io; # add Subject: if missing
  $this->{body}=~s/^Subject:/Subject: $spamSubject/gim if ($spamSubjectCC && $spamSubject);
  # merge our header, add X-Intended-For header
  $this->{myheader}=headerWrap($this->{myheader}); # wrap long lines
    $this->{body}=~s/^($HeaderRe*)/$1\r\n\n\n\r$this->{myheader}X-Intended-For: $this->{rcpt}\r\n/o;
$this->{body}=~s/\r?\n?\r\n\n\n\r/\r\n/;
  
  sendque($fh,$this->{body}) if $this->{body};
  $this->{ready}=1;
  $this->{body}='';
  $Con{$fh}->{getline}=\&FSdone;
 }
}
sub FSdone { my ($fh,$l)=@_;

 if($l=~/^ *5/) {
  FSabort($fh,"done Expected 250, got: $l");
 } elsif($l=~/^ *250 /) {

done2($fh); # close and delete
 }
}
sub FSabort {mlog(0,"FSabort: $_[1]"); done2($_[0]);}

#####################################################################################
#                Web Configuration functions

sub webRequest {
 my ($tempfh,$fh,$head,$data)=@_;
 %webRequests=(
  '/lists' => \&ConfigLists,
  '/maillog' => \&ConfigMaillog,
  '/analyze' => \&ConfigAnalyze,
  '/infostats' => \&ConfigStats,
  '/edit' => \&ConfigEdit,
  '/shutdown' => \&Shutdown,
  '/shutdown_frame' => \&ShutdownFrame,
  '/shutdown_list' => \&ShutdownList,
  '/donations' => \&Donations,
  '/get' => \&GetFile
 );
 my $i=0;
 # %head -- public hash
 (%head)=map{++$i % 2 ? lc $_ : $_} map/^([^ :]*)[: ]{0,2}(.*)/, split(/\r\n/,$head);
 my ($page,$qs)=($head{get} || $head{head} || $head{post})=~/^([^\? ]+)(?:\?(\S*))?/;
 if(defined $data) { # GET, POST order
  $qs.='&' if ($qs ne '');
  $qs.=$data;
 }
 $qs=~y/+/ /;
 $i=0;
 # parse query string, get rid of google autofill
 # %qs -- public hash
 (%qs)=map{s/(e)_(mail)/$1$2/gi if ++$i % 2; $_} split(/[=&]/,$qs);
 foreach $k (keys %qs) {$qs{$k}=~s/%([0-9a-fA-F][0-9a-fA-F])/pack(C,hex($1))/ge}
 my ($auth)=$head{authorization}=~/Basic (\S+)/i;
 my ($user,$pass)=split(':',base64decode($auth));
 my $ip=$fh->peerhost();
 my $port=$fh->peerport();
 if($pass eq $webAdminPassword) {
  if ($page!~/shutdown_frame|shutdown_list|favicon.ico|get/i) {
   # only count requests for pages without meta refresh tag
   # dont count requests for favicon.ico file
   # dont count requests for 'get' page
   my $args;
   if ($page=~/edit/i) {
    if (defined($qs{contents})) {
     $args="writing file:$qs{file}";
    } else {
     $args="reading file:$qs{file}";
    }
   }
   if ($args) {
    mlog('',"admin connection from $ip:$port; page:$page; $args");
   } else {
    mlog('',"admin connection from $ip:$port; page:$page");
   }
   $Stats{admConn}++;
  }
  ConfigQuit($tempfh) if $page=~/quit/i;
  if ($page=~/favicon.ico/i) {
   print $tempfh "HTTP/1.1 404 Not Found
Content-type: text/html

<html><body><h1>Not found</h1>
</body></html>\n";
  } else {
   print $tempfh ((defined ($v=$webRequests{$page}))? $v->($head,$qs): webConfig($head,$qs));
  }
 } else {
  if ($pass ne '') {
   mlog('',"admin connection from $ip:$port; page:$page rejected -- authorization failed");
   $Stats{admConnDenied}++;
  }
  print $tempfh "HTTP/1.1 401 Unauthorized
WWW-Authenticate: Basic realm=\"Anti-Spam SMTP Proxy (ASSP) Configuration\"
Content-type: text/html

<html><body><h1>Unauthorized</h1>
</body></html>\n";
 }
}

sub ConfigQuit {
 mlog('',"quit requested from admin interface");
 &SaveWhitelist;
 my $fh=shift;
 print $fh "HTTP/1.1 200 OK
Content-type: text/html

<html><body><h1>ASSP Terminated.</h1>
</body></html>
";
 exit;
}

# compute various totals
sub statsTotals {
 my %s;
 $s{smtpConnIdleTimeout}=$Stats{smtpConnIdleTimeout};
 $s{smtpConnIdleTimeout2}=$AllStats{smtpConnIdleTimeout};
 $s{smtpConnAcceptedTotal}=$Stats{smtpConn}+$Stats{smtpConnNotLogged};
 $s{smtpConnAcceptedTotal2}=$AllStats{smtpConn}+$AllStats{smtpConnNotLogged};
 $s{smtpConnLimit}=$Stats{smtpConnLimit}+$Stats{smtpConnLimitIP};
 $s{smtpConnLimit2}=$AllStats{smtpConnLimit}+$AllStats{smtpConnLimitIP};
 $s{smtpConnRejectedTotal}=$s{smtpConnLimit}+$Stats{smtpConnDenied};
 $s{smtpConnRejectedTotal2}=$s{smtpConnLimit2}+$AllStats{smtpConnDenied};
 $s{smtpConnTotal}=$s{smtpConnAcceptedTotal}+$s{smtpConnRejectedTotal};
 $s{smtpConnTotal2}=$s{smtpConnAcceptedTotal2}+$s{smtpConnRejectedTotal2};
 $s{admConnTotal}=$Stats{admConn}+$Stats{admConnDenied};
 $s{admConnTotal2}=$AllStats{admConn}+$AllStats{admConnDenied};
 $s{rcptAcceptedLocal}=$Stats{rcptValidated}+$Stats{rcptUnchecked}+$Stats{rcptSpamLover};
 $s{rcptAcceptedLocal2}=$AllStats{rcptValidated}+$AllStats{rcptUnchecked}+$AllStats{rcptSpamLover};
 $s{rcptAcceptedRemote}=$Stats{rcptWhitelisted}+$Stats{rcptNotWhitelisted};
 $s{rcptAcceptedRemote2}=$AllStats{rcptWhitelisted}+$AllStats{rcptNotWhitelisted};
 $s{rcptUnprocessed}=$Stats{rcptUnprocessed};
 $s{rcptUnprocessed2}=$AllStats{rcptUnprocessed};
 $s{rcptReport}=$Stats{rcptReportSpam}+$Stats{rcptReportHam}+$Stats{rcptReportWhitelistAdd}+$Stats{rcptReportWhitelistRemove}+$Stats{rcptReportRedlistAdd}+$Stats{rcptReportRedlistRemove};
 $s{rcptReport2}=$AllStats{rcptReportSpam}+$AllStats{rcptReportHam}+$AllStats{rcptReportWhitelistAdd}+$AllStats{rcptReportWhitelistRemove}+$AllStats{rcptReportRedlistAdd}+$AllStats{rcptReportRedlistRemove};
 $s{rcptAcceptedTotal}=$s{rcptAcceptedLocal}+$s{rcptAcceptedRemote}+$s{rcptUnprocessed}+$s{rcptReport};
 $s{rcptAcceptedTotal2}=$s{rcptAcceptedLocal2}+$s{rcptAcceptedRemote2}+$s{rcptUnprocessed2}+$s{rcptReport2};
 $s{rcptRejectedLocal}=$Stats{rcptNonexistent}+$Stats{rcptDelayed}+$Stats{rcptDelayedLate}+$Stats{rcptDelayedExpired}+
                       $Stats{rcptEmbargoed}+$Stats{rcptSpamBucket};
 $s{rcptRejectedLocal2}=$AllStats{rcptNonexistent}+$AllStats{rcptDelayed}+$AllStats{rcptDelayedLate}+$AllStats{rcptDelayedExpired}+
                        $AllStats{rcptEmbargoed}+$AllStats{rcptSpamBucket};
 $s{rcptRejectedRemote}=$Stats{rcptRelayRejected};
 $s{rcptRejectedRemote2}=$AllStats{rcptRelayRejected};
 $s{rcptRejectedTotal}=$s{rcptRejectedLocal}+$s{rcptRejectedRemote};
 $s{rcptRejectedTotal2}=$s{rcptRejectedLocal2}+$s{rcptRejectedRemote2};
 $s{rcptTotal}=$s{rcptAcceptedTotal}+$s{rcptRejectedTotal};
 $s{rcptTotal2}=$s{rcptAcceptedTotal2}+$s{rcptRejectedTotal2};
 $s{msgAcceptedTotal}=$Stats{bhams}+$Stats{whites}+$Stats{locals}+$Stats{noprocessing}+$Stats{spamlover};
 $s{msgAcceptedTotal2}=$AllStats{bhams}+$AllStats{whites}+$AllStats{locals}+$AllStats{noprocessing}+$AllStats{spamlover};
 $s{msgRejectedTotal}=$Stats{bspams}+$Stats{blacklisted}+$Stats{helolisted}+$Stats{spambucket}+$Stats{spamtrap}+$Stats{viri}+
                      $Stats{viridetected}+$Stats{bombs}+$Stats{invalidHelo}+$Stats{ptrMissing}+$Stats{mxaMissing}+$Stats{forgedHelo}+$Stats{pbdenied}+$Stats{senderBombs}+$Stats{senderInvalidLocals}+$Stats{scripts}+$Stats{spffails}+$Stats{rblfails}+$Stats{rblcachehits}+
                      $Stats{msgMaxErrors}+$Stats{msgDelayed}+$Stats{msgNoRcpt}+$Stats{msgNoSRSBounce};
 $s{msgRejectedTotal2}=$AllStats{bspams}+$AllStats{blacklisted}+$AllStats{helolisted}+$AllStats{spambucket}+$AllStats{viri}+
                       $AllStats{viridetected}+$AllStats{bombs}+$AllStats{forgedHelo}+$AllStats{invalidHelo}+$AllStats{pbdenied}+$AllStats{senderBombs}+$AllStats{senderInvalidLocals}+$AllStats{scripts}+$AllStats{spffails}+$AllStats{rblfails}+
                       $AllStats{msgMaxErrors}+$AllStats{msgDelayed}+$AllStats{msgNoRcpt}+$AllStats{msgNoSRSBounce};
 $s{msgTotal}=$s{msgAcceptedTotal}+$s{msgRejectedTotal};
 $s{msgTotal2}=$s{msgAcceptedTotal2}+$s{msgRejectedTotal2};
 %s;
}

sub ConfigStats {
 SaveStats();
 my %tots=statsTotals();
 my $upt=(time-$Stats{starttime})/(24*3600);
 my $upt2=(time-$AllStats{starttime})/(24*3600);
 my $uptime=sprintf("%.3f",$upt);
 my $uptime2=sprintf("%.3f",$upt2);
 my $mpd=sprintf("%.1f",$upt==0 ? 0 : $tots{msgTotal}/$upt);
 my $mpd2=sprintf("%.1f",$upt2==0 ? 0 : $tots{msgTotal2}/$upt2);
 my $pct=sprintf("%.1f",$tots{msgTotal}-$Stats{locals}==0 ? 0 : 100*$tots{msgRejectedTotal}/($tots{msgTotal}-$Stats{locals}));
 my $pct2=sprintf("%.1f",$tots{msgTotal2}-$AllStats{locals}==0 ? 0 : 100*$tots{msgRejectedTotal2}/($tots{msgTotal2}-$AllStats{locals}));
 my $cpu=$CanStatCPU ? sprintf("%.2f\%",100*$cpuUsage) : 'n/a';
 my $cpuAvg=sprintf(" (%.2f\% avg)",$Stats{cpuTime}==0 ? 0 : 100*$Stats{cpuBusyTime}/$Stats{cpuTime}) if $CanStatCPU;
 my $cpuAvg2=$CanStatCPU ? sprintf("%.2f\% avg",$AllStats{cpuTime}==0 ? 0 : 100*$AllStats{cpuBusyTime}/$AllStats{cpuTime}) : 'n/a';
<<EOT;
$headerHTTP
$headerDTDStrict
$headers
<script type=\"text/javascript\">
<!--
  function toggleTbody(id) {
    if (document.getElementById) {
      var tbod = document.getElementById(id);
      if (tbod && typeof tbod.className == 'string') {
        if (tbod.className == 'off') {
          tbod.className = 'on';
        } else {
          tbod.className = 'off';
        }
      }
    }
    return false;
  }
//-->
</script>
<div class="content"><h2>ASSP Information and Statistics</h2>
<br />
<table class="statBox">

<thead>
<tr><td colspan="5" class="sectionHeader" onmousedown="toggleTbody('StatItem3')">General Runtime Information</td></tr>
</thead>
<tbody id="StatItem3" class="on">
<tr><td class="statsOptionTitle"><b>ASSP Proxy Uptime:</b></td>
<td class="statsOptionValue" colspan="2">$uptime days</td>
<td class="statsOptionValue" colspan="2">$uptime2 days</td>
</tr>
<tr><td class="statsOptionTitle"><b>Messages Processed:</b></td>
<td class="statsOptionValue" colspan="2">$tots{msgTotal} ($mpd per day)</td>
<td class="statsOptionValue" colspan="2">$tots{msgTotal2} ($mpd2 per day)</td>
</tr>
<tr><td class="statsOptionTitle"><b>Non-Local Mail Blocked:</b></td>
<td class="statsOptionValue" colspan="2">$pct%</td>
<td class="statsOptionValue" colspan="2">$pct2%</td>
</tr>
<tr><td class="statsOptionTitle"><b>CPU Usage:</b></td>
<td class="statsOptionValue" colspan="2">$cpu$cpuAvg</td>
<td class="statsOptionValue" colspan="2">$cpuAvg2</td>
</tr>
<tr><td class="statsOptionTitle"><b>Concurrent SMTP Sessions:</b></td>
<td class="statsOptionValue" colspan="2">$smtpConcurrentSessions ($Stats{smtpMaxConcurrentSessions} max)</td>
<td class="statsOptionValue" colspan="2">$AllStats{smtpMaxConcurrentSessions} max</td>
</tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since restart</i></td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since reset</i></td>
 </tr>
</tbody>
<tbody>
<tr><td colspan="5" class="sectionHeader" onmousedown="toggleTbody('StatItem4')">Totalled Statistics</td></tr>
</tbody>
<tbody id="StatItem4" class="off">
<tr><td class="statsOptionTitle"><b>SMTP Connections Received:</b></td>
<td class="statsOptionValue" colspan="2">$tots{smtpConnTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{smtpConnTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;SMTP Connections Accepted:</b></td>
<td class="statsOptionValue" colspan="2">$tots{smtpConnAcceptedTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{smtpConnAcceptedTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;SMTP Connections Rejected:</b></td>
<td class="statsOptionValue" colspan="2">$tots{smtpConnRejectedTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{smtpConnRejectedTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Envelope Recipients Processed:</b></td>
<td class="statsOptionValue" colspan="2">$tots{rcptTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{rcptTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Envelope Recipients Accepted:</b></td>
<td class="statsOptionValue" colspan="2">$tots{rcptAcceptedTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{rcptAcceptedTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Envelope Recipients Rejected:</b></td>
<td class="statsOptionValue" colspan="2">$tots{rcptRejectedTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{rcptRejectedTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Messages Processed:</b></td>
<td class="statsOptionValue" colspan="2">$tots{msgTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{msgTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Messages Passed:</b></td>
<td class="statsOptionValue" colspan="2">$tots{msgAcceptedTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{msgAcceptedTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Messages Blocked:</b></td>
<td class="statsOptionValue" colspan="2">$tots{msgRejectedTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{msgRejectedTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Admin Connections Received:</b></td>
<td class="statsOptionValue" colspan="2">$tots{admConnTotal}</td>
<td class="statsOptionValue" colspan="2">$tots{admConnTotal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Admin Connections Accepted:</b></td>
<td class="statsOptionValue" colspan="2">$Stats{admConn}</td>
<td class="statsOptionValue" colspan="2">$AllStats{admConn}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Admin Connections Rejected:</b></td>
<td class="statsOptionValue" colspan="2">$Stats{admConnDenied}</td>
<td class="statsOptionValue" colspan="2">$AllStats{admConnDenied}</td>
</tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since restart</i></td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since reset</i></td>
 </tr>
</tbody>
<tbody>
<tr><td colspan="5" class="sectionHeader" onmousedown="toggleTbody('StatItem5')">SMTP Connections Statistics</td></tr>
</tbody>
<tbody id="StatItem5" class="off">
<tr><td class="statsOptionTitle"><b>Accepted Logged SMTP Connections:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{smtpConn}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{smtpConn}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Not Logged SMTP Connections:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{smtpConnNotLogged}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{smtpConnNotLogged}</td>
</tr>
<tr><td class="statsOptionTitle"><b>SMTP Connection Limits:</b></td>
<td class="statsOptionValue negative" colspan="2">$tots{smtpConnLimit}</td>
<td class="statsOptionValue negative" colspan="2">$tots{smtpConnLimit2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Overall Limits:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{smtpConnLimit}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{smtpConnLimit}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;By IP Limits:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{smtpConnLimitIP}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{smtpConnLimitIP}</td>
</tr>
<tr><td class="statsOptionTitle"><b>SMTP Connections Timeout:</b></td>
<td class="statsOptionValue negative" colspan="2">$tots{smtpConnIdleTimeout}</td>
<td class="statsOptionValue negative" colspan="2">$tots{smtpConnIdleTimeout2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Denied SMTP Connections:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{smtpConnDenied}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{smtpConnDenied}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Denied SMTP Connections(PB):</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{smtpConnPBDenied}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{smtpConnPBDenied}</td>
</tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since restart</i></td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since reset</i></td>
 </tr>
</tbody>
<tbody>
<tr><td colspan="5" class="sectionHeader" onmousedown="toggleTbody('StatItem6')">Envelope Recipients Statistics</td></tr>
</tbody>
<tbody id="StatItem6" class="off">
<tr><td class="statsOptionTitle"><b>Local Recipients Accepted:</b></td>
<td class="statsOptionValue positive" colspan="2">$tots{rcptAcceptedLocal}</td>
<td class="statsOptionValue positive" colspan="2">$tots{rcptAcceptedLocal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Validated Recipients:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptValidated}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptValidated}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Unchecked Recipients:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptUnchecked}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptUnchecked}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Spam-Lover Recipients:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptSpamLover}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptSpamLover}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Remote Recipients Accepted:</b></td>
<td class="statsOptionValue positive" colspan="2">$tots{rcptAcceptedRemote}</td>
<td class="statsOptionValue positive" colspan="2">$tots{rcptAcceptedRemote2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Whitelisted Recipients:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptWhitelisted}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptWhitelisted}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Not Whitelisted Recipients:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptNotWhitelisted}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptNotWhitelisted}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Noprocessed Recipients:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptUnprocessed}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptUnprocessed}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Email Reports:</b></td>
<td class="statsOptionValue positive" colspan="2">$tots{rcptReport}</td>
<td class="statsOptionValue positive" colspan="2">$tots{rcptReport2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Spam Reports:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptReportSpam}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptReportSpam}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Ham Reports:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptReportHam}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptReportHam}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Whitelist Additions:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptReportWhitelistAdd}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptReportWhitelistAdd}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Whitelist Deletions:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptReportWhitelistRemove}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptReportWhitelistRemove}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Redlist Additions:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptReportRedlistAdd}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptReportRedlistAdd}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Redlist Deletions:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{rcptReportRedlistRemove}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{rcptReportRedlistRemove}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Local Recipients Rejected:</b></td>
<td class="statsOptionValue negative" colspan="2">$tots{rcptRejectedLocal}</td>
<td class="statsOptionValue negative" colspan="2">$tots{rcptRejectedLocal2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Nonexistent Recipients:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptNonexistent}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptNonexistent}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Delayed Recipients:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptDelayed}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptDelayed}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Delayed (Late) Recipients:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptDelayedLate}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptDelayedLate}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Delayed (Expired) Recipients:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptDelayedExpired}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptDelayedExpired}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Embargoed Recipients:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptEmbargoed}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptEmbargoed}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Spam Bucketed Recipients:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptSpamBucket}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptSpamBucket}</td>
</tr>

<tr><td class="statsOptionTitle"><b>Remote Recipients Rejected:</b></td>
<td class="statsOptionValue negative" colspan="2">$tots{rcptRejectedRemote}</td>
<td class="statsOptionValue negative" colspan="2">$tots{rcptRejectedRemote2}</td>
</tr>
<tr><td class="statsOptionTitle"><b>&nbsp;&nbsp;&nbsp;&nbsp;Relay Attempts Rejected:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rcptRelayRejected}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rcptRelayRejected}</td>
</tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since restart</i></td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since reset</i></td>
 </tr>
</tbody>
<tbody>
<tr><td colspan="5" class="sectionHeader" onmousedown="toggleTbody('StatItem7')">Messages Statistics</td></tr>
</tbody>
<tbody id="StatItem7" class="on">
<tr><td class="statsOptionTitle"><b>Bayesian Hams:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{bhams}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{bhams}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Whitelisted Messages:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{whites}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{whites}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Local Messages:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{locals}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{locals}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Noprocessing Messages:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{noprocessing}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{noprocessing}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Spamlover Spams Passed:</b></td>
<td class="statsOptionValue positive" colspan="2">$Stats{spamlover}</td>
<td class="statsOptionValue positive" colspan="2">$AllStats{spamlover}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Bayesian Spams:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{bspams}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{bspams}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Blacklisted Messages:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{blacklisted}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{blacklisted}</td>
</tr>
<tr><td class="statsOptionTitle"><b>HELO Blacklisted Messages:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{helolisted}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{helolisted}</td>
</tr>
<tr><td class="statsOptionTitle"><b>HELO Invalid:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{invalidHelo}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{invalidHelo}</td>
</tr>
<tr><td class="statsOptionTitle"><b>HELO Forged:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{forgedHelo}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{forgedHelo}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Missing MX/A:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{mxaMissing}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{mxaMissing}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Missing PTR:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{ptrMissing}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{ptrMissing}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Spam Bucketed Messages:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{spambucket}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{spambucket}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Spam Trap Messages:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{spamtrap}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{spamtrap}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Attachments Blocked:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{viri}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{viri}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Viruses Detected:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{viridetected}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{viridetected}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Spam Bombs Blocked:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{bombs}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{bombs}</td>
</tr>

<tr><td class="statsOptionTitle"><b>Penalty Box Blocked:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{pbdenied}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{pbdenied}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Invalid Local Address (Sender):</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{senderInvalidLocals}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{senderInvalidLocals}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Scripts Blocked:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{scripts}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{scripts}</td>
</tr>
<tr><td class="statsOptionTitle"><b>SPF Failures:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{spffails}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{spffails}</td>
</tr>
<tr><td class="statsOptionTitle"><b>RBL Failures:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rblfails}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rblfails}</td>
</tr>
<tr><td class="statsOptionTitle"><b>RBL Cache Hits:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{rblcachehits}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{rblcachehits}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Max Errors Exceeded:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{msgMaxErrors}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{msgMaxErrors}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Delayed Messages:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{msgDelayed}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{msgDelayed}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Empty Recipient Messages:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{msgNoRcpt}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{msgNoRcpt}</td>
</tr>
<tr><td class="statsOptionTitle"><b>Not SRS Signed Bounces:</b></td>
<td class="statsOptionValue negative" colspan="2">$Stats{msgNoSRSBounce}</td>
<td class="statsOptionValue negative" colspan="2">$AllStats{msgNoSRSBounce}</td>
</tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since restart</i></td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>since reset</i></td>
 </tr>
</tbody>
<thead>
 <tr>
  <td class="sectionHeader" onmousedown="toggleTbody('StatItem0')" colspan="5">Server Information</td>
 </tr>
</thead>
<tbody id="StatItem0" class="off">
 <tr>
  <td class="statsOptionTitle"><b>$localhostname</b></td>
  <td class="statsOptionValue" colspan="2">$localhostaddr</td>
  <td class="statsOptionValue" colspan="2">&nbsp;</td>
 </tr>
<td class="statsOptionValue" colspan="5" style="background-color: #FFFFFF">&nbsp;</td></tbody>
<tbody>
 <tr>
  <td class="sectionHeader" onmousedown="toggleTbody('StatItem1')" colspan="5">Core Components</td>
 </tr>
</tbody>
<tbody id="StatItem1" class="off">
 <tr>
  <td class="statsOptionTitle" width="0%"><b>Perl</b></td>
  <td class="statsOptionValue" width="25%" colspan="2">$]</td>
  <td class="statsOptionValueC" width="50%" colspan="2">
  <a href="http://www.perl.org/get.html" rel="external">Perl.org</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle" width="0%"><b>ASSP</b></td>
  <td class="statsOptionValue" width="25%" colspan="2">$version$modversion</td>
  <td class="statsOptionValueC" width="25%"><a href="http://sourceforge.net/project/showfiles.php?group_id=69172" rel="external">release</a></td>
  <td class="statsOptionValueC" width="25%"><a href="http://www.iworld.de/homes/fb/ASSP/" rel="external">beta</a></td>
 </tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">&nbsp;</td>
  <td class="statsOptionValueC" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>downloads</i></td>
 </tr>
</tbody>
<tbody>
 <tr>
  <td class="sectionHeader" onmousedown="toggleTbody('StatItem2')" colspan="5">Module Add-ons</td>
 </tr>
</tbody>
<tbody id="StatItem2" class="off">
 <tr>
  <td class="statsOptionTitle"><b>Compress::Zlib</b></td>
  <td class="statsOptionValue" colspan="2">$VerCompressZlib&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Compress::Zlib" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Digest::MD5</b></td>
  <td class="statsOptionValue" colspan="2">$VerDigestMD5&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Digest::MD5" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Email::Valid</b></td>
  <td class="statsOptionValue" colspan="2">$VerEmailValid&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Email::Valid" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>File::ReadBackwards</b></td>
  <td class="statsOptionValue" colspan="2">$VerFileReadBackwards&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=File::ReadBackwards" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Mail::SPF::Query</b></td>
  <td class="statsOptionValue" colspan="2">$VerMailSPFQuery&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Mail::SPF::Query" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Mail::SRS</b></td>
  <td class="statsOptionValue" colspan="2">$VerMailSRS&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Mail::SRS" rel="external">CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Net::DNS</b></td>
  <td class="statsOptionValue" colspan="2">$VerNetDNS&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Net::DNS" rel="external">CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Net::LDAP</b></td>
  <td class="statsOptionValue" colspan="2">$VerNetLDAP&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Net::LDAP" rel="external">CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Time::HiRes</b></td>
  <td class="statsOptionValue" colspan="2">$VerTimeHiRes&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Time::HiRes" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Sys::Syslog</b></td>
  <td class="statsOptionValue" colspan="2">$VerSysSyslog&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a href="http://search.cpan.org/search?query=Sys::Syslog" rel="external">
  CPAN</a></td>
 </tr>
 <tr>
  <td class="statsOptionTitle"><b>Win32::Daemon</b></td>
  <td class="statsOptionValue" colspan="2">$VerWin32Daemon&nbsp;</td>
  <td class="statsOptionValueC" colspan="2">
  <a rel="external" href="http://www.roth.net/perl/Daemon/">roth.net</a></td>
 </tr>
 <tr>
  <td class="statsOptionValue" style="background-color: #FFFFFF">&nbsp;</td>
  <td class="statsOptionValue" style="background-color: #FFFFFF" colspan="2">&nbsp;</td>
  <td class="statsOptionValueC" style="background-color: #FFFFFF" colspan="2">
  <font size="1" color="#C0C0C0"><i>downloads</i></td>
 </tr>
</tbody>
</table>
<br />
$kudos
<br />
</div>
$footers
</body></html>
EOT
}

sub ConfigLists {
 my $s;
 my $a;
 my $act=$qs{action};
 if($act) {
  if ($qs{list} eq 'tuplets') {
   my $ip;
   my $hash;
   my $t;
   my $interval;
   my $intervalFormatted;
   while ($qs{addresses}=~/(\d+\.\d+\.\d+\.\d+),<?(?:$EmailAdrRe\@)?($EmailDomainRe|)>?/go) {
    $ip=ipNetwork($1,($DelayUseNetblocks ? 24 : 32));
    $a=lc $2;
    if ($DelayNormalizeVERPs) {
     # strip extension
     $a=~s/\+.*(?=@)//;
     # replace numbers with '#'
     $a=~s/\b\d+\b(?=.*@)/#/g;
    }
    # get sender domain
    $a=~s/.*@//;
    $hash="$ip $a";
    $hash=Digest::MD5::md5_hex($hash) if $CanUseMD5Keys;
    $t=time;
    $s.="<div class=\"text\">($ip,$a) ";
    if($act eq 'v') {
     if (!exists $DelayWhite{$hash}) {
      $s.="<span class=\"negative\">tuplet NOT whitelisted</span>";
     } else {
      $interval=$t-$DelayWhite{$hash};
      $intervalFormatted=formatTimeInterval($interval);
      if ($interval<$DelayExpiryTime*24*3600) {
       $s.="tuplet whitelisted, age: $intervalFormatted";
      } else {
       $s.="tuplet expired, age: $intervalFormatted";
      }
     }
    } elsif($act eq 'a') {
     if (!exists $DelayWhite{$hash} || ($t-$DelayWhite{$hash}>=$DelayExpiryTime*24*3600)) {
      if(localmail('@'.$a)) {
       $s.="<span class=\"negative\">local addresses not allowed on whitelisted tuplets</span>";
      } else {
       $s.="tuplet added";
       $DelayWhite{$hash}=$t;
       mlog(0,"whitelisted tuplets addition: ($ip,$a) (admin)");
      }
     } else {
      $s.="<span class=\"positive\">tuplet already whitelisted</span>";
     }
    } elsif($act eq 'r') {
     if (!exists $DelayWhite{$hash}) {
      $s.="<span class=\"negative\">tuplet NOT whitelisted</span>";
     } else {
      $interval=$t-$DelayWhite{$hash};
      $intervalFormatted=formatTimeInterval($interval);
      if ($interval<$DelayExpiryTime*24*3600) {
       $s.="tuplet removed, age: $intervalFormatted";
      } else {
       $s.="expired tuplet removed, age: $intervalFormatted";
      }
      delete $DelayWhite{$hash};
      mlog(0,"whitelisted tuplets deletion: ($ip,$a) (admin)");
     }
    }
    $s.="</div>\n";
   }
  } else {
   my $color=$qs{list} eq 'red'? 'Red' : 'White';
   my $list=$color."list";
   while ($qs{addresses}=~/($EmailAdrRe\@$EmailDomainRe)/go) {
    $a=$1;
    $s.="<div class=\"text\">$a ";
    $a=lc $a;
    if($act eq 'v') {
     if($list->{$a}) {
      $s.="${color}listed";
     } else {
      $s.="<span class=\"negative\">NOT $qs{list}listed</span>";
     }
    } elsif($act eq 'a') {
     if($list->{$a}) {
      $s.="<span class=\"positive\">already $qs{list}listed</span>";
     } else {
      if($color eq 'White' && localmail($a)) {
       $s.="<span class=\"negative\">local addresses not allowed on whitelist</span>";
      } else {
       $s.="added";
       $list->{$a}=time;
       mlog(0,"$qs{list}list addition: $a (admin)");
      }
     }
    } elsif($act eq 'r') {
     if($list->{$a}) {
      $s.="removed";
      delete $list->{$a};
      mlog(0,"$qs{list}list deletion: $a (admin)");
     } else {
      $s.="not $qs{list}listed";
     }
    }
    $s.="</div>\n";
   }
  }
 }
 if($qs{B1}=~/^Show (.)/i) {
  local $/="\n";
  if($1 eq 'R') {
   $qs{list}="red"; # update radios
   $RedlistObject->flush() if $RedlistObject;
   open(F,"<$base/$redlistdb");
   $s.='<div class="textbox"><b>Redlist</b></div>';
  } else {
   $qs{list}="white"; # update radios
   $WhitelistObject->flush() if $WhitelistObject;
   open(F,"<$base/$whitelistdb");
   $s.='<div class="textbox"><b>Whitelist</b></div>';
  }
  my $l;
  while($l=<F>) {
   my ($a)=$l=~/([^\002]*)/;
   $s.="<div class=\"textbox\">$a</div>";
  }
  close F;
 }
<<EOT;
$headerHTTP
$headerDTDStrict
$headers
<div class="content">
<h2>Update or Verify the Whitelist/Redlist</h2>
$s
<form method="post" action=\"\">
    <table class="textBox" style="width: 99%;">
        <tr>
            <td class="noBorder">Do you want to work with the:
            </td>
            <td class="noBorder">
            <input type="radio" name="list" value="white"${\((!$qs{list} || $qs{list} eq 'white') ? ' checked="checked" ' : ' ')} /> Whitelist or<br />
            <input type="radio" name="list" value="red"${\($qs{list} eq 'red' ? ' checked="checked" ' : ' ')} /> Redlist or<br />
            <input type="radio" name="list" value="tuplets"${\($qs{list} eq 'tuplets' ? ' checked="checked" ' : ' ')} /> Tuplets
            </td>
        </tr>
        <tr>
            <td class="noBorder">Do you want to: </td>
            <td class="noBorder"><input type="radio" name="action" value="a" />add<br />
            <input type="radio" name="action" value="r" />remove<br />
            <input type="radio" checked="checked" name="action" value="v" />or verify</td>
            <td class="noBorder">
                List the addresses in this box:<br />
                (for tuplets put: ip-address,domain-name)<br />
                <p><textarea name="addresses" rows="5" cols="40" wrap="off">$qs{addresses}</textarea></p>
            </td>
        </tr>
        <tr>
            <td class="noBorder">&nbsp;</td>
            <td class="noBorder"><input type="submit" name="B1" value="  Submit  " /></td>
            <td class="noBorder">&nbsp;</td>
        </tr>
    </table>
</form>
<div class="textBox">
<p>Post less than 1 megabyte of data at a time.</p>
Note: The redlist is not a blacklist. The redlist is a list of addresses that cannot
contribute to the whitelist, and who are not considered local, even if their mail is
from a local computer. For example, if someone goes on a vacation and turns on their
email's autoresponder, put them on the redlist until they return. Then as they reply
to every spam they receive they won't corrupt your non-spam collection or whitelist.

  <form action="" method="post">
  <table style="width: 90%; margin-left: 5%;">
    <tr>
      <td align="center" class="noBorder"><input type="submit" name="B1" value="Show Whitelist" /></td>
      <td align="center" class="noBorder"><input type="submit" name="B1" value="Show Redlist" /></td>
    </tr>
  </table>
  </form>
      <p class="warning">Warning: If your whitelist or redlist is long, pushing these buttons
      is ill-advised. Use these for testing and while your whitelist is short.</p>
</div>
</div>
$footers
</body></html>
EOT
}

sub ConfigAnalyze {
 my ($s,$st,$wl,%wl);
 my $mail=$qs{mail};
 if($mail) {
  my $name=$myName; $name=~s/(\W)/\\$1/g;
  my ($ip)=$mail=~/Received: from ([0-9\.]+).*?by\s+$name/is;
  my ($ip3)=$ip=~/(.*)\.\d+$/;
  my ($helo)=$mail=~/helo=(.*?)\)/i;
  $wl.="<br /><div class=\"textBox\">";
  while($mail=~/($EmailAdrRe\@$EmailDomainRe)/go) {
   my $a=lc $1;
   my $mf=$a;
   my $mfd = $1 if $mf=~/\@(.*)/;
   my $mfdd = $1 if $mf=~/(\@.*)/;
   next if $wl{$a}++;
   if ($noProcessing) {
   if($mf=~$NPREL || $mfdd=~$NPREL) { $wl.="<b>$mf is on NP-list<br /></b>\n"; }  }
   if ($blackListedDomains && $mfdd=~$BLDRE1){$wl.="<b>$mfdd is on blackdomain-list<br /></b>\n";}
	if($whiteListedDomains && $mfdd=~$WLDRE) {$wl.="<b>$mfdd is on whitedomain-list<br /></b>\n";}
   if( $Redlist{$a} ){
    $wl.="<b>$a is redlisted<br /></b>\n";
   } else {
    $wl.="<b>$a is whitelisted<br /></b>\n" if $Whitelist{$a};
   }
  }
$wl.="<p>" if $wl;

  $wl.="Mail matches White RE: '$1'<p>\n" if $whiteRe && $mail=~('('.$whiteReRE.')');
  $wl.="Mail matches Black RE: '$1'<p>\n" if $blackRe && $mail=~('('.$blackReRE.')');
  $wl.="Mail matches No Processing RE: '$1'<p>\n" if $npRe && $mail=~('('.$npReRE.')');
  $wl.="Mail matches Red RE: '$1'<p>\n" if ($mail=~$redRe && $mail=~('('.$redReRE.')'));
  $wl.="Mail matches Mail Bomb RE: '$1'<p>\n" if $bombRe && $mail=~('('.$bombReRE.')');
  $wl.="Mail matches Script RE: '$1'<p>\n" if $scriptRe && $mail=~('('.$scriptReRE.')');
  $wl.="Mail matches CheckContentOnly RE: '$1'<p>\n" if $contentOnlyRe && $mail=~('('.$contentOnlyReRE.')');

  $wl.="<b>Mail matches helo blacklist '$helo'</b><p>\n" if $HeloBlack{lc $helo};

  $mail=clean(substr($mail,0,$MaxBytes));
  $wl.="Mail matches White RE: '$1'<p>\n" if $whiteRe && $mail=~('('.$whiteReRE.')');
  $wl.="Mail matches Black RE: '$1'<p>\n" if $blackRe && $mail=~('('.$blackReRE.')');
if (exists $PBBlack{$ip}) {
my($ct,$ut,$pbstatus,$value,$sip,$reason)=split(" ",$PBBlack{$ip});
$wl.="IP $ip is in PB Black - last event:$reason<p>\n" ;}

if (exists $PBWhite{$ip}) {
my($ct,$ut,$pbstatus,$sip,$reason)=split(" ",$PBWhite{$ip});
$wl.="IP $ip is in PB White - last event:$reason<p>\n" ;}
if (exists $RBLCache{$ip}) {
my($ct,$mm,$rbllists)=split(" ",$RBLCache{$ip});
$wl.="IP $ip is in RBLCache - inserted at $mm by $rbllists<p>\n" ;}

if ($denySMTPConnectionsFrom && $ip=~$DSMTPCFRE) {
$wl.="<b>IP $ip is in denySMTPConnectionsFrom<p>\n" ;}
  my @t; my %got;

  if(defined($Dnsbl{$ip}) || defined($Dnsbl{$ip3})) {
   $wl.="<b>$ip dnsbl hit</b> (adds 0.97 0.97)<p>\n";
   push(@t,0.97);
   push(@t,0.97);
  }
  if($greylist) {
    my $v;
    if ($ispip && $ip=~$ISPRE) {
       if ($ispgreyvalue) {
        $v=$ispgreyvalue;
      } else {
        $v=$Greylist{x};
      }
    } else {
      $v=$Greylist{$ip3} || $Greylist{x};
    }
   $wl.="<b>$ip3 has a greylist value of $v</b> (adds $v $v)<p>\n";
   push(@t,$v,$v) if $v;
  }

  my ($v,$lt,$t,%seen);
 
   while($mail=~/([-\$A-Za-z0-9\'\.!\240-\377]+)/g) {
   next if length($1) > 20;
   $lt=$t; $t=lc $1;
   $t=~s/[,.']+$//; $t=~s/!!!+/!!/g; $t=~s/--+/-/g;
   my $j="$lt $t";
   next if $seen{$j}++>1;
   push(@t,$v) if ($v=$Spamdb{$j}); $got{$j}=$v if $v;
  }
  my $cnt=0;
  $s.="<tr><td style=\"text-align: right;\">Bad Words</td>
  <td style=\"text-align: center;\">Bad Prob</td>
  <td style=\"text-align: right;\">Good Words</td>
  <td style=\"text-align: center;\">Good Prob</td></tr>\n";
  foreach (sort {abs($got{$b}-.5)<=>abs($got{$a}-.5)} keys %got) {
   my $g=sprintf("%.4f",$got{$_});
   if($g < 0.5) {
    $s.="<tr><td></td><td></td><td align=\"right\">$_</td><td>$g</td></tr>\n";
   } else {
    $s.="<tr><td align=\"right\">$_</td><td>$g</td><td></td><td></td></tr>\n";
   }
   last if $cnt++ > 20;
  }
  @t=sort {abs($b-.5)<=>abs($a-.5)} @t;
  @t=@t[0..30];
  $st="<br /><p>Analysis totals: ";
  foreach (@t) {$st.=sprintf ("%.4f ",$_) if $_;}
  $st.="</p>\n";
  my $p1=1; my $p2=1; foreach $p (@t) {if($p) {$p1*=$p; $p2*=(1-$p);}}
  $SpamProb=$p1/($p1+$p2);
 $SpamProbConfidence=abs($p1-$p2);
$st.="<table>";
$st.=sprintf(" <tr><td>spamprobability:</td><td>%.40f</td></tr>\n",$p1);
$st.=sprintf(" <tr><td>hamprobability:</td><td>%.40f</td></tr>\n",$p2);
$st.=sprintf(" <tr><td>combined spamprobability:</td><td>%.40f</td></tr>\n",$SpamProb);
$st.=sprintf(" <tr><td>bayesian confidence:</td><td>%.40f</td></tr>\n",$SpamProbConfidence);
$st.=" </table></div>";
  $mail=~s/([^\n]{70,84}[^\w\n<\@])/$1\n/g; $mail=~s/\s*\n+/\n/g; $mail=~s/<\/textarea>/\/textarea/ig;
 }
<<EOT;
$headerHTTP
$headerDTDStrict
$headers
<div class="content">
<h2>ASSP Mail Analyzer</h2>
<div class="note">This page will show you how ASSP analyzes an email to come up with the assigned spam
probability. You can also see how it pre-processes mail.
</div>
$wl<table><tr><td>$s</td></tr></table>$st
<form action="" method="post">
    <table class="textBox" style="width: 99%;">
        <tr>
            <td class="noBorder" align="center">Copy and paste the mail header and
            body here:<br />
            <textarea name="mail" rows="10" cols="75" wrap="off">$mail</textarea>
            </td>
        </tr>
        <tr>
            <td class="noBorder" align="center"><input type="submit" name="B1" value=" Analyze " /></td>
        </tr>
    </table>
</form>
<p class="note" >Note: Analysis is performed using the current spam database --
if yours was rebuilt since the time the mail was received you'll
receive a different result.</p>
<div class="textbox">
<p>To use this form using <i>Outlook Express</i> do the following. Right-click on the message
of interest. Select <i>Properties</i>. Click the <i>Details</i> tab. Click the <i>message
source</i> button. Right-click on the message source and click <i>Select All</i>. Right-click
again and click <i>Copy</i>. Click on the text box above and paste (Ctrl-V perhaps). Click
the <i>Analyze</i> button.</p>
<p>The page will update to show you the following: if any of the email's addresses are in
the redlist or whitelist, the most and least spammy phrases together with their spaminess,
the resulting probabilities (probabilities may repeat one time), and the final spam probability
score.</p>
</div>
</div>
$footers
</body></html>
EOT
}

sub needEs {
 my ($count,$text,$es)=@_;
 return $count . $text . ($count==1 ? '' : $es);
}

# wrap long log lines
sub logWrap {
 my ($line,$indent)=@_;
 my $wraps=$MaillogTailWrapColumn+11; # has to be >= $indent, or while line loops infinitely
 my $wrape=$wraps+15;
 # wrap anchors are: space;-,.:= (but not &lt; &gt;)
 # matches are greedy to minimize number of line breaks
 # not a danger code as long as $wraps >= $indent
 while ($line=~s/(?:([^\r\n]{$wraps,$wrape}) |([^\r\n]{$wraps,$wrape}(?<![lg]t);)|([^\r\n]{$wraps,$wrape}[-,.:=])) {0,5}(?=[^\r\n]{5,}$)/$1$2$3\r\n$indent/) {};
 return $line;
}

sub encodeHTMLEntities {
 $s=shift;
 $s=~s/&/&amp;/gs;
 $s=~s/</&lt;/gs;
 $s=~s/>/&gt;/gs;
 $s=~s/"/&quot;/gs;
 return $s;
}

sub decodeHTMLEntities {
 $s=shift;
 $s=~s/&quot;?/"/gis;
 $s=~s/&gt;?/>/gis;
 $s=~s/&lt;?/</gis;
 $s=~s/&amp;?/&/gis;
 return $s;
}

sub ConfigMaillog {
 my $pat=$qs{search};
 my $s='';
 my $res='';
 # calculate indent
 my $m=localtime();
 $m=~s/^... (...) +(\d+) (\S+) ..(..)/$1-$2-$4 $3 /;
 my $indent=" " x length($m);
 if(!$pat) {
  open(F,"<$base/$logfile");
  seek(F,-$MaillogTailBytes,2) || seek(F,0,0);
  local $/;
  $s=<F>;
  close F;
  $s=encodeHTMLEntities($s);
  if ($MaillogTailWrapColumn>0) {
   my @sary=map{$_."\n"} split(/\r?\n|\r/,$s);
   foreach (@sary) {
    $_=logWrap($_,$indent);
    s/(\r\n\Q$indent\E)/<span style="background-color:white">$1<\/span>/g;
   }
   $s=join('',@sary);
  }
 } elsif ($CanSearchLogs) {
  my @sary;
  my $matches=0;
  my $lines=0;
  my $files=0;
  my ($logdir, $logdirfile) = $logfile=~/^(.*[\/\\])?(.*?)$/;
  my @logfiles=reverse sort glob("$base/$logdir*$logdirfile");
  my $logf=File::ReadBackwards->new(shift(@logfiles),'(?:\r?\n|\r)',1); # line terminator regex
  if ($logf) {
   $files++;
   my $maxmatches=$qs{limit} eq '1000' ? 1000 : $qs{limit} eq '100' ? 100 : $qs{limit} eq '10' ? 10 : 0;
   my $maxlines=lc $qs{files} eq 'lines' ? 10000 : 0;
   my $maxfiles=lc $qs{files} eq 'last' ? 2 : 0;
   $pat=encodeHTMLEntities($pat);
   # mormalize and strip redundand minuses
   $pat=~s/(?<!(?:-|\w))(-(?:\s+|\z))+/-/g;
   $pat=~s/\s+-$//;
   my $l=$logf->readline();
   # make line terminators uniform
   $l=~s/(.*?)(?:\r?\n|\r)/$1\n/;
   $l=encodeHTMLEntities($l);
   my @ary;
   push(@ary,$l);
   my $infinity=10000;
   my $precontext=my $postcontext=$qs{nocontext} ? 0 : 6;
   my $notmatched=0;
   my $currentpre=0;
   my $seq=0;
   my $lastoutput=$infinity;
   my $cur=@ary[0];
   my $i=0;
   my @words=map/^\d+\_(.*)/, sort values %{{map{lc $_ => sprintf("%02d",$i++).'_'.$_} split(' ',$pat)}};
   $pat=join(' ', @words);
   my @highlights=('<span style="color:black; background-color:#ffff66">',
                   '<span style="color:black; background-color:#A0FFFF">',
                   '<span style="color:black; background-color:#99ff99">',
                   '<span style="color:black; background-color:#ff9999">',
                   '<span style="color:black; background-color:#ff66ff">',
                   '<span style="color:white; background-color:#880000">',
                   '<span style="color:white; background-color:#00aa00">',
                   '<span style="color:white; background-color:#886800">',
                   '<span style="color:white; background-color:#004699">',
                   '<span style="color:white; background-color:#990099">');
   my $findExpr=join(' && ',((map{'$cur=~/'.quotemeta($_).'/io'} map/^([^-].*)/, split(' ',$pat)),
                             (map{'$cur!~/'.quotemeta($_).'/io'} map/^-(.*)/, split(' ',$pat))));
   my %replace;
   my $j=0;
   my $highlightExpr='=~s/(';
   foreach (map/^([^-].*)/, split(' ',$pat)) {
    $replace{lc $_}=$highlights[$j % @highlights]; # pick highlight style
    $highlightExpr.=quotemeta($_).'|';
    if ($MaillogTailWrapColumn>0) {
     for ($i=1; $i<length($_); $i++) {
      # cover all possible positions of wrapping whitespaces
      my $word=$_;
      $word=~s/^(.{$i})/$1\r\n$indent/;
      $replace{lc $word}=$highlights[$j % @highlights];
      $highlightExpr.=quotemeta($word).'|';
     }
    }
    $j++;
   }
   $highlightExpr=~s/\|$//;
   $highlightExpr.=')/$replace{lc $1}$1<\/span>/gio';
   my $loop=<<'LOOP';
   while ($cur && !($maxmatches && $matches>=$maxmatches && $notmatched>$postcontext) && !($maxlines && $notmatched>=$maxlines)) {
LOOP
    $loop.='if (!($maxmatches && $matches>=$maxmatches) && '.$findExpr.') {'. <<'LOOP';
     $matches++;
     $cur=logWrap($cur,$indent) if $MaillogTailWrapColumn>0;
LOOP
     $loop.='$cur'.$highlightExpr.' unless $qs{nohighlight};'. <<'LOOP';
     if ($lastoutput<=$postcontext) {
      push(@sary,$cur);
     } else {
      push(@sary,"\r\n") if ($seq++ && ($precontext+$postcontext>0));
      for ($i=0; $i<@ary; $i++) {
       $ary[$i]=logWrap($ary[$i],$indent) if $MaillogTailWrapColumn>0;
       if ($i<$precontext && $currentpre==$precontext || $i<$currentpre) {
        $ary[$i]=~s/^(.*?)(\r?\n)$/<span style="color:#999999">$1<\/span>$2/s;
       } else {
LOOP
        $loop.='$ary[$i]'.$highlightExpr.' unless $qs{nohighlight};'. <<'LOOP';
       }
       push(@sary,$ary[$i]);
      }
     }
     $lastoutput=0;
     $notmatched=0;
    } elsif ($logf->eof) {
     for (; $currentpre>=0; $currentpre--) {
      shift(@ary);
     }
     $logf->close if exists $logf->{'handle'};
     if (!($maxfiles && $files>=$maxfiles)) {
      $logf=File::ReadBackwards->new(shift(@logfiles),'(?:\r?\n|\r)',1);
      $files++ if $logf;
     }
     $lastoutput=$infinity;
    } elsif ($lastoutput<=$postcontext) {
     $cur=logWrap($cur,$indent) if $MaillogTailWrapColumn>0;
     $cur=~s/^(.*?)(\r?\n)$/<span style="color:#999999">$1<\/span>$2/s;
     push(@sary,$cur);
    }
    $lastoutput++;
    $notmatched++;
    if ($l) {
     $l=$logf->readline();
     # make line terminators uniform
     $l=~s/(.*?)(?:\r?\n|\r)/$1\n/;
     $l=encodeHTMLEntities($l);
     $lines++;
    }
    push(@ary,$l);
    if ($currentpre<$precontext) {
     $currentpre++;
    } else {
     shift(@ary);
    }
    $cur=$ary[$currentpre];
    MainLoop2();
   }
LOOP
   eval $loop;
   $logf->close if exists $logf->{'handle'};
  }
  if ($matches>0) {
   $res='found '. needEs($matches,' matching line','s') .', searched in '. needEs($files,' log file','s') .' ('. needEs($lines,' line','s'). ')';
   if ($MaillogTailWrapColumn>0) {
    # wipe out highlighted wrapping whitespaces
    s/(\r\n\Q$indent\E)/<span style="background-color:white">$1<\/span>/g foreach @sary;
   }
   $s=join('',reverse @sary);
  } else {
   $res='no results found, searched in '. needEs($files,' log file','s') .' ('. needEs($lines,' line','s'). ')';
  }
 } else {
  $s='<p class="warning">Please install required module <a href="http://search.cpan.org/~uri/File-ReadBackwards-1.03/" rel="external">File::ReadBackwards</a>.</p>';
 }
<<EOT;
$headerHTTP
$headerDTDStrict
$headers
<div class="content">
<h2>ASSP Maillog Tail</h2>
<div class="note">
Press your browser's refresh to update this screen. Newest entries are at the end.
</div>
<form action="" method="get">
  <table class="textBox" style="width: 99%;">
    <tr>
      <td class="noBorder" align="right">
        <input type="text" name="search" value='$pat' size="20"/>
        <input type="submit" name="" value="Search" />
      </td>
      <td class="noBorder" align="center">
        <select size="1" name="files">
          <option selected="selected" value="lines">last 10.000 lines</option>
          <option value="last">last two log files</option>
          <option value="all">all log files</option>
        </select>
        <select size="1" name="limit">
          <option selected="selected" value="10">limit to 10 matches</option>
          <option value="100">limit to 100 matches</option>
          <option value="1000">limit to 1.000 matches</option>
     <!-- <option value="0">display all matches</option> -->
        </select>
      </td>
      <td class="noBorder">
        <input type="checkbox" name="nocontext"${\($qs{nocontext} ? ' checked="checked" ' : ' ')}value='1' />hide&nbsp;context&nbsp;lines<br />
        <input type="checkbox" name="nohighlight"${\($qs{nohighlight} ? ' checked="checked" ' : ' ')}value='1' />disable&nbsp;highlighting
      </td>
    </tr>
  </table>
</form>
<div class="log">
$res
<pre>
$s
</pre>
</div>
$maillogJump
</div>
$footers
</body></html>
EOT
}

sub ConfigEdit {
 my $fil=$qs{file};
 my $note=$qs{note} eq '1' ? '<div class="note">
File should have one entry per line; anything on a line following a numbersign ( #) is ignored (a comment).
 Whitespace at the beginning or end of the line is ignored.
</div>' : $qs{note} eq '2' ? '<div class="note">
First line specifies text that appears in the subject of report message.
The remaining lines are the report message body.
</div>' : $qs{note} eq '3' ? '<div class="note">
Put here comments to your assp installation.
</div>' : '';
 my ($s1,$s2,$s3);
  $s2='<div class="text">&nbsp;</div>';
 if ($fil=~/\.\./) {
  $s2.='<div class="text"><span class="negative">File path includes \'..\' -- access denied</span></div>';
  mlog(0,"file path not allowed while editing file '$fil'");
 } else {

 $fil="$base/$fil" if $fil!~/^(([a-z]:)?[\/\\]|\Q$base\E)/;
  #$fil="$base/$fil" if $fil!~/^\Q$base\E/i;
  if ($qs{B1}=~/delete/i) {
   unlink($fil);
  } else {
   if (defined($qs{contents})) {
    $s1=$qs{contents};
    $s1=decodeHTMLEntities($s1);
    open(F,">$fil");
    print F $s1;
    close F;
    $s2='<div class="text"><span class="positive">File saved successfully</span></div>';
   }
  }
  if(open(F,"<$fil")) {
   local $/;
   $s1=<F>;
   # make line terminators uniform
   $s1=~s/(?:\r?\n|\r)/\n/g;
   $s1=encodeHTMLEntities($s1);
   close F;
  } else {
   $s2='<div class="text"><span class="negative">'.ucfirst($!).'</span></div>';
  }
  if (-e $fil) {
   $s3='<input type="submit" name="B1" value="Save changes" />&nbsp;
        <input type="submit" name="B1" value="Delete file" />&nbsp;
        <input type="button" value="Close" onClick="javascript:window.close();"/>';
  } else {
   $s2='<div class="text"><span class="positive">File deleted</span></div>' if $qs{B1}=~/delete/i;
   $s3='<input type="submit" name="B1" value="Save changes" />&nbsp;
        <input type="submit" name="B1" value="Delete file" disabled="disabled" />&nbsp;
        <input type="button" value="Close" onClick="javascript:window.close();"/>';
  }
 }
<<EOT;
$headerHTTP
$headerDTDStrict
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head>
  <meta http-equiv="content-type" content="application/xhtml+xml; charset=utf-8" />
  <title>ASSP (Anti SPAM SMTP Proxy)</title>
  <link rel=\"stylesheet\" href=\"get?file=images/editor.css\" type=\"text/css\" />
</head>
<body>
<div class="content">
<h2>ASSP File Editor</h2>
$s2
<form action="" method="post">
  <table class="textBox" style="width: 99%;">
    <tr>
      <td class="noBorder" align="center">
        Contents of the $fil file:<br />
        <textarea name="contents" rows="15" cols="65" wrap="off">$s1</textarea>
      </td>
    </tr>
    <tr>
      <td class="noBorder" align="center">
        $s3
      </td>
    </tr>
  </table>
</form>
$note
</div>
$footers
</body></html>
EOT
}

sub webConfig {
 my $r = '';
 $ConfigChanged=0;
 undef %qs unless $qs{theButton}; # don't post partial data if somebody's browser's busted
 my $counter = 0;
 foreach $c (@Config) {
  if (@{$c} == 5) {
   @tmp = @{$c};
   push(@tmp, "setupItem$counter");
   $r .= $c->[3]->(@tmp);
   $counter++;
  } else {
   $r .=$c->[3]->(@{$c});
  }
 }
 if($ConfigChanged) {
  SaveConfig();
  renderConfigHTML();
 }
 my $quit='<form action="quit" method="post">
<table class="textBox" style="width: 99%;">
  <tr><td class="noBorder" align="center">Panic button: </td></tr>
  <tr><td class="noBorder" align="center"><input type="submit" value="Terminate Now!" /></td></tr>
</table>
</form>' unless $AsAService;
<<EOT;
$headerHTTP
$headerDTDStrict
$headers
<div class="content">
<h2>ASSP Configuration</h2>
<form action="" method="post">
<div>
$r
</div>
<div class="rightButton">
  <input name="theButton" type="submit" value="Apply Changes" />
</div>
<div class="note">
  Note: Items marked with an asterisk (*) accept a list separated by | or you can specify a file to read
  the list from this way: file:filename.txt (relative to ASSP directory base).<br /> Pushing "Apply" will open a frame with "no such file". You can fill data in and save. That creates a file under the given name.<br />
  Files should have one entry per line; anything on a line following a numbersign ( #) is ignored (a comment).
  Whitespace at the beginning or end of the line is ignored.
</div>
</form>
$quit
</div>
$footers
<script type="text/javascript">
<!--
  expand(0, 0);
  string = new String(document.location);
  string = string.substr(string.indexOf('#')+1);
  if(document.forms[0].length) {
    for(i = 0; i < document.forms[0].elements.length; i++) {
      if(string == document.forms[0].elements[i].name) {
        document.forms[0].elements[i].focus();
      }
    }
  }
// -->
</script>
</body></html>
EOT
}

sub Donations {
<<EOT;
$headerHTTP
$headerDTDStrict
$headers
<div class="content">
<h2>ASSP Donations</h2>
<div class="note">
ASSP is here thanks to the following people, please feel free to donate to support the ASSP project.
</div>
<br />
<table style="width: 99%;" class="textBox">
<tr>
<td class="underline">John Hanna the founder and developer of ASSP up to version 1.0.12</td>
<td class="underline"><a href="https://www.paypal.com/xclick/business=johnhanna77%40yahoo.com&amp;item_name=Support+ASSP&amp;item_number=assp&amp;no_note=1&amp;tax=0&amp;currency_code=USD" rel="external">Donate</a></td>
</tr>
<tr>
<td class="underline">AJ the designer behind ASSP's web interface &amp; site.</td>
<td class="underline">&nbsp;</td>
</tr>
<tr>
<td class="underline">John Calvi the developer of ASSP from version 1.0.12.</td>
<td class="underline"><a href="https://www.paypal.com/xclick/business=jcalvi%40lewis.com.au&amp;item_name=Support+ASSP&amp;item_number=assp&amp;no_note=1&amp;tax=0&amp;currency_code=USD" rel="external">Donate</a></td>
</tr>
<tr>
<td class="underline">Robert Orso the developer of ASSP's LDAP functions.</td>
<td class="underline"><a href="https://www.paypal.com/xclick/business=ro%40astronomie.at&amp;item_name=Support+ASSP&amp;item_number=assp&amp;no_note=1&amp;tax=0&amp;currency_code=USD" rel="external">Donate</a></td>
</tr>
<tr>
<td class="underline">Przemek Czerkas the developer behind SRS, Delaying, Maillog Search .</td>
<td class="underline">&nbsp;</td>
</tr>
<tr>
<td class="underline">Fritz Borgstedt the developer of ASSP 1.2.x</td>
<td class="underline"><a href="https://www.paypal.com/xclick/business=fb%40iworld.de&amp;item_name=Support+ASSP&amp;item_number=assp&amp;no_note=1&amp;tax=0&amp;currency_code=USD" rel="external">Donate</a></td>
</tr>
<tr>
<td>&nbsp;</td>
<td></td>
</tr>
<tr>
<td colspan="2">
<div class="note">Special thanks go to......<br />
&nbsp;&nbsp;  Nigel Barling for his contributions to SPF &amp; RBL.<br />
&nbsp;&nbsp;  Mark Pizzolato for his contributions to SMTP Session Limits.<br />
&nbsp;&nbsp;  Wim Borghs, Micheal Espinola, Doug Traylor, Lars Troen, Andrew Macpherson, Javier Albinarrate for their contributions to 1.2.x.<br />

</div>
</td>
</tr>
</table>
</div>
$footers
</body></html>
EOT
}

sub HTTPStrToTime {
 my $str=shift;
 if ($str=~/[SMTWF][a-z][a-z], (\d\d) ([JFMAJSOND][a-z][a-z]) (\d\d\d\d) (\d\d):(\d\d):(\d\d) GMT/) {
  my %MoY=qw(Jan 1 Feb 2 Mar 3 Apr 4 May 5 Jun 6 Jul 7 Aug 8 Sep 9 Oct 10 Nov 11 Dec 12);
  return eval {
   my $t=Time::Local::timegm($6, $5, $4, $1, $MoY{$2}-1, $3-1900);
   $t<0 ? undef : $t;
  };
 } else {
  return undef;
 }
}

sub GetFile {
 my $fil=$qs{file};
 if ($fil=~/\.\./) {
  mlog(0,"file path not allowed while getting file '$fil'");
return <<EOT;
HTTP/1.1 403 Forbidden
Content-type: text/html

<html><body><h1>Forbidden</h1>
</body></html>
EOT
 }

$fil="$base/$fil" if $fil!~/^(([a-z]:)?[\/\\]|\Q$base\E)/;
 #$fil="$base/$fil" if $fil!~/^\Q$base\E/i;
 if (-e $fil) {
  my $mtime;
  if (defined ($mtime=$head{'if-modified-since'})) {
   if (defined ($mtime=HTTPStrToTime($mtime))) {
    if ($mtime>=[stat($fil)]->[9]) {
return <<EOT;
HTTP/1.1 304 Not Modified
Content-type: text/html

<html><body><h1>Not Modified</h1>
</body></html>
EOT
    }
   }
  }
  if(open(F,"<$fil")) {
   binmode F;
   local $/;
   my $s=<F>;
   close F;
   %mimeTypes=(
    'log|txt|pl' => 'text/plain',
    'htm|html' => 'text/html',
    'css' => 'text/css',
    'bmp' => 'image/bmp',
    'gif' => 'image/gif',
    'jpg|jpeg' => 'image/jpeg',
    'png' => 'image/png',
    'zip' => 'application/zip',
    'sh' => 'application/x-sh',
    'gz|gzip' => 'application/x-gzip',
    'exe' => 'application/octet-stream',
    'js' => 'application/x-javascript'
   );
   my $ct='text/plain'; # default content-type
   foreach $key (keys %mimeTypes) {
    $ct=$mimeTypes{$key} if $fil=~/\.($key)$/i;
   }
   $mtime=[stat($fil)]->[9];
   $mtime=gmtime($mtime);
   $mtime=~s/(...) (...) +(\d+) (........) (....)/$1, $3 $2 $5 $4 GMT/;
return <<EOT;
HTTP/1.1 200 OK
Content-type: $ct
Last-Modified: $mtime

$s
EOT
  }
 }
<<EOT;
HTTP/1.1 404 Not Found
Content-type: text/html

<html><body><h1>Not found</h1>
</body></html>
EOT
}

sub Shutdown {
<<EOT;
$headerHTTP
$headerDTDTransitional
$headers
<div class="content">
<h2>ASSP Shutdown/Restart</h2>
<div class="note">
Note: It's possible to restart, if ASSP runs as a service or in a script that restarts it after it stops,
otherwise this function can only shut ASSP down. In either case, shutdown is clean -- SMTP sessions are not
interrupted.
</div>
<br />
<table style="background-color: white; border-width: 0px; width: 100%">
<tr>
<td style="background-color: white; padding: 0px;">
<iframe src="/shutdown_frame" width="100%" height="300" frameborder="0" marginwidth="0" marginheight="0" scrolling="no"></iframe>
</td>
</tr>
</table>

</div>
$footers
</body></html>
EOT
}


sub ShutdownFrame {
 my $action=$qs{action};
 my ($s1,$s2,$s3,$query,$refresh);
 my $shutdownDelay=2;

 my $timerJS='
<script type="text/javascript">
  var ns=(navigator.appName.indexOf("Netscape")!=-1);
  var timerVal=parseInt(ns ? document.getElementById("myTimer1").childNodes[0].nodeValue : myTimer1.innerText);
  function countDown() {
    if (isNaN(timerVal)==0 && timerVal>=0) {
      if (ns) {
        document.getElementById("myTimer1").childNodes[0].nodeValue=timerVal--;
      } else {
        myTimer1.innerText=timerVal--;
      }
      setTimeout("countDown()",1000);
    }
  }
  countDown();
</script>';
if ($action=~/abort/i) {
  $shuttingDown=0;
  $refresh=3;
  $s1='Shutdown request aborted';
  $s3='<input type="submit" name="action" value=" Proceed " disabled="disabled" />&nbsp;
<input type="submit" name="action" value=" Abort " disabled="disabled" />';
  $doShutdown=0;
  $query='?nocache';
  mlog(0,"shutdown/restart process aborted per admin request; SMTP session count:$smtpConcurrentSessions");
 } elsif ($action=~/proceed/i || $shuttingDown) {
  $shuttingDown=1;
  $refresh=$smtpConcurrentSessions>0 ? 2 : 60;
  $s1=$smtpConcurrentSessions>0 ? 'Waiting for '. needEs($smtpConcurrentSessions,' SMTP session','s') .' to finish ...' : "Shutdown in progress, please wait: <span id=\"myTimer1\">$refresh</span>s$timerJS";
  $s3='<input type="submit" name="action" value=" Proceed " disabled="disabled" />&nbsp;
<input type="submit" name="action" value=" Abort "'.($smtpConcurrentSessions>0 ? '' : ' disabled="disabled"').' />
'.($refresh>1 ? '' : '&nbsp;<input type="button" name="action" value=" View " onClick="javascript:window.open(\'shutdown_list?\',\'SMTP_Connections\',\'width=600,height=600,toolbar=no,menubar=no,location=no,personalbar=no,scrollbars=yes,status=no,directories=no,resizable=yes\')" />').'';


  $doShutdown=$smtpConcurrentSessions>0 ? 0 : time+$shutdownDelay;
  $query=$smtpConcurrentSessions>0 ? '?nocache' : '?action=Success';
  mlog(0,"shutdown/restart process initiated per admin request; SMTP session count:$smtpConcurrentSessions") if $action=~/proceed/i;
	 if ($action=~/proceed/i)
  {$smtpConcurrentSessions=0 if $smtpConcurrentSessions<3;}
 } elsif ($action=~/success/i) {
  $refresh=3;
  $s1='ASSP restarted successfully.';
  $s3='<input type="submit" name="action" value=" Proceed " disabled="disabled" />&nbsp;
<input type="submit" name="action" value=" Abort " disabled="disabled" />';
  $doShutdown=0;
  $query='?nocache';
 } else {
  $refresh=1;

  $s1=$smtpConcurrentSessions>0 ? ($smtpConcurrentSessions>1 ? 'There are ' : 'There is '). needEs($smtpConcurrentSessions,' SMTP session','s') .' active' : 'There are no active SMTP sessions';
  $s3='<input type="submit" name="action" value=" Proceed " />&nbsp;
<input type="submit" name="action" value=" Abort " disabled="disabled" />&nbsp;
<input type="button" name="action" value=" View " onClick="javascript:window.open(\'shutdown_list?\',\'SMTP_Connections\',\'width=600,height=600,toolbar=no,menubar=no,location=no,personalbar=no,scrollbars=yes,status=no,directories=no,resizable=yes\')" />';
  $doShutdown=0;
  $query='?nocache';
 }
  my $quit='<form action="quit" method="post">
<table class="textBox" style="width: 99%;">
  <tr><td class="noBorder" align="center">Panic button:</td></tr>
  <tr><td class="noBorder" align="center"><input type="submit" value="Terminate ASSP now!" /></td></tr>
</table>
</form>' unless $AsAService;
<<EOT;
$headerHTTP
$headerDTDStrict
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head>
  <meta http-equiv="content-type" content="application/xhtml+xml; charset=utf-8" />
  <meta http-equiv="refresh" content="$refresh;url=/shutdown_frame$query" />
  <title>ASSP (Anti SPAM SMTP Proxy)</title>
  <link rel=\"stylesheet\" href=\"get?file=images/shutdown.css\" type=\"text/css\" />
</head>
<body>
<div class="content">
<form action="" method="get">
  <table class="textBox">
    <tr>
      <td class="noBorder" nowrap>
        $s3&nbsp;&nbsp;&nbsp;$s1
      </td>
    </tr>
  </table>
</form>
</div>
<div class="content">

$quit
</div>
</body></html>
EOT
}

# Micheal Espinola - Add new pop-up window for listing SMTP connection information, allowing
# the main window to be used for other tasks simultaniously. Window is fully resizable and
# scrollable. SMTP Connection list has been slightly reformatted for asthetics and readability.
sub ShutdownList {
 my $action=$qs{action};
 my ($s1,$s2,$s3,$query,$refresh);
 my $shutdownDelay=2;

 my $timerJS='
<script type="text/javascript">
  var ns=(navigator.appName.indexOf("Netscape")!=-1);
  var timerVal=parseInt(ns ? document.getElementById("myTimer1").childNodes[0].nodeValue : myTimer1.innerText);
  function countDown() {
    if (isNaN(timerVal)==0 && timerVal>=0) {
      if (ns) {
        document.getElementById("myTimer1").childNodes[0].nodeValue=timerVal--;
      } else {
        myTimer1.innerText=timerVal--;
      }
      setTimeout("countDown()",1000);
    }
  }
  countDown();
</script>';
if ($action=~/abort/i) {
  $shuttingDown=0;
  $refresh=3;
  $s1='Shutdown/restart request aborted.';
  $s3='
<input type="submit" name="action" value="  Proceed  " disabled="disabled" />&nbsp;
<input type="submit" name="action" value="   Abort   " disabled="disabled" />&nbsp;
<input type="button" value="Close" onClick="javascript:window.close();"/>';
  $doShutdown=0;
  $query='?nocache';
  mlog(0,"shutdown/restart process aborted per admin request; SMTP session count:$smtpConcurrentSessions");
 } elsif ($action=~/proceed/i || $shuttingDown) {
  $shuttingDown=1;
  $refresh=$smtpConcurrentSessions>0 ? 2 : 60;

  $s1 = $smtpConcurrentSessions>0 ? 'Waiting for '. needEs($smtpConcurrentSessions,' SMTP session','s') .' to finish ...' : "Shutdown in progress, please wait ... <span id=\"myTimer1\">$refresh</span>s$timerJS";

  $tmpTimeNow = time();
  $s2 = '<tr><td colspan="12">'.localtime().'</td></tr><tr><td width="25" class="tabletext"><b>N</b></td><td class="tabletext" width="150"><b>IP</b></td><td class="tabletext" width="200"><b>HELO</b></td><td class="tabletext"><b>From</b></td><td class="tabletext"><b>Rcpt</b></td><td class="tabletext" align="center" width="50"><b>Relay</b></td><td class="tabletext" align="center" width="50"><b>SPAM</b></td><td class="tabletext" width="50" align="center"><b>Bytes</b></td><td class="tabletext" width="50" align="center"><b>Duration</b></td><td class="tabletext" width="50" align="center"><b>Inactive</b></td></tr>';

	sub sortByAge {
	    $Con{$a}->{timestart} <=> $Con{$b}->{timestart};	# presuming integers
	}
	
  @tmpConKeys = keys(%Con);
  @tmpConSortedKeys = sort sortByAge @tmpConKeys;
  $tmpCount = 1;
  foreach $key (@tmpConSortedKeys) {
    if ($Con{$key}->{ip}){
      $tmpDuration = $tmpTimeNow - $Con{$key}->{timestart};
      $tmpInactive = $tmpTimeNow - $Con{$key}->{timelast};
      $s2.= '<tr><td class="tabletext"><b>' . ($tmpCount++) . '</b></td><td class="tabletext">' . $Con{$key}->{ip} . '</td><td class="tabletext">' . substr($Con{$key}->{helo},0,25) . '</td><td class="tabletext">' .substr($Con{$key}->{mailfrom},0,30) . '</td><td class="tabletext">'.substr($Con{$key}->{rcpt},0,30).'</td><td class="tabletext" align="center">'.$Con{$key}->{relayok}.'</td><td class="tabletext" align="center" align="center">'.$Con{$key}->{spamfound}.'</td><td class="tabletext" align="center">'.$Con{$key}->{maillength}.'</td><td class="tabletext" align="center">'.$tmpDuration.'</td><td class="tabletext" align="center">'.$tmpInactive.'</td></tr>';
    }
  }

  $s3='
<input type="submit" name="action" value="  Proceed  " disabled="disabled" />&nbsp;
<input type="submit" name="action" value="   Abort   "'.($smtpConcurrentSessions>0 ? '' : ' disabled="disabled"').' />&nbsp;
<input type="button" value="Close" onClick="javascript:window.close();"/>';

  $doShutdown=$smtpConcurrentSessions>0 ? 0 : time+$shutdownDelay;
  $query=$smtpConcurrentSessions>0 ? '?nocache' : '?action=Success';
  mlog(0,"shutdown/restart process initiated per admin request; SMTP session count:$smtpConcurrentSessions") if $action=~/proceed/i;
	 if ($action=~/proceed/i)
  {$smtpConcurrentSessions=0 if $smtpConcurrentSessions<3;}
 } elsif ($action=~/success/i) {
  $refresh=3;
  $s1='ASSP restarted successfully.';
  $s3='
<input type="submit" name="action" value="  Proceed  " disabled="disabled" />&nbsp;
<input type="submit" name="action" value="   Abort   " disabled="disabled" />&nbsp;
<input type="button" value="Close" onClick="javascript:window.close();"/>';
  $doShutdown=0;
  $query='?nocache';
 } else {
  $refresh=1;

  $s1 = $smtpConcurrentSessions>0 ? ($smtpConcurrentSessions>1 ? 'There are ' : 'There is '). needEs($smtpConcurrentSessions,' SMTP session','s') .' active.' : 'There are no active SMTP sessions.';

  $tmpTimeNow = time();
  $s2 = '<tr><td colspan="12">'.localtime().'</td></tr><tr><td width="25" class="tabletext"><b>N</b></td><td class="tabletext" width="150"><b>IP</b></td><td class="tabletext" width="200"><b>HELO</b></td><td class="tabletext"><b>From</b></td><td class="tabletext"><b>Rcpt</b></td><td class="tabletext" align="center" width="50"><b>Relay</b></td><td class="tabletext" align="center" width="50"><b>SPAM</b></td><td class="tabletext" width="50" align="center"><b>Bytes</b></td><td class="tabletext" width="50" align="center"><b>Duration</b></td><td class="tabletext" width="50" align="center"><b>Inactive</b></td></tr>';

	sub sortByAge {
	    $Con{$a}->{timestart} <=> $Con{$b}->{timestart};	# presuming integers
	}
	
  @tmpConKeys = keys(%Con);
  @tmpConSortedKeys = sort sortByAge @tmpConKeys;
  $tmpCount = 1;
  foreach $key (@tmpConSortedKeys) {
    if ($Con{$key}->{ip}){
      $tmpDuration = $tmpTimeNow - $Con{$key}->{timestart};
      $tmpInactive = $tmpTimeNow - $Con{$key}->{timelast};
      $s2.= '<tr><td class="tabletext"><b>' . ($tmpCount++) . '</b></td><td class="tabletext">' . $Con{$key}->{ip} . '</td><td class="tabletext">' . substr($Con{$key}->{helo},0,25) . '</td><td class="tabletext">' .substr($Con{$key}->{mailfrom},0,30) . '</td><td class="tabletext">'.substr($Con{$key}->{rcpt},0,30).'</td><td class="tabletext" align="center">'.$Con{$key}->{relayok}.'</td><td class="tabletext" align="center" align="center">'.$Con{$key}->{spamfound}.'</td><td class="tabletext" align="center">'.$Con{$key}->{maillength}.'</td><td class="tabletext" align="center">'.$tmpDuration.'</td><td class="tabletext" align="center">'.$tmpInactive.'</td></tr>';
    }
  }

  $s3 = '
<input type="submit" name="action" value="  Proceed  " />&nbsp;
<input type="submit" name="action" value="   Abort   " disabled="disabled" />&nbsp;
<input type="button" value="Close" onClick="javascript:window.close();"/>';

  $doShutdown=0;
  $query='?nocache';
 }
  my $quit='<form action="quit" method="post">
<table class="textBox" style="width: 99%;">
  <tr><td class="noBorder" align="center">Panic button:</td></tr>
  <tr><td class="noBorder" align="center"><input type="submit" value="Terminate ASSP now!" /></td></tr>
</table>
</form>' unless $AsAService;
<<EOT;
$headerHTTP
$headerDTDStrict
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head>
  <meta http-equiv="content-type" content="application/xhtml+xml; charset=utf-8" />
  <meta http-equiv="refresh" content="$refresh;url=/shutdown_list$query" />
  <title>ASSP (Anti SPAM SMTP Proxy)</title>
  <link rel=\"stylesheet\" href=\"get?file=images/editor.css\" type=\"text/css\" />
</head>
<body>
<div class="content">
<h2>SMTP Connections</h2>
<div class="text">&nbsp;</div>
<form action="" method="get">
 <table class="textBox" width="99%">
  <tr>
   <td class="noBorder" nowrap>
    $s3&nbsp;&nbsp;$s1
   </td>
  </tr>
 </table>
</form>
<table width="100%" cellspacing="0" cellpadding="0">
<tr><td class="tabletext" colspan="4" width="100%">&nbsp;</td><tr>
$s2</table>
<br>
</div>
</body></html>
EOT
}

sub SaveConfig {
 rename("$base/assp.cfg.bak","$base/assp.cfg.bak.bak");
 rename("$base/assp.cfg","$base/assp.cfg.bak");
 open(F,">$base/assp.cfg");
 foreach (sort keys %Config) {print F "$_:=$Config{$_}\n";}
 close F;
}

sub textinput {my ($name,$nicename,$size,$func,$default,$valid,$onchange,$description)=@_;
 my $Error=checkUpdate($name,$valid,$onchange);
 my $value=encodeHTMLEntities($Config{$name});
 my $edit;
 if ($value=~/^ *file: *(.+)/i) { # the optionlist is actually saved in a file.
  my $fil=$1;
  # escape query string
  $fil=~s/([^\w\-.!~*\'() ])/sprintf("%%%02X",ord($1))/eg; $fil=~s/ /+/g;
  $edit="<input type=\"button\" value=\" Edit file \" onClick=\"javascript:popFileEditor(\'$fil\',1);\">";
 }
 $name=~s/(e)(mail)/$1_$2/gi; # get rid of google autofill
"<a name=\"$name\"></a>
 <div class=\"shadow\">
 <div class=\"option\">
  <div class=\"optionTitle\">$nicename</div>
  <div class=\"optionValue\">
   <input name=\"$name\" size=\"$size\" value=\"$value\" />
   $edit<br />
   $Error$description\n
  </div>
 </div>
 &nbsp;
 </div>";
}
# everybody wants this, but I hate it -- use it if you care.
sub passinput {my ($name,$nicename,$size,$func,$default,$valid,$onchange,$description)=@_;
 my $Error=checkUpdate($name,$valid,$onchange);
 my $value=encodeHTMLEntities($Config{$name});
"<a name=\"$name\"></a>
 <div class=\"shadow\">
 <div class=\"option\">
  <div class=\"optionTitle\">$nicename</div>
  <div class=\"optionValue\"><input type=\"password\" name=\"$name\" size=\"$size\" value=\"$value\" /><br />\n$Error$description
  </div>
 </div>
 &nbsp;
 </div>";
}
sub checkbox {my ($name,$nicename,$size,$func,$default,$valid,$onchange,$description)=@_;
 my $Error=checkUpdate($name,$valid,$onchange);
 my $checked=$Config{$name}?'checked="checked"':'';
 "<a name=\"$name\"></a>
 <div class=\"shadow\">
 <div class=\"option\">
  <div class=\"optionTitle\">
   <input type=\"checkbox\" name=\"$name\" value=\"1\" $checked />$nicename<br /></div>
  <div class=\"optionValue\">\n$Error$description
  </div>
 </div>
 &nbsp;
 </div>";
}
sub heading {my ($description,$nodeId)=@_[4,5,6];
 "</div>
<div onmousedown=\"toggleDisp('$nodeId')\" class=\"contentHead\">
 $description
</div>
<div id=\"$nodeId\">\n";
}

sub checkUpdate {
 my ($name,$valid,$onchange)=@_;
 return '' unless %qs;
 if($qs{$name} ne $Config{$name}) {
  if($qs{$name}=~/$valid/i) {
   my $new=$1; my $info;
   my $old=$Config{$name};
   $Config{$name}=$new;
   if($onchange) {
    $info=$onchange->($name,$old,$new);
   } else {
    mlog(0,"admin update: $name changed from '$old' to '$new'");
    ${$name}=$new;
    # -- this sets the variable name with the same name as the config key to the new value
    # -- for example $Config{myName}="ASSP-nospam" -> $myName="ASSP-nospam";
   }
   $ConfigChanged=1;
   return "<span class=\"positive\"><b>*** Updated $info</b></span><br />";
  } else {
   return "<span class=\"negative\"><b>*** Invalid: '$qs{$name}'</b></span><br />";
  }
 }
}

# This function is called on startup to clean up some settings
# Primarily these are settings that might be absent from assp.cfg
# or settings that are not needed anymore after an upgrade
sub fixConfigSettings {
 $Config{base}=$base;
 # for upgrading from earlier than 1.1.1
 if (exists $Config{TestMode}) {
  if ($Config{TestMode}) {
   $Config{baysTestMode}=1;
   $Config{blTestMode}=1;
   $Config{hlTestMode}=1;
   $Config{sbTestMode}=1;
   $Config{spfTestMode}=1;
   $Config{rblTestMode}=1;
   $Config{srsTestMode}=1;
  }
  # TestMode is not used in this version
  delete $Config{TestMode};
 }
 if (exists $Config{ExtensionsToBlock}) {
  $Config{BadAttachL1}=$Config{ExtensionsToBlock};
  # ExtensionsToBlock is not used in this version
  delete $Config{ExtensionsToBlock};
 }
 if (exists $Config{EmailWhitelist}) {
  $Config{EmailWhitelistAdd}=$Config{EmailWhitelist};
  # EmailWhitelist is not used in this version
  delete $Config{EmailWhitelist};
 }
 # settings that are not needed anymore after an upgrade
 delete $Config{noProcessingDomains} if exists $Config{noProcessingDomains};
 delete $Config{showDNSValidation} if exists $Config{showDNSValidation};
 delete $Config{showEmailInterface} if exists $Config{showEmailInterface};
 delete $Config{showFilePaths} if exists $Config{showFilePaths};
 delete $Config{showLogging} if exists $Config{showLogging};
 delete $Config{showNetworkSetup} if exists $Config{showNetworkSetup};
 delete $Config{showOtherSettings} if exists $Config{showOtherSettings};
 delete $Config{showRelaying} if exists $Config{showRelaying};
 delete $Config{showSecurity} if exists $Config{showSecurity};
 delete $Config{showSpamBomb} if exists $Config{showSpamBomb};
 delete $Config{showSpamControl} if exists $Config{showSpamControl};
 delete $Config{showTestModeOptions} if exists $Config{showTestModeOptions};
 delete $Config{showValidateRecipients} if exists $Config{showValidateRecipients};
 delete $Config{showVirusControl} if exists $Config{showVirusControl};
 delete $Config{showWhitelistOptions} if exists $Config{showWhitelistOptions};
 # -- this sets the variable name with the same name as the config key to the new value
 # -- for example $Config{myName}="ASSP-nospam" -> $myName="ASSP-nospam";
 foreach (keys %Config) {${$_}=$Config{$_};}
 # turn settings into regular expressions
 @PossibleOptionFiles=();
 @PossibleOptionFiles2=();
 foreach (@Config) {
  if($_->[6] eq 'ConfigMakeRe') {
   $silent=1 if($AsADaemon);
   ${$_->[0]}=optionList(${$_->[0]},$_->[0]);
   push(@PossibleOptionFiles,$_->[0]);
  } elsif($_->[6] eq 'ConfigCompileRe') {
   ConfigCompileRe($_->[0],'',${$_->[0]},'Initializing');
   push(@PossibleOptionFiles2,$_->[0]);
  }
 }
 updateBadAttachL1(BadAttachL1,'',$Config{BadAttachL1},'Initializing');
 updateRBL(updateRBL,'',$Config{ValidateRBL},'Initializing');
 updateSRS(updateSRS,'',$Config{EnableSRS},'Initializing');
 updateLog2(updateLog2,'',$Config{freqSpam},'Initializing');
 SaveConfig();
}

sub ConfigMakeRe { my ($name, $old, $new)=@_;
 $$name=optionList($new,$name);
 mlog(0,"admin update: $name changed from '$old' to '$new'");
 '';
}

sub checkOptionList {
 # this checks and corrects a | separated list and handles the options in a file
 my ($value,$name)=@_;
 my $fromfile=0;
 if($value=~/^ *file: *(.+)/i) {
  # the option list is actually saved in a file.
  $fromfile=1;
  my $fil=$1;
 $fil="$base/$fil" if $fil!~/^(([a-z]:)?[\/\\]|\Q$base\E)/;
  #$fil="$base/$fil" if $fil!~/^\Q$base\E/i;
  local $/;
  my @s=stat($fil);
  my $mtime=$s[9];
  $FileUpdate{$fil}=$mtime;
  if(open(OL,"<$fil")) {
   $value=<OL>; # read the file
   $value=~s/#.*//g; # clean off comments
   $value=~s/\s*\n\s*/|/g; # replace newlines (and the whitespace that surrounds them) with a |
   mlog(0,"option list file '$fil' reloaded ($name)");
   close OL;
  } else {
   $value='zzzzz';
   mlog(0,"failed to open option list file '$fil' ($name): $!");
  }
 }
 $value=~s/\|\|+/\|/g;
 $value=~s/^\s*\|?//;
 $value=~s/\|?\s*$//;
 if (!$fromfile) {
  # set corrected value back in Config
  $Config{$name}=$value;
 }
 return $value;
}

sub ConfigCompileRe { my ($name, $old, $new, $init)=@_;
 $$name=$new;
 mlog(0,"admin update: $name changed from '$old' to '$new'") unless $init;
 my $n2=$name."RE";
 $new=checkOptionList($new,$name);

 if($new) {
  SetRE($n2,$new,"is",$name);
 }

}

sub optionList {
 # this converts a | separated list into a RE
 my ($d,$configname)=@_;
 $d=checkOptionList($d,$configname);
 $d=~s/([\.\[\]\-\(\)\*\+\\])/\\$1/g;
 $MakeRE{$configname}->($d);
 $d;
}
sub autoChange {
 # this converts a | separated list into a RE
my ($d,$configname)=@_;
my $value=$Config{$configname};
@valuelist = split(/\|/,$value);
my $size=@valuelist;
if ($size!=0) {
open (F, ">$base/$configname.txt");
foreach (@valuelist) {
 print F "$_\n";
}
close (F);
$Config{$name}="file:$configname.txt";
}}
sub fileUpdated {
 my $fil=shift;

 $fil="$base/$fil" if $fil!~/^(([a-z]:)?[\/\\]|\Q$base\E)/;
 #$fil="$base/$fil" if $fil!~/^\Q$base\E/i;
 return 1 unless $FileUpdate{$fil};
 my @s=stat($fil);
 my $mtime=$s[9];
 $FileUpdate{$fil}!=$mtime;
}

sub ConfigChangeMailPort {my ($name, $old, $new)=@_;
 if($> == 0 || $new >= 1024) {
  # change the listenport
  $listenPort=$new;
  if($lsn) {
   $readable->remove($lsn);
   $lsn->close();
  }
  $lsn = newListen($listenPort,\&NewSMTPConnection);
  mlog(0,"listening on new mail port $listenPort (changed from $old) per admin request");
  return '';
 } else {
  # don't have permissions to change
  mlog(0,"request to listen on new mail port $listenPort (changed from $old) -- restart required; euid=$>");
  return "<br />Restart required; euid=$>";
 }
}

sub ConfigChangeMailPort2 {my ($name, $old, $new)=@_;
 if($> == 0 || $new >= 1024) {
  # change the listenport2
  $listenPort2=$new;
  if($lsn2) {
   $readable->remove($lsn2);
   $lsn2->close();
  }
  $lsn2 = newListen($listenPort2,\&NewSMTPConnection);
  mlog(0,"listening on new secondary mail port $listenPort2 (changed from $old) per admin request");
  return '';
 } else {
  # don't have permissions to change
  mlog(0,"request to listen on new secondary mail port $listenPort2 (changed from $old) -- restart required; euid=$>");
  return "<br />Restart required; euid=$>";
 }
}

sub ConfigChangeAdminPort {my ($name, $old, $new)=@_;
 if($> == 0 || $new >= 1024) {
  # change the listenport
  $webAdminPort=$new;
  $readable->remove($WebSocket);
  $WebSocket->close();
  $WebSocket = newListen($webAdminPort,\&NewWebConnection);
  if($WebSocket) {
   mlog(0,"listening on new admin port $new (changed from $old) per admin request");
  } else {
   # couldn't open the port -- switch back
   $webAdminPort=$old;
   $WebSocket = newListen($webAdminPort,\&NewWebConnection);
   mlog(0,"couldn't open new port -- still listening on $old");
   $Config{$name}=$old;
   return "<span class=\"negative\">Couldn't open new port $new</span>";
  }
  return '';
 } else {
  # don't have permissions to change
  mlog(0,"request to listen on new admin port $new (changed from $old) -- restart required; euid=$>");
  return "<br />Restart required; euid=$>";
 }
}

sub ConfigChangeRelayPort {my ($name, $old, $new)=@_;
 unless ($relayHost && $new) {
  if($Relay) {
   $readable->remove($Relay);
   $Relay->close();
   mlog(0,"relay port disabled");
   return '<br />relay port disabled';
  } else {
   return "<br />relayHost ($relayHost) and relayPort ($new) must be defined to enable relaying";
  }
 }
 if($> == 0 || $new >= 1024) {
  # change the listenport
  $relayPort=$new;
  if($Relay) {
   $readable->remove($Relay);
   $Relay->close();
  }
  $Relay=newListen($relayPort,\&NewSMTPConnection);
  mlog(0,"listening for relay connections at $relayPort -- changed per admin request");
  return '';
 } else {
  # don't have permissions to change
  mlog(0,"request to listen on new relay port $new (changed from $old) -- restart required; euid=$>");
  return "<br />Restart required; euid=$>";
 }
}
sub ConfigPBDB {my ($name, $old, $new)=@_;
$PBDBfile=$Config{$name};
}
sub ConfigChangeLogfile {my ($name, $old, $new)=@_;
 close LOG if $logfile;
 $logfile=$new;
 if($logfile && open(LOG,">>$base/$logfile")) {my $oldfh = select(LOG); $| = 1; select($oldfh);}
 mlog(0,"log file changed to '$new' from '$old' per admin request");
 '';
}
sub ConfigDEBUG {my ($name, $old, $new)=@_;
 close DEBUG if $DEBUG;
 $DEBUG=$new;
 if($DEBUG) {
  open(DEBUG, ">$base/".time.".dbg"); binmode(DEBUG); my $oldfh = select(DEBUG); $| = 1; select($oldfh);
  eval(q[sub d {
   my $time=gmtime(); $time=~s/... (...) +(\d+) (........) ..(..)/$2 $1 $4 $3/;
   print DEBUG "$time <$_[0]>\n";
  }
  ]);
 } else {
  eval(q[sub d{}]);
 }
 mlog(0,"debug file changed to '$new' from '$old' per admin request");
 '';
}

# Bad Attachment Settings, Checks and Update.
sub updateBadAttachL1 {my ($name, $old, $new, $init)=@_;
  mlog(0,"Badattach Level 1 updated from '$old' to '$new'") unless $init;
  SetRE(badattachL1RE,qq[content-\\w+: .*\\s+.*name\\s*=\\s*".*\\.($new)"|content-\\w+: .*\\s+.*name\\s*=\\s*.*\\.($new)\\s],'i',"Bad Attachment L1");
 updateBadAttachL2(BadAttachL2,'',$Config{BadAttachL2},$new);
}
sub updateBadAttachL2 {my ($name, $old, $new, $init)=@_;
  mlog(0,"Badattach Level 2 updated from '$old' to '$new'") unless $init;
  $new.='|'.$init;
  SetRE(badattachL2RE,qq[content-\\w+: .*\\s+.*name\\s*=\\s*".*\\.($new)"|content-\\w+: .*\\s+.*name\\s*=\\s*.*\\.($new)\\s],'i',"Bad Attachment L2");
 updateBadAttachL3(BadAttachL3,'',$Config{BadAttachL3},$new);
}
sub updateBadAttachL3 {my ($name, $old, $new, $init)=@_;
 mlog(0,"Badattach Level 3 updated from '$old' to '$new'") unless $init;
 $new.='|'.$init;
 SetRE(badattachL3RE,qq[content-\\w+: .*\\s+.*name\\s*=\\s*".*\\.($new)"|content-\\w+: .*\\s+.*name\\s*=\\s*.*\\.($new)\\s],'i',"Bad Attachment L2");
 $badattachRE[1]=$badattachL1RE;
 $badattachRE[2]=$badattachL2RE;
 $badattachRE[3]=$badattachL3RE;
 '';
}

# RBL Settings Checks, and Update.
sub updateRBL {my ($name, $old, $new, $init)=@_;
 mlog(0,"RBL-Enable updated from '$old' to '$new'") unless $init;
 $ValidateRBL=$Config{ValidateRBL}=$new;
 if (!$CanUseRBL) {
  mlog(0,"RBL-Enable updated from '1' to ''") if $Config{ValidateRBL};
  $ValidateRBL=$Config{ValidateRBL}=undef;
  return '<span class="negative">*** Net::DNS must be installed before enabling RBL.</span>';
 } else {
  updateRBLMH(updateRBLMH,'',$Config{RBLmaxhits},'Cascading');
 }
}

sub updateRBLMH {my ($name, $old, $new, $init)=@_;
 mlog(0,"RBL Maximum Hits updated from '$old' to '$new'") unless $init;
 $RBLmaxhits=$new;
 if ($new<=0) {
  mlog(0,"RBL-Enable updated from '1' to ''") if $Config{ValidateRBL};
  $ValidateRBL=$Config{ValidateRBL}=undef;
  return '<span class="negative">*** RBLmaxhits must be defined and positive before enabling RBL.</span>';
 } else {
  updateRBLMR(updateRBLMR,'',$Config{RBLmaxreplies},'Cascading');
 }
}
sub updateRBLMR {my ($name, $old, $new, $init)=@_;
 mlog(0,"RBL Maximum Replies updated from '$old' to '$new'") unless $init;
 $RBLmaxreplies=$new;
 if ($new<$RBLmaxhits) {
  mlog(0,"RBL-Enable updated from '1' to ''") if $Config{ValidateRBL};
  $ValidateRBL=$Config{ValidateRBL}=undef;
  return '<span class="negative">*** RBLmaxreplies must be more than or equal to RBLmaxhits before enabling RBL.</span>';
 } else {
  updateRBLSP(updateRBLSP,'',$Config{RBLServiceProvider},'Cascading');
 }
}
sub updateRBLSP {my ($name, $old, $new, $init)=@_;
 mlog(0,"RBL Service Providers updated from '$old' to '$new'") unless $init;
 $RBLServiceProvider=$new;
 my $domains = ($new =~ s/\|/$1/g)+1;
 if ($domains<$RBLmaxreplies) {
  mlog(0,"RBL-Enable updated from '1' to ''") if $Config{ValidateRBL};
  $ValidateRBL=$Config{ValidateRBL}=undef;
  return '<span class="negative">*** RBLServiceProvider must contain more than or equal to RBLmaxreplies domains before enabling RBL.</span>';
 } elsif($CanUseRBL) {
  my $res = Net::DNS::Resolver->new;
  @nameservers = $res->nameservers;
  @rbllist = split(/\|/,$RBLServiceProvider);
  if ($init && $ValidateRBL) {
   return ' & RBL activated';
  } else {
   return '';
  }
 }
}
sub updateDNSWL {my ($name, $old, $new, $init)=@_;
 mlog(0,"DNSWL Service Providers updated from '$old' to '$new'") unless $init;
 $DNSWLServiceProvider=$new;
 my $domains = ($new =~ s/\|/$1/g)+1;
 
  @dnswllist = split(/\|/,$DNSWLServiceProvider);
  if ($init && $ValidateRBL) {

   return ' & DNSWL activated';
  } else {
   return '';
  }
}
sub updateRBLCR {my ($name, $old, $new, $init)=@_;
mlog(0,"RBL Cache Refresh updated from '$old' to '$new'") unless $init;
&cleanCacheRBL;
}
sub updateLDAPHost {my ($name, $old, $new, $init)=@_;
 mlog(0,"LDAP Hosts updated from '$old' to '$new'") unless $init;
 $LDAPHost=$new;
if($CanUseLDAP && $DoLDAP) {
	@ldaplist = split(/\|/,$LDAPHost);
	$ldaplist = \@ldaplist;
	mlog($fh,"checking LDAP server at $LDAPHost -- ");
	$ldap = Net::LDAP->new( $ldaplist);
	
 if(! $ldap) {
  mlog($fh,"couldn't contact LDAP server at $LDAPHost -- ");
  AdminReportMail("Warning: LDAP server at $LDAPHost","couldn't contact LDAP server at $LDAPHost -- ") ;
    if (!$init) {
   return ' & LDAP not activated';
  } else {
   return '';
  }
 } else {
  mlog($fh,"LDAP server at $LDAPHost contacted -- ");
 if (!$init) {
 return ' & LDAP activated';
  } else {
   return '';
  }}
 }
}

sub updatePenaltyDuration {
my ($name, $old, $new, $init)=@_;
 mlog(0,"$name updated from '$old' to '$new'") unless $init;
&CleanPB unless $init;
return "";
}
sub updatePenaltyExpiration {
my ($name, $old, $new, $init)=@_;
 mlog(0,"$name updated from '$old' to '$new'") unless $init;
&CleanPB unless $init;
return "";
}


sub cleanBlackPB {
if ($PenaltyExpiration==0) {
$PBBlackObject->flush() if $PBBlackObject;
unlink "$base/$pbdb.black.db.bak";
rename("$base/$pbdb.black.db","$base/$pbdb.black.db.bak");
$PBBlackObject->DESTROY() if $PBBlackObject;

return;
}

my $ips_before=$ips_deleted=0;
my $t=time;
my $tdif;
my $newscore=0;
my($ct,$ut,$pbstatus,$score,$sip,$reason);
my $expmin=$PenaltyExpiration*60;
delete $PBBlack{"0.0.0.0"};
delete $PBBlack{""};
while (($k,$v)=each(%PBBlack)) {
($ct,$ut,$pbstatus,$score,$sip,$reason)=split(" ",$v);
$tdif=$t-$ct;
$ips_before++;

if ($tdif>$PenaltyDuration*60 && $score<$PenaltyLimit ) {
   delete $PBBlack{$k};
   $ips_deleted++;
   next;}
 if ($tdif>$PenaltyExpiration*60 && $score<$PenaltyExtreme) {
   delete $PBBlack{$k};
   $ips_deleted++;
   next;}

if (exists $PBWhite{$ip} || ($ispip && $k=~$ISPRE) || ($noDelay && $k=~$NDRE) || ($contentOnlyRe && $k=~('('.$contentOnlyReRE.')'))) {
   delete $PBBlack{$k};
   $ips_deleted++;
   next;}
if ($tdif>$ExtremeExpiration*60*60*24 ) {
   delete $PBBlack{$k};
   $ips_deleted++;
   next;}
}
if ($ips_before==0) {
$PBBlackObject->flush() if $PBBlackObject;
unlink "$base/$pbdb.black.db.bak";
rename("$base/$pbdb.black.db","$base/$pbdb.black.db.bak");
$PBBlackObject->DESTROY() if $PBBlackObject;}
mlog(0,"PB: cleaning black finished; IPs before=$ips_before, deleted=$ips_deleted") if $PenaltyLog;
MainLoop2();
}
sub cleanWhitePB {
my $ips_before=$ips_deleted=0;
my $t=time;
my $newscore=0;
delete $PBWhite{"0.0.0.0"};
delete $PBWhite{""};

while (($k,$v)=each(%PBWhite)) {
my($ct,$ut,$pbstatus,$score)=split(" ",$v);
$ips_before++;
if ($t-$ut>=$MaxWhitelistDays*24*3600*2) {
   delete $PBWhite{$k};
   $ips_deleted++;
}}
 if ($ips_before==0) {

} else {
 mlog(0,"PB: cleaning white finished; IPs before=$ips_before, deleted=$ips_deleted") if $PenaltyLog;
 }
}
sub cleanCacheRBL {
my $ips_before=$ips_deleted=0;
my $t=time;
while (($k,$v)=each(%RBLCache)) {
my($ct,$date,$rbllists)=split(" ",$v);

$ips_before++;
if ($t-$ct>=$RBLCacheRefresh*3600) {
   delete $RBLCache{$k};
   $ips_deleted++;
}}
mlog(0,"RBLCache: cleaning cache finished; IPs before=$ips_before, deleted=$ips_deleted") if $PenaltyLog;
if ($ips_before==0) {
$RBLCacheObject->flush() ;
unlink "$base/$pbdb.rbl.db.bak";
rename("$base/$pbdb.rbl.db","$base/$pbdb.rbl.db.bak");
$RBLCacheObject->DESTROY();
$RBLCache{""}="" if $ips_before==0;
}}

sub exportExtremePB {
my $myexport=$Config{"exportExtremeFile"};
if($myexport=~/^ *file: *(.+)/i) {
$fil=$1;
} else {
return;
}
$fil="$base/$fil" if $fil!~/^(([a-z]:)?[\/\\]|\Q$base\E)/;

open (EXPORT, ">$fil");
my $counter=0;
while (($k,$v)=each(%PBBlack)) {
($ct,$ut,$pbstatus,$score,$sip,$reason)=split(" ",$v);
next if $k=~/\.0$/;
if ($score>$PenaltyExtreme) {
my ($sec,$min,$hour,$mday,$mon,$year) = localtime($ct);
$mon++; $year-=100;
my $mm=sprintf("%02d-%02d-%02d",$year,$mon,$mday);
print EXPORT "$k\n" ;
$counter++;
}
}
mlog(0,"PB:  $fil generated, entries:$counter") if $PenaltyLog;
close (EXPORT);
}
sub deleteNP {
my ($name,$reason)=shift;
return if ($EmailNoNPRemove==1);
my $mynp=$Config{"noProcessing"};
if($mynp=~/^ *file: *(.+)/i) {
$fil=$1;
} else {
return;
}
$fil="$base/$fil" if $fil!~/^(([a-z]:)?[\/\\]|\Q$base\E)/;
return if ( !-e "$fil");
my (@lines,$nlines,$kk);
open (NP, $fil);
@lines = <NP>;
close (NP);
unlink "$fil.bak"; 
rename("$fil","$fil.bak");
open (NP, ">$fil");

foreach $k (@lines) {
mlog(0,"$name deleted from $fil reason:$reason") if $k=~/$name/i;

next if $k=~/$name/i;
print NP "$k";
}
close (NP);
}

# SRS Settings Checks, and Update.
sub updateSRS {my ($name, $old, $new, $init)=@_;
 mlog(0,"SRS-Enable updated from '$old' to '$new'") unless $init;
 $EnableSRS=$Config{EnableSRS}=$new;
 if (!$CanUseSRS) {
  mlog(0,"SRS-Enable updated from '1' to ''") if $Config{EnableSRS};
  $EnableSRS=$Config{EnableSRS}=undef;
  return '<span class="negative">*** Mail::SRS must be installed before enabling SRS.</span>';
 } else {
  updateSRSAD(updateSRSAD,'',$Config{SRSAliasDomain},'Cascading');
 }
}
sub updateSRSAD {my ($name, $old, $new, $init)=@_;
 mlog(0,"SRS Alias Domain updated from '$old' to '$new'") unless $init;
 $SRSAliasDomain=$new;
 if ($new eq '') {
  mlog(0,"SRS-Enable updated from '1' to ''") if $Config{EnableSRS};
  $EnableSRS=$Config{EnableSRS}=undef;
  return '<span class="negative">*** SRSAliasDomain must be defined before enabling SRS.</span>';
 } else {
  updateSRSSK(updateSRSSK,'',$Config{SRSSecretKey},'Cascading');
 }
}
sub updateSRSSK {my ($name, $old, $new, $init)=@_;
 mlog(0,"SRS Secret Key updated from '*****' to '*****'") unless $init;
 $SRSSecretKey=$new;
 if (length($new)<5) {
  mlog(0,"SRS-Enable updated from '1' to ''") if $Config{EnableSRS};
  $EnableSRS=$Config{EnableSRS}=undef;
  return '<span class="negative">*** SRSSecretKey must be at least 5 characters long before enabling SRS.</span>';
 } elsif($CanUseSRS) {
  if ($init && $EnableSRS) {
   return ' & SRS activated';
  } else {
   return '';
  }
 }
}

# Database File Logging Frequency Setup.
sub updateLog2 {my ($name, $old, $new, $init)=@_;
 mlog(0,"Non Spam Logging Frequency updated from '$old' to '$new'") unless $init;
 $logFreq[2]=$new;
 updateLog3(updateLog3,'',$Config{freqNonSpam},$new);
}
sub updateLog3 {my ($name, $old, $new, $init)=@_;
 mlog(0,"Spam Logging Frequency updated from '$old' to '$new'") unless $init;
 $logFreq[3]=$new;
 return '';
}

sub reloadConfigFile {
 # called on SIG HUP
 my %newConfig;
 mlog(0,"sig HUP -- reloading config");
 open(F,"<$base/assp.cfg"); local $/; (%newConfig)=split(/:=|\n/,<F>); close F;
 foreach $c (@Config) {
  my ($name,$nicename,$size,$func,$default,$valid,$onchange,$description)=@$c;
  if($Config{$name} ne $newConfig{$name}) {
   if($newConfig{$name}=~/$valid/i) {
    my $new=$1; my $info;
    if($onchange) {
     $info=$onchange->($name,$Config{$name},$new);
    } else {
     mlog(0,"admin update: $name changed from '$Config{$name}' to '$new'");
     ${$name}=$new;
     # -- this sets the variable name with the same name as the config key to the new value
     # -- for example $Config{myName}="ASSP-nospam" -> $myName="ASSP-nospam";
    }
    $Config{$name}=$new;
   } else {
    mlog(0,"error: invalid '$newConfig{$name}' -- not changed");
   }
  }
 }
  foreach $f (@PossibleOptionFiles) {
   ${$f}=optionList($Config{$f},$f) if $Config{$f}=~/^ *file: *(.+)/i && fileUpdated($1);
  }
  foreach $f (@PossibleOptionFiles2) {
   ConfigCompileRe($f,'',${$f},'Initializing') if $Config{$f}=~/^ *file: *(.+)/i && fileUpdated($1);
  }
 # reopen log file, just for fun.
  close LOG;
  if(open(LOG,">>$base/$logfile")) {my $oldfh = select(LOG); $| = 1; select($oldfh);}
  print LOG "Logfile reopened on HUP\n";
}

#####################################################################################
#                orderedtie
{
package orderedtie;
# This is a tied value that caches lookups from a sorted file; \n separates records,
# \002 separates the key from the value. After main::OrderedTieHashSize lookups the cache is
# cleared. This give us most of the speed of the hash without the huge memory overhead of storing
# the entire hash and should be totally portable. Picking the best value for n requires some
# tuning. A \n is required to start the file.

# if you're updating entries it behoves you to call flush every so often to make sure that your
# changes are saved. This also frees the memory used to remember updated values.

# for my purposes a value of undef and a nonexistant key are the same

# Obviously if your keys or values contain \n or \002 it will totally goof things up.


sub TIEHASH {
 my ($c,$fn)=@_;
 my $self={
  fn => $fn,
  age => mtime($fn),
  cnt => 0,
  cache => {},
  updated => {},
  ptr => 1,
 };
 bless $self, $c;
 return $self;
}
sub DESTROY { $_[0]->flush(); }

sub mtime { my @s=stat($_[0]); $s[9]; }

sub flush {
 my $this=shift;
 return unless %{$this->{updated}};
 my $f=$this->{fn};
 open(O,">$f.tmp") || return undef;
 binmode(O);
 open(I,"<$f") || print O "\n";
 binmode(I);
 local $/="\n";
 my @l=(sort keys %{$this->{updated}});
 my ($k,$d,$r,$v);
 while($r=<I>) {
  ($k,$d)=split("\002",$r);
  while(@l && $l[0] lt $k) {
   $v=$this->{updated}{$l[0]};
   print O "$l[0]\002$v\n" if $v;
   shift(@l);
  }
  if($l[0] eq $k) {
   $v=$this->{updated}{$l[0]};
   print O "$l[0]\002$v\n" if $v;
   shift(@l);
  } else {
   print O $r;
  }
 }
 while(@l) {
  $v=$this->{updated}{$l[0]};
  print O "$l[0]\002$v\n" if $v;
  shift(@l);
 }
 close I; close O; unlink($f); rename("$f.tmp", $f);
 $this->{updated}={};
}

sub STORE {
 my ($this, $key, $value)=@_;
 $this->{cache}{$key}=$this->{updated}{$key}=$value;
}

sub FETCH { my ($this, $key)=@_;
 return $this->{cache}{$key} if exists $this->{cache}{$key};
 $this->resetCache() if($this->{cnt}++ >$main::OrderedTieHashSize || ($this->{cnt} & 0x1f) == 0 && mtime($this->{fn}) != $this->{age});

 return $this->{cache}{$key}=binsearch($this->{fn},$key);
}

sub resetCache {
 my $this=shift;
 $this->{cnt}=0;
 $this->{age}=mtime($this->{fn});
 $this->{cache}={%{$this->{updated}}};
 main::mlog(0,"cache reset ($this->{fn})") if $main::MaintenanceLog;
}

sub binsearch {
 my ($f,$k)=@_;
 open(F,"<$f") || return undef;
 binmode(F);
 my $count=0;
 my $siz=my $h=-s $f;
 $siz-=1024;
 my $l=0;
 my $k0=$k;
 $k=~s/([\[\]\(\)\*\^\!\|\+\.\\\/\?\`\$\@\{\}])/\\$1/g; # make sure there's no re chars unqutoed in the key
 while(1) {
  my $m=(($l+$h)>>1)-1024;
  $m=0 if $m < 0;
  seek(F,$m,0);
  my $d; my $read= read(F,$d,2048);
  if( $d=~/\n$k\002([^\n]*)\n/) {
   close F;
   return $1;
  }
  my ($pre,$first,$last,$post)=$d=~/^(.*?)\n(.*?)\002.*\n(.*?)\002.*?\n(.*?)$/s;
  last unless defined $first;
  if($k0 gt $first && $k0 lt $last) {
   last;
  }
  if($k0 lt $first) {
   last if $m ==0;
   $h=$m-1024+length($pre);
   $h=0 if $h < 0;
  }
  if($k0 gt $last) {
   last if $m >= $siz;
   $l=$m+$read-length($post);
  }
  if($count++ > 100) {
   #main::mlog(0,"Warning: $this->{fn} must be repaired ($k0)");
   last;
  }
 }
 close F;
 return undef;
}

sub FIRSTKEY { $this=shift;
 $this->flush();
 $this->{ptr}=1;
 $this->NEXTKEY();
}
sub NEXTKEY { my ($this, $lastkey)=@_;
 local $/="\n";
 open(F,"<$this->{fn}") || return undef;
 binmode(F);
 seek(F,$this->{ptr},0);
 my $r=<F>;
 return undef unless $r;
 $this->{ptr}=tell F;
 close F;
 my ($k,$v)=$r=~/(.*?)\002(.*?)\n/s;
 if(!exists($this->{cache}{$k}) && $this->{cnt}++ >$main::OrderedTieHashSize) {
  $this->{cnt}=0;
  $this->{cache}={%{$this->{updated}}};
 }
 $this->{cache}{$k}=$v;
 $k;
}

sub EXISTS { my ($this, $key)=@_;
 return FETCH($this, $key);
}

sub DELETE {my ($this, $key)=@_;
 $this->{cache}{$key}=$this->{updated}{$key}=undef;
}

sub CLEAR {my ($this)=@_;
 open(F,">$this->{fn}"); binmode(F); print F "\n"; close F;
 $this->{cache}={};
 $this->{updated}={};
 $this->{cnt}=0;
}
}

{
#################################################################
# this package implements a pure perl virus scanner
# it uses the clam anti-virus databases (see www.clamav.net)
# Download your databases this way -- maybe once a day:
#  wget --timestamping http://database.clamav.net/database/viruses.db
#  wget --timestamping http://database.clamav.net/database/viruses.db2
#
# copyright (C) 2004, John Hanna under the terms of the GPL

package Av;

# load the databases -- return the number of signatures present
# optional parameters:
#   path => "/path/to/your/clamav/db/files", # default .
#   databases => "viruses.db,viruses.db2" # as many or as few as you want
sub init { my($proto,$args)=@_;
 $path= $args->{path} || ".";
 $databases = $args->{databases} || "viruses.db,viruses.db2";
 loadAll();
}

# public function to create a new scan buffer -- see addchar below
sub new { bless({offset=>0, buf=>'', prereq=>{}}, ref($_[0]) || $_[0]); }

# public function to reset the scan buffer
sub clear {my $self=shift; $self->{offset}=0; $self->{buf}=''; $self->{prereq}={};}

# return the number of signatures in the virus database
sub count {$count}

# called internally, but can be called to manually reload the virus signature database
sub loadAll {
 $count=0;
 $longest=0;
 undef %prereqs;
 $prereqcount='a';
 undef @db;
 load("$path/$_") foreach (split(/,/,$databases));
 $count;
}

# called internally to add a signature file to the database
sub load { my ($f)=@_;
 open(F,"<$f");
 $fileTimes{$f}=[stat(F)]->[9];
 my ($nam,$sig,$lsig);
 while(<F>) {
  ($nam,$sig)=/(.*)=(.*)/;
  next unless $sig;
  $sig=lc $sig;
  $nam=~s/ \(clam\)//i;
  $nam=~s/'/\\'/g;
  my @parts=split(/\*/,$sig);
  my $lp;
  foreach my $part (0 .. $#parts) {
   my $p=$parts[$part];
   $longest = length($p)/2 if length($p)/2 > $longest;
   my $prereqn=$prereqs{$p} || ($prereqs{$p}=++$prereqcount);# if($part < $#parts);
   my $prereq=$part? $prereqs{$lp} :'';
   $lp=$p;
   my $return=$part == $#parts? $nam:'';
   my $setprereq=$part == $#parts? '' : $prereqn;
   my ($tail)=$p=~/([0-9a-f]{2,16})$/;
   my $ltail = length($tail);
   my $hsize=$ltail >=16? 8: $ltail >= 8? 4: $ltail >= 4? 2: 1;
   my $loc=substr($tail,-2*$hsize);

   my($pretest,$rest)=$p=~/([0-9a-f]{2,8})([0-9a-f\?]*)$/;
   $pretest=pack("H*",$pretest);
   my $lpretest=length($pretest);
   $rest=length($rest)/2+$lpretest;
   my @pretest;
   if($rest>$hsize && length($p) > 32) {
    @pretest=(-$rest,$lpretest,$pretest);
   } else {@pretest=(0,0,'');}
   $test=$p;
   $test=~s/(..)/\\x$1/g;
   my ($re,$match,$matchlen)=('','',0);
   if($test=~s/\\x\?\?/./g) {
    $re=qr/$test$/s;
   } else {
    my $len=length($p)/2;
    $matchlen=$len; $match=pack("H*",$p);
    #$match="" if $len == $hsize;
   }

   push(@{$db[$hsize]->{pack("H*",$loc)}}, [$prereq,$return,$setprereq,@pretest,$re,$match,$matchlen]);
  }
  $count++;
 }
 close F;
}

# public function to check if the database needs to be reloaded
# use this this way: Av->loadAll if Av->checkReload;
sub checkReload {
 foreach my $f (split(/,/,$databases)) {
  $f="$path/$f";
  # we want to reload if a file is newer (has later date) than when read,
  # and is at least 120 seconds old -- in lieu of locking
  my $modtime=[stat($f)]->[9];
  if($modtime > $fileTimes{$f} && time - $modtime > 120) {
   return 1;
  }
 }
 0;
}

# public function to scan a file
# returns undef if no virus found
# returns array-ref with the offset into the buffer and the name of the virus if found
# you can pass in an offset to start scanning to continue scanning the file
# you may need to $av->clear to get the desired effects
sub scanfile { my ($self, $file, $n)=@_;
 open(F,"<$file") || die("Couldn't open $file: $!"); binmode F;
 my $c;
 $self->{offset}=$n; $self->{buf}=''; $self->{prereq}={};
 seek(F,$n,0) if $n>0;
 seek(F,$n,2) if $n < 0;
 my $r;
 while(defined ($c=getc(F))) {
  return $r if $r=$self->addchar($c);
 }
 close F;
 undef;
}

# public function to do character-at-a-time scanning.
# $av=Av->new();
# foreach my $c (split(//,$buf)) {
#  print "'$r->[1]' virus found at offset $r->[0]\n" if $r=$av->addchar($c);
# }
sub addchar {
 my $self=shift;
 $self->{buf} .= $_[0];
 $self->{offset}++;
 if(length($self->{buf}) > $longest * 2) {
  $self->{buf}=substr($self->{buf}, -$longest);
 }
 foreach $hsiz (8,4,2,1) {
  my $l=$db[$hsiz]->{substr($self->{buf},-$hsiz)};
  foreach (@{$l}){
   if( ! $_->[0] || $self->{prereq}->{$_->[0]} ) {
    # pre test
    if(! $_->[4] || substr($self->{buf},$_->[3],$_->[4]) eq $_->[5]) {
     # real test
     if($_->[8] && substr($self->{buf},-$_->[8]) eq $_->[7] || ! $_->[8] && $self->{buf}=~$_->[6]) {
      $_->[2] && ($self->{prereq}->{$_->[2]}=1) || return [$self->{offset},$_->[1]];
     }
    }
   }
  }
 }
 return undef;
}

}

#################################################################
# this package implements realtime blacklisting
# it is based on Net::RBLClient by Asher Blum <asher@wildspark.com>
# CREDITS Martin H. Sluka <martin@sluka.de>
# Copyright (C) 2002 Asher Blum.  All rights reserved.
# This code is free software; you can redistribute it and/or modify it under
# the same terms as Perl itself.
# Modified for integration with ASSP by John Calvi.


package RBL;

use IO::Socket;

sub new {
    # This avoids compile time errors if Net::DNS is not installed.
    # The error will be returned on the lookup function call.
    if ($main::CanUseDNS) {
     require Net::DNS::Packet;
     $CanUseDNS=1;
    }
    my($class, %args) = @_;
    my $self = {
        lists       => [ lists() ],
        query_txt   => 1,
        max_time    => 10,
        timeout     => 1,
        max_hits    => 3,
        max_replies => 6,
        udp_maxlen  => 4000,
        server      => '127.0.0.1',
    };
    bless $self, $class;
    foreach my $key(keys %args) {
        defined($self->{ $key })
            or return "Invalid key: $key";
        $self->{ $key } = $args{ $key };
    }

    $self;
}

sub lookup {
    return "Net::DNS package required" unless $CanUseDNS;
    my($self, $target_ip) = @_;
    my $ip_pat = qr(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3});
    $target_ip =~ /$ip_pat/
        or return "Invalid ip: '$target_ip' - must be dotted quad";
    my $start_time = time;
    my $qip = join '.', reverse(split /\./, $target_ip);
    my $deadline = time + $self->{ max_time };

    my $sock = IO::Socket::INET->new(
        Proto     => 'udp',
        PeerPort  => 53,
        PeerAddr  => $self->{ server },
    ) or return "Failed to create UDP client";

    if ( $self->{ query_txt } ) {
      foreach my $list(@{ $self->{ lists } }) {
        my($msg_a, $msg_t) = mk_packet($qip, $list);
        foreach ($msg_a, $msg_t) {
          $sock->send($_) or return "send: $!";
        }
      }
    } else {
        foreach my $list(@{ $self->{ lists } }) {
          my $msg = mk_packet($qip, $list);
          $sock->send($msg) || return "send: $!";
        }
    }

    $self->{ results } = {};
    $self->{ txt } = {};

    my $needed = 0;
    if ($self->{ max_replies} > @{ $self->{ lists } }) {
      $needed = @{ $self->{ lists } };
    } else {
      $needed = $self->{ max_replies };
    }
    $needed <<= 1 if $self->{ query_txt }; # how many packets needed back
    my $hits = my $replies = 0;

    my $select = new IO::Select;
    $select->add($sock);

    # Keep receiving packets until one of the exit conditions is met:
    main::mlog(0,"Commencing RBL checks on $target_ip") if $main::RBLLog;
    while($needed && time < $deadline) {
      my $msg = '';
      my $dur = time - $start_time;
      if( my @ready = $select->can_read($self->{ timeout }) ){
        $sock->recv($msg, $self->{ udp_maxlen })  || return "recv: $!";
      } else {
        # waiting for other replies.
      }
      if($msg) {
        my ($domain, $res, $type) = decode_packet($msg);
        if ( defined $type && $type eq 'TXT' ) {
          $self->{ txt }{ $domain } = $res
        }
        elsif ($res) {
          $replies ++;
          $hits ++ if $res;
          $self->{ results }{ $domain } = $res;
          return 1 if    $hits >= $self->{ max_hits } ||
                         $replies >= $self->{ max_replies };
        }
        $needed --;
      }
    }
    main::mlog(0,"Completed RBL checks on $target_ip") if $main::RBLLog;
    close ($sock);
    1;
}

sub listed_by {
    my $self = shift;
    sort keys %{ $self->{ results } };
}

sub listed_hash {
    my $self = shift;
    %{ $self->{ results } };
}

sub txt_hash {
    my $self = shift;
    warn <<_ unless $self->{ query_txt };
Without query_txt turned on, you won't get any results from ->txt_hash().
_
    if (wantarray) { %{ $self->{ txt } } }
    else { $self->{ txt } }
}

# End methods - begin internal functions

sub mk_packet {
    # pass me a REVERSED dotted quad ip (qip) and a blocklist domain
    my($qip, $list) = @_;
    my($packet, $error) = new Net::DNS::Packet(my $fqdn = "$qip.$list", 'A');
    return "Cannot build DNS query for $fqdn, type A: $error" unless $packet;
    return $packet->data unless wantarray;
    my($txt_packet, $error) = new Net::DNS::Packet($fqdn, 'TXT', 'IN');
    return "Cannot build DNS query for $fqdn, type TXT: $error" unless $txt_packet;
    $packet->data, $txt_packet->data;
}

sub decode_packet {
    # takes a raw DNS response packet
    # returns domain, response
    my $data = shift;
    my $packet = Net::DNS::Packet->new(\$data);
    my @answer = $packet->answer;

    {
        my($res, $domain, $type);
        foreach my $answer (@answer) {
            {
                my $name = lc $answer->name;
                warn $answer->answerfrom .
                  " returned answers to different domains ($domain and $answer)"
                  if defined $domain && $name ne $domain;
                $domain = $answer->name;
            }
            $domain =~ s/^\d+\.\d+\.\d+\.\d+\.//;
            $type = $answer->type;
            $res = $type eq 'A'     ? inet_ntoa($answer->rdata)  :
                   $type eq 'CNAME' ?   cleanup($answer->rdata)  :
                   $type eq 'TXT'   ? (defined $res && "$res; ")
                                      . $answer->txtdata         :
                   '?';
            last unless $type eq 'TXT';
        }
        return $domain, $res, $type if defined $res;
    }

    # OK, there were no answers -
    # need to determine which domain
    # sent the packet.

    my @question = $packet->question;
    foreach my $question(@question) {
        my $domain = $question->qname;
        $domain =~ s/^\d+\.\d+\.\d+\.\d+\.//;
        return($domain, undef);
    }
}

sub cleanup {
    # remove control chars and stuff
    $_[ 0 ] =~ tr/a-zA-Z0-9./ /cs;
    $_[ 0 ];
}


sub lists {
    qw(
       bl.spamcop.net
       cbl.abuseat.org
       sbl-xbl.spamhaus.org
       dnsbl.njabl.org
       list.dsbl.org
       dnsbl.sorbs.net
       opm.blitzed.org
       dynablock.njabl.org
    );
}
1;

